## ---------------------------------------------
##
## Script name: 01_panel_krs
##
## Purpose of script: Build Panel Data Set at
##                    District (KRS) Level
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(openxlsx)
library(tidyverse)

# Clear environment
rm(list = ls())

# Define observation period
obs_years <- c(2008:2021)



# Import ------------------------------------------------------------------

# Reg Data
df_reg <- read.xlsx("../data/regdata/reg_data.xlsx")

# Unique district list (as of 2021)
krs400 <- unique(df_reg$krs)


## Price data: RWI-GEO-REDX

# Abbreviations: apRent: Apartment Rents; apPurc: Apartment Purchase prices;
#                houPurc: House Purchase prices

# Regional price index on district level, 2008-2022 (regression 2)
# --> suffix: _idx
apRent_idx <- read.xlsx("../data/RWIGEOREDX/RWIGEOREDX_ApRent_v9.xlsx",
  sheet = "2__District_Pindex_yearly"
)
apPurc_idx <- read.xlsx("../data/RWIGEOREDX/RWIGEOREDX_ApPurc_v9.xlsx",
  sheet = "2__District_Pindex_yearly"
)
houPurc_idx <- read.xlsx("../data/RWIGEOREDX/RWIGEOREDX_HouPurc_v9.xlsx",
  sheet = "2__District_Pindex_yearly"
)

# Change of regional price indices on district level to 2008, 2008-2022
# (regression 3) --> suffix: _chg
apRent_chg <- read.xlsx("../data/RWIGEOREDX/RWIGEOREDX_ApRent_v9.xlsx",
  sheet = "3__District_Change_yearly"
)
apPurc_chg <- read.xlsx("../data/RWIGEOREDX/RWIGEOREDX_ApPurc_v9.xlsx",
  sheet = "3__District_Change_yearly"
)
houPurc_chg <- read.xlsx("../data/RWIGEOREDX/RWIGEOREDX_HouPurc_v9.xlsx",
  sheet = "3__District_Change_yearly"
)


## IMPORT HERE REQUESTED DATA ##

# Hazard rate from GDV
hazard_rate <- read.xlsx("../data/regdata/hazard_rate.xlsx")

# Share of subprime credit scores from SCHUFA
neg_credscore <- read.xlsx("../data/regdata/neg_credscore.xlsx")

# Newly designated residential zones from Nbank
new_res_area <- read.xlsx("../data/regdata/new_res_area.xlsx")

# Housing vacancy from BBSR
housing_vac <- read.xlsx("../data/regdata/housing_vac.xlsx")



# Clean RWIG-GEO-REDX Housing Price Data ----------------------------------

# Put all dfs into one list
l_prices <- list(
  apRent_idx, apPurc_idx, houPurc_idx,
  apRent_chg, apPurc_chg, houPurc_chg
)
prices_names <- c(
  "apRent_idx", "apPurc_idx", "houPurc_idx",
  "apRent_chg", "apPurc_chg", "houPurc_chg"
)
names(l_prices) <- prices_names

# Remove second column (name) and drop frequencies (freq2008, ...)
l_prices1 <- lapply(l_prices, function(x) {
  y <- x[, -c(2, 3, 5, 7, 9, 11, 13, 15, 17, 19, 21, 23, 25, 27, 29, 31)]
  return(y)
})

# Remove second column (name) and drop price indices
l_prices2 <- lapply(l_prices, function(x) {
  y <- x[, -c(2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 22, 24, 26, 28, 30, 32)]
  return(y)
})

# suffix _n indicates number of ads used (freq) for the price index
prices_names2 <- c(
  "apRent_idx_n", "apPurc_idx_n", "houPurc_idx_n",
  "apRent_chg_n", "apPurc_chg_n", "houPurc_chg_n"
)
names(l_prices2) <- prices_names2

# Set years as column names
colnames <- c("krs", 2008:2022)
l_prices1 <- lapply(l_prices1, setNames, colnames)
l_prices2 <- lapply(l_prices2, setNames, colnames)

# Bring into long format
l_prices_long1 <- lapply(l_prices1, function(x) {
  y <- x %>%
    pivot_longer(cols = "2008":"2022", names_to = "year", values_to = "value")
  return(y)
})

l_prices_long1 <- lapply(seq_along(l_prices_long1), function(x) {
  names(l_prices_long1[[x]]) <- c("krs", "year", names(l_prices)[x])
  return(l_prices_long1[[x]])
})

names(l_prices_long1) <- prices_names

l_prices_long2 <- lapply(l_prices2, function(x) {
  y <- x %>%
    pivot_longer(cols = "2008":"2022", names_to = "year", values_to = "value")
  return(y)
})

l_prices_long2 <- lapply(seq_along(l_prices_long2), function(x) {
  names(l_prices_long2[[x]]) <- c("krs", "year", names(l_prices2)[x])
  return(l_prices_long2[[x]])
})

names(l_prices_long2) <- prices_names2

# Reduce to data frames
df_prices1 <- l_prices_long1 %>%
  reduce(full_join, by = c("krs", "year"))

df_prices2 <- l_prices_long2 %>%
  reduce(full_join, by = c("krs", "year"))

# Match both data frames back together
# Filter for observation period
df_prices <- df_prices1 %>%
  left_join(., df_prices2, by = c("krs", "year")) %>%
  filter(year %in% obs_years)


## Aggregation to district definition as of 2021 (400 districts)

# Add label & weights for Wartburgkreis and Eisenach (which were merged in 2021)
# Weights based on number of ads

df_prices_long <- df_prices %>%
  pivot_longer(
    cols = starts_with("apRent") | starts_with("apPurc") | starts_with("houPurc"),
    names_to = c("var", "type"),
    names_pattern = "([^_]+)_(.*)"
  )

df_prices_long_w <- df_prices_long %>%
  filter(type == "chg_n") %>%
  select(-type) %>%
  rename(n = value)

df_prices_long <- df_prices_long %>%
  filter(type != "chg_n", type != "idx_n") %>%
  left_join(df_prices_long_w, by = c("krs", "year", "var"))


# Aggregate price index by weighted mean
df_prices_long400 <- df_prices_long %>%
  mutate(krs_new = ifelse(krs == "16056", "16063", krs)) %>%
  group_by(krs_new, year, var, type) %>%
  summarise(value = weighted.mean(value, n, na.rm = TRUE)) %>%
  ungroup() %>%
  rename(krs = krs_new) %>%
  filter(!is.na(krs))

# Bring back to original format
df_prices400 <- df_prices_long400 %>%
  mutate(id_combined = paste(var, type, sep = "_")) %>%
  select(krs, year, id_combined, value) %>%
  pivot_wider(names_from = id_combined, values_from = value)

# Aggregate frequency by sum
df_prices_long2_400 <- df_prices_long %>%
  mutate(krs_new = ifelse(krs == "16056", "16063", krs)) %>%
  group_by(krs_new, year, var, type) %>%
  summarise(n = sum(n, na.rm = TRUE)) %>%
  ungroup() %>%
  rename(krs = krs_new) %>%
  filter(!is.na(krs))

# Bring back to original format
df_prices2_400 <- df_prices_long2_400 %>%
  filter(type == "chg") %>%
  mutate(type = ifelse(type == "chg", "n", type)) %>%
  mutate(id_combined = paste(var, type, sep = "_")) %>%
  select(krs, year, id_combined, n) %>%
  pivot_wider(names_from = id_combined, values_from = n)


# Merge both aggregated price data sets together
df <- df_prices400 %>%
  left_join(., df_prices2_400, by = c("krs", "year")) %>%
  select(
    krs, year,
    apRent_chg, apRent_idx, apRent_n,
    apPurc_chg, apPurc_idx, apPurc_n,
    houPurc_chg, houPurc_idx, houPurc_n
  )

# Merge requested data
df <- df %>%
  left_join(., hazard_rate, by = c("krs", "year")) %>%
  left_join(., housing_vac, by = c("krs", "year")) %>%
  left_join(., neg_credscore, by = c("krs", "year")) %>%
  left_join(., new_res_area, by = c("krs", "year"))


# Keep only districts as of 2021 (krs400)
# Merge regional data
df <- df %>%
  filter(krs %in% krs400) %>%
  left_join(., df_reg, by = c("krs", "year"))


# Check length and structure of data set
stopifnot(length(unique(df$krs)) == 400)
stopifnot(length(unique(df$year)) == length(obs_years))



# Generate new variables --------------------------------------------------

# Calculate price index level in 2008 (_08) + price index with base year
# 2008 (_chg_idx)
df <- df %>%
  arrange(krs, year) %>%
  group_by(krs) %>%
  mutate(apRent_08 = apRent_idx[year == 2008], .after = apRent_idx) %>%
  mutate(apPurc_08 = apPurc_idx[year == 2008], .after = apPurc_idx) %>%
  mutate(houPurc_08 = houPurc_idx[year == 2008], .after = houPurc_idx) %>%
  mutate(apRent_chg_idx = (100 + apRent_chg), .before = apRent_chg) %>%
  mutate(apPurc_chg_idx = (100 + apPurc_chg), .before = apPurc_chg) %>%
  mutate(houPurc_chg_idx = (100 + houPurc_chg), .before = houPurc_chg) %>%
  ungroup()


## Write custom functions to calculate change compared to base year
## [= value in 2021 represents long difference used in the paper, i.e.
##    total change between 2008 and 2021]
fd_r <- function(x) ((x / x[1] - 1) * 100) # Change in percent
fd_a <- function(x) (x - x[1]) # Change in absolute values
fd_s <- function(x) (cumsum(x)) # Cumulated sum

vars_fd_r <- c(
  "gdp_pc", "tight", "pop_dens",
  "age", "lvng_area_pc", "land_prc",
  "house_inc", "resbuild_pc",
  "divorces", "hh_size", "guest_nights", "sb_lend"
)
vars_fd_a <- c(
  "vac_r", "unemp_r", "hiring_r", "comm_net",
  "students_pc", "mig", "permits_apts_pc", "smallapts_pc",
  "emp_wz_ind_pt", "bigapts_pc", "houses_pc", "new_apts_pc",
  "fem_pc", "ext_mig_pc", "dom_mig_pc", "new_hou_pc",
  "total_mig_pc", "debtor_ratio", "svb_hq_pt",
  "births_pc", "deaths_pc", "prop_tax_factor", "neg_credscore",
  "developable", "hazard_rate"
)
vars_sum <- c(
  "ext_mig_balance", "dom_mig_balance",
  "total_mig_balance"
)

# Run functions depending on variable groups defined above
df <- df %>%
  arrange(krs, year) %>%
  group_by(krs) %>%
  mutate(
    across(all_of(vars_fd_r),
      .fns = fd_r,
      .names = "{col}_chg08"
    ),
    across(all_of(vars_fd_a),
      .fns = fd_a,
      .names = "{col}_chg08"
    ),
    across(all_of(vars_sum),
      .fns = fd_s,
      .names = "{col}_sum08"
    )
  ) %>%
  rename(
    apRent_chg08 = apRent_chg,
    apPurc_chg08 = apPurc_chg,
    houPurc_chg08 = houPurc_chg
  )


## Adjust cumulated sums by initial population size in 2008
df <- df %>%
  mutate(
    dom_mig_balance_sum08 = 
      dom_mig_balance_sum08 / pop_total[year == 2008] * 100,
    ext_mig_balance_sum08 = 
      ext_mig_balance_sum08 / pop_total[year == 2008] * 100,
    total_mig_balance_sum08 = 
      total_mig_balance_sum08 / pop_total[year == 2008] * 100
  )


## Generate new category of district types: 0 = top 7 cities
## Berlin, Hamburg, Munich, Cologne, Frankfurt, Stuttgart, Düsseldorf
df <- df %>%
  mutate(
    krs_type = ifelse(krs %in% c(
      "11000", "02000", "09162",
      "05315", "06412", "08111",
      "05111"
    ), 0, krs_type),
    krs_type = as.factor(krs_type)
  )



# Export ------------------------------------------------------------------

saveRDS(df, "../data/panel_krs.RDS")
