## ---------------------------------------------
##
## Script name: 02_panel_amr
##
## Purpose of script: Build Panel Data Set at Level
##                    of Labor Market Regions (AMR)
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(openxlsx)
library(tidyverse)
library(zoo)

# Clear environment
rm(list = ls())

# Define observation period
obs_years <- c(2008:2021)



# Import ------------------------------------------------------------------

# Read Data on KRS Level
panel_data <- readRDS("../data/panel_krs.RDS")

# Read in KRS-AMR Key
amr_key <- read.xlsx("../data/keys/krs_amr_rwi_key.xlsx") %>%
  select(krs, amr)


## Price data on AMR Level. AMR defined according to the delineation of
## version 1 in RWI (2018).

# Abbreviations: apRent: Apartment Rents; apPurc: Apartment Purchase prices;
#                houPurc: House Purchase prices

# Regional price index on labour market district level**,
# 2008-2022 (regression 2)
apRent_idx <- read.xlsx("../data/RWIGEOREDX/RWIGEOREDX_ApRent_v9.xlsx",
  sheet = "6__AMR2_Pindex_yearly"
)
apPurc_idx <- read.xlsx("../data/RWIGEOREDX/RWIGEOREDX_ApPurc_v9.xlsx",
  sheet = "6__AMR2_Pindex_yearly"
)
houPurc_idx <- read.xlsx("../data/RWIGEOREDX/RWIGEOREDX_HouPurc_v9.xlsx",
  sheet = "6__AMR2_Pindex_yearly"
)

# Change of regional price indices on  labour market district level to 2008,
# 2008-2022 (regression 3)
apRent_chg <- read.xlsx("../data/RWIGEOREDX/RWIGEOREDX_ApRent_v9.xlsx",
  sheet = "7__AMR2_Change_yearly"
)
apPurc_chg <- read.xlsx("../data/RWIGEOREDX/RWIGEOREDX_ApPurc_v9.xlsx",
  sheet = "7__AMR2_Change_yearly"
)
houPurc_chg <- read.xlsx("../data/RWIGEOREDX/RWIGEOREDX_HouPurc_v9.xlsx",
  sheet = "7__AMR2_Change_yearly"
)



# Clean Price Data ----------------------------------------------------------

# Put all dfs into one list
l_prices <- list(
  apRent_idx, apPurc_idx, houPurc_idx,
  apRent_chg, apPurc_chg, houPurc_chg
)
prices_names <- c(
  "apRent_idx", "apPurc_idx", "houPurc_idx",
  "apRent_chg", "apPurc_chg", "houPurc_chg"
)
names(l_prices) <- prices_names

# Remove frequencies (freq2008, ...)
l_prices <- lapply(l_prices, function(x) {
  y <- x[, -c(2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 22, 24, 26, 28, 30, 32)]
  return(y)
})

# Set new colnames
colnames <- c("amr", 2008:2022)
l_prices <- lapply(l_prices, setNames, colnames)

# Bring into long format
l_prices_long <- lapply(l_prices, function(x) {
  y <- x %>%
    pivot_longer(cols = "2008":"2022", names_to = "year", values_to = "value")
  return(y)
})

l_prices_long <- lapply(seq_along(l_prices_long), function(x) {
  names(l_prices_long[[x]]) <- c("amr", "year", names(l_prices)[x])
  return(l_prices_long[[x]])
})

names(l_prices_long) <- prices_names

# Reduce to data frame
df_prices <- l_prices_long %>%
  reduce(full_join, by = c("amr", "year"))

# Bring IDs into correct format (5 char)
# Filter for observation period
df_prices <- df_prices %>%
  mutate(amr = formatC(amr, width = 5, format = "d", flag = "0")) %>%
  filter(year %in% obs_years) %>%
  select(
    amr, year,
    apRent_chg, apRent_idx,
    apPurc_chg, apPurc_idx,
    houPurc_chg, houPurc_idx,
  )



# Aggregation to AMR ------------------------------------------------------

## All data regional data (reg_data.xlsx) are only available on district
## level, so have to be aggregated to the AMR level.

# Merge AMR Key to regional data set
panel_data <- merge(panel_data, amr_key, by = c("krs"))

# Define columns that should be summed up
col_sum <- c(
  "area", "apts_total", "emp_wz_total", "labforce", "houses",
  "land_area", "pop_total", "resbuild_total", "svb", "unemp"
)

# Define columns that should be weighted by population
col_w_pop <- c(
  "debtor_ratio", "divorces", "dom_mig_pc",
  "ext_mig_pc", "gdp_pc", "house_inc", "lvng_area_pc",
  "mig", "new_apts_pc", "new_hou_pc", "permits_apts_pc", "age",
  "prop_tax_factor", "neg_credscore", "hh_size", "students_pc"
)

# Define columns that should be weighted by employees subject to social
# security contributions (=svb)
col_w_svb <- c("comm_net", "svb_hq_pt")

# Define columns that should be weighted by labor force
col_w_ep <- c("vac_r", "hiring_r", "unemp_r")

# Define columns that should be weighted by unemployed
col_w_unemp <- c("tight")

# Define columns that should be weighted by employed
col_w_emp <- c("emp_wz_ind_pt")

# Define columns that should be weighted by apartments
col_w_apts <- c("smallapts_pc", "bigapts_pc")

# Define columns that should be weighted by residential buildings
col_w_build <- c("houses_pc")

# Define columns that should be weighted by area
col_w_area <- c("pop_dens")

# Define columns that should be weighted by area of sold land
col_w_land <- c("land_prc")

# Define columns that should be defined as maximum
col_max <- c("rent_control")

# Sum
panel_amr_sum <- panel_data %>%
  group_by(amr, year) %>%
  summarise_at(col_sum, sum)

# Weight by pop
panel_amr_w_pop <- panel_data %>%
  group_by(amr, year) %>%
  summarise_at(col_w_pop, list(~ weighted.mean(., pop_total)))

# Weight by employees ssc
panel_amr_w_svb <- panel_data %>%
  group_by(amr, year) %>%
  summarise_at(col_w_svb, list(~ weighted.mean(., svb)))

# Weight by apartments
panel_amr_w_apts <- panel_data %>%
  group_by(amr, year) %>%
  summarise_at(col_w_apts, list(~ weighted.mean(., apts_total)))

# Weight by residential buildings
panel_amr_w_build <- panel_data %>%
  group_by(amr, year) %>%
  summarise_at(col_w_build, list(~ weighted.mean(., resbuild_total)))

# Weight by labor force
panel_amr_w_ep <- panel_data %>%
  group_by(amr, year) %>%
  summarise_at(col_w_ep, list(~ weighted.mean(., labforce)))

# Weight by unemployed
panel_amr_w_unemp <- panel_data %>%
  group_by(amr, year) %>%
  summarise_at(col_w_unemp, list(~ weighted.mean(., unemp)))

# Weight by employed
panel_amr_w_emp <- panel_data %>%
  group_by(amr, year) %>%
  summarise_at(col_w_emp, list(~ weighted.mean(., emp_wz_total)))

# Weight by area
panel_amr_w_area <- panel_data %>%
  group_by(amr, year) %>%
  summarise_at(col_w_area, list(~ weighted.mean(., area)))

# Weight by area
panel_amr_w_land <- panel_data %>%
  group_by(amr, year) %>%
  summarise_at(col_w_land, list(~ weighted.mean(., land_area)))

# Max
panel_amr_max <- panel_data %>%
  group_by(amr, year) %>%
  summarise_at(col_max, max)

# Match all together (incl. price data already on AMR level)
panel_amr <- panel_amr_sum %>%
  full_join(., panel_amr_w_pop, by = c("amr", "year")) %>%
  full_join(., panel_amr_w_svb, by = c("amr", "year")) %>%
  full_join(., panel_amr_w_apts, by = c("amr", "year")) %>%
  full_join(., panel_amr_w_build, by = c("amr", "year")) %>%
  full_join(., panel_amr_w_ep, by = c("amr", "year")) %>%
  full_join(., panel_amr_w_unemp, by = c("amr", "year")) %>%
  full_join(., panel_amr_w_emp, by = c("amr", "year")) %>%
  full_join(., panel_amr_w_area, by = c("amr", "year")) %>%
  full_join(., panel_amr_w_land, by = c("amr", "year")) %>%
  full_join(., panel_amr_max, by = c("amr", "year")) %>%
  left_join(., df_prices, by = c("amr", "year"))



# Generate new variables --------------------------------------------------

# Calculate price index with base year 2008 (_chg_idx)
panel_amr <- panel_amr %>%
  arrange(amr, year) %>%
  group_by(amr) %>%
  mutate(apRent_chg_idx = (100 + apRent_chg), .before = apRent_chg) %>%
  mutate(apPurc_chg_idx = (100 + apPurc_chg), .before = apPurc_chg) %>%
  mutate(houPurc_chg_idx = (100 + houPurc_chg), .before = houPurc_chg) %>%
  ungroup()


# Check length and structure of data set
stopifnot(length(unique(panel_amr$amr)) == 182)
stopifnot(length(unique(panel_amr$year)) == length(obs_years))

# Check for NAs
sapply(panel_amr, function(x) sum(is.na(x)))

# Check for 0s
sapply(panel_amr, function(x) sum(x == 0, na.rm = T))

# Check for negative values
sapply(panel_amr, function(x) sum(x < 0, na.rm = T))



# Export ------------------------------------------------------------------

saveRDS(panel_amr, "../data/panel_amr.RDS")
