## ---------------------------------------------
##
## Script name: 03_prep_greix
##
## Purpose of script: Prepare GREIX Index
##                    (Amaral et al. 2023)
##
## Paper: Regional Supply and Demand Fundamentals 
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(openxlsx)
library(tidyverse)

# Clear environment
rm(list = ls())



# Import ------------------------------------------------------------------

# Read in Individual Data GREIX Indices (by City Names) 
temp <- list.files(path = "../data/GREIX/download/", pattern = "*.xlsx")
temp_names <- gsub(".xlsx", "", temp)
data_list <- lapply(temp, function(x) 
  read.xlsx(paste0("../data/GREIX/download/", x),
            sheet = 1))
names(data_list) <- temp_names


# Read in district IDs of GREIX cities
krs_key <- read.xlsx("../data/keys/GREIX_IDs.xlsx")



# Preparation -------------------------------------------------------------

## Set column names:
# apts = apartments
# mfh = multi-family houses
# efh = single-family houses
colnames <- c("year", "GREIX_apts_idx", "GREIX_mfh_idx", "GREIX_efh_idx")
lst_greix <- lapply(data_list, setNames, colnames)

# Reduce to one data frame
df_greix <- bind_rows(lst_greix, .id = "greix_name")

# Extract observation period
period <- c(2008:2021)
df_greix <- df_greix %>%
  mutate(year = as.numeric(year)) %>%
  filter(year %in% period)

# Merge KRS Key and select relevant columns
df_greix <- df_greix %>%
  left_join(krs_key, by = "greix_name") %>%
  select(krs, year, GREIX_apts_idx, 
         GREIX_mfh_idx, GREIX_efh_idx)

# Change base year of indices to 2008 (as for the RWI-GEO-REDX)
# Not available for Munich ("09162") and Potsdam ("12054")
df_greix <- df_greix %>%
  group_by(krs) %>%
  mutate(GREIX_apts_idx = GREIX_apts_idx/GREIX_apts_idx[year==2008] * 100,
         GREIX_mfh_idx = ifelse(krs %in% c("09162", "12054"), NA, 
                                GREIX_mfh_idx/GREIX_mfh_idx[year==2008] * 100),
         GREIX_efh_idx = ifelse(krs == "09162", NA, 
                                GREIX_efh_idx/GREIX_efh_idx[year==2008] * 100)) %>%
  mutate(GREIX_apts_chg08 = GREIX_apts_idx - GREIX_apts_idx[year == 2008], 
         GREIX_mfh_chg08 = ifelse(krs %in% c("09162", "12054"), NA, 
                                   GREIX_mfh_idx - GREIX_mfh_idx[year == 2008]),
         GREIX_efh_chg08 =  ifelse(krs == "09162", NA, 
                                   GREIX_efh_idx - GREIX_efh_idx[year == 2008]))



# Export ------------------------------------------------------------------

write.xlsx(df_greix, "../data/GREIX/GREIX.xlsx")
