## ---------------------------------------------
##
## Script name: 04_prep_ahl
##
## Purpose of script: Prepare Ahlfeldt et al. 
##                    (2023) Index
##
## Paper: Regional Supply and Demand Fundamentals 
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(openxlsx)
library(tidyverse)

# Clear environment
rm(list = ls())



# Import ------------------------------------------------------------------

## Price data

# Rents
rent <- read.csv("../data/ahlfeldt_index/INDEX_AHL_IMMO_county_RENT.csv",
                 header = T)

# Purchases
purch <- read.csv("../data/ahlfeldt_index/INDEX_AHL_IMMO_county_PURCH.csv",
                  header = T)



# Clean Price Data ----------------------------------------------------------

# Put all dfs into one list
l_prices <- list(
  rent, purch
)
prices_names <- c(
  "ahl_rent", "ahl_purch"
)
names(l_prices) <- prices_names

# Extract prices per square meter
l_prices <- lapply(l_prices, function(x) {
  y <- x[, c(1, 2, 5, 8, 11, 14, 17, 20, 23, 26, 29, 32, 35, 38, 41, 44)]
  return(y)
})

# Set years as new column names
colnames <- c("krs", 2007:2021)
l_prices <- lapply(l_prices, setNames, colnames)

# Bring into long format
l_prices_long <- lapply(l_prices, function(x) {
  y <- x %>%
    pivot_longer(cols = "2007":"2021", names_to = "year", values_to = "value")
  return(y)
})

l_prices_long <- lapply(seq_along(l_prices_long), function(x) {
  names(l_prices_long[[x]]) <- c("krs", "year", names(l_prices)[x])
  return(l_prices_long[[x]])
})

names(l_prices_long) <- prices_names

# Reduce to data frame
# Bring IDs into correct format (5 char)
df_prices <- l_prices_long %>%
  reduce(full_join, by = c("krs", "year")) %>%
  mutate(krs = str_pad(krs, width = 5, side = "left", pad = "0"))


# Calculate price indices with base year 2008 (as for the RWI-GEO-REDX)
df_prices <- df_prices %>%
  group_by(krs) %>%
  mutate(across(c("ahl_rent", "ahl_purch"),
                .fns = ~ (. / .[year=="2008"] - 1) * 100,
                .names = "{col}_chg08")) %>%
  mutate(across(c("ahl_rent", "ahl_purch"),
                .fns = ~ ((. / .[year=="2008"] - 1) * 100) + 100,
                .names = "{col}_chg_idx"))



# Export ------------------------------------------------------------------

write.xlsx(df_prices, "../data/ahlfeldt_index/ahl.xlsx")
