## ---------------------------------------------
##
## Script name: figure-1.R
##
## Purpose of script: Generate Figure 1
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(tidyverse)

# Clear environment
rm(list = ls())

# Load customized plot theme
theme_pub <- function() {
  theme_bw() %+replace%
    theme(
      panel.grid.major.x = element_blank(),
      panel.grid.major.y = ggplot2::element_line(color = "gray95"),
      panel.grid.minor.y = element_blank(),
      panel.border = element_blank(),
      axis.line = element_line(colour = "grey40", size = 0.3),
      axis.text = element_text(size = 7),
      axis.title = element_text(size = 7),
      axis.ticks = element_line(colour = "grey40", size = 0.3),
      legend.text = element_text(size = 7),
      legend.background = element_rect(
        colour = "grey30",
        fill = "white",
        size = 0.2
      ),
      legend.key.height = unit(0.8, "line"),
      legend.key.width = unit(1, "line"),
      plot.title = element_text(
        size = 7,
        vjust = 2,
        hjust = 0,
        margin = margin(0.2, 0.2, 0.2, 0.2, "cm")
      )
    )
}



# Import ------------------------------------------------------------------

# Data
panel_krs <- readRDS("../data/panel_krs.RDS")



# FIGURE 1 ----------------------------------------------------------------

# Calculate quantiles: 10th, 25th, 50th, 75th, and 90th
quant <- panel_krs %>%
  group_by(year) %>%
  summarise(
    apRent_base = quantile(apRent_chg08,
      c(0.1, 0.25, 0.5, 0.75, 0.9),
      na.rm = T
    ),
    apPurc_base = quantile(apPurc_chg08,
      c(0.1, 0.25, 0.5, 0.75, 0.9),
      na.rm = T
    ),
    houPurc_base = quantile(houPurc_chg08,
      c(0.1, 0.25, 0.5, 0.75, 0.9),
      na.rm = T
    ),
    q = c(0.1, 0.25, 0.5, 0.75, 0.9)
  )

# Merge together, reshape and relevel to prepare for plotting
panel_krs_quant <- quant %>%
  mutate(
    q_legend = case_when(
      q == 0.1 ~ "10th perc.",
      q == 0.25 ~ "25th perc.",
      q == 0.5 ~ "Median",
      q == 0.75 ~ "75th perc.",
      q == 0.9 ~ "90th perc.",
      TRUE ~ as.character(q)
    ),
    q_legend = as.factor(q_legend),
    q_legend = fct_relevel(
      q_legend, "10th perc.", "25th perc.",
      "Median", "75th perc.", "90th perc."
    )
  ) %>%
  pivot_longer(., c(apRent_base, apPurc_base, houPurc_base),
    names_to = "outcome", values_to = "value"
  ) %>%
  mutate(
    outcome = fct_relevel(outcome, "apRent_base", 
                          "apPurc_base", "houPurc_base"),
    outcome = fct_recode(outcome,
      "Panel A. Apartment rents" = "apRent_base",
      "Panel B. Apartment purchase prices" = "apPurc_base",
      "Panel C. House purchase prices" = "houPurc_base"
    )
  )

# Make Plot
p_quant <- panel_krs_quant %>%
  ggplot(
    aes(
      x = year, y = value, group = q_legend,
      colour = q_legend, shape = q_legend
    )
  ) +
  theme_pub() +
  facet_wrap(~outcome, scales = "free") +
  geom_line(size = 0.4) +
  geom_point(size = 1.1) +
  labs(
    x = NULL,
    y = "Change relative to 2008 [%]",
    title = NULL
  ) +
  scale_y_continuous(
    limits = c(-20, 200), expand = c(0.01, 0)
  ) +
  scale_x_discrete(
    expand = c(0, 0.5),
    labels = c(
      "2008", "", "2010", "", "2012", "", "2014", "",
      "2016", "", "2018", "", "2020", ""
    )
  ) +
  scale_color_brewer(palette = "Set2") +
  theme(
    legend.title = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    panel.grid.minor.x = element_blank(),
    axis.line.y = element_blank(),
    axis.ticks.y = element_blank(),
    legend.position = "bottom",
    strip.background = element_blank()
  )

# Export
ggsave("../figures/figure-1.png",
  width = 16, height = 6.5, units = "cm", dpi = 300
)


### Fact stated on page 9: "By 2021, rental prices increased by
# 34 percent at the median, while apartment and house purchase prices
# rose by 77 percent and 36 percent respectively [...]"
panel_krs_quant %>%
  filter(
    outcome == "Panel A. Apartment rents",
    q == 0.5,
    year == 2021
  )
panel_krs_quant %>%
  filter(
    outcome == "Panel B. Apartment purchase prices",
    q == 0.5,
    year == 2021
  )
panel_krs_quant %>%
  filter(
    outcome == "Panel C. House purchase prices",
    q == 0.5,
    year == 2021
  )
