## ---------------------------------------------
##
## Script name: figure-2.R
##
## Purpose of script: Generate Figure 2
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(openxlsx)
library(tidyverse)
library(ggpubr)
library(grid)

# Clear environment
rm(list = ls())

# Load customised plot theme
theme_pub <- function() {
  theme_bw() %+replace%
    theme(
      panel.grid.major.x = element_blank(),
      panel.grid.major.y = ggplot2::element_line(color = "gray95"),
      panel.grid.minor.y = element_blank(),
      panel.border = element_blank(),
      axis.line = element_line(colour = "grey40", size = 0.3),
      axis.text = element_text(size = 7),
      axis.title = element_text(size = 7),
      axis.ticks = element_line(colour = "grey40", size = 0.3),
      legend.text = element_text(size = 7),
      legend.background = element_rect(
        colour = "grey30",
        fill = "white",
        size = 0.2
      ),
      legend.key.height = unit(0.8, "line"),
      legend.key.width = unit(1, "line"),
      plot.title = element_text(
        size = 7,
        vjust = 2,
        hjust = 0,
        margin = margin(0.2, 0.2, 0.2, 0.2, "cm")
      )
    )
}

# Function for additional lines for axis labels
addline_format <- function(x, ...) {
  gsub("\\s", "\n", x)
}



# Import ------------------------------------------------------------------

# Data
panel_krs <- readRDS("../data/panel_krs.RDS")

# AMR Key
amr_key <- read.xlsx("../data/keys/krs_amr_rwi_key.xlsx") %>%
  select(krs, amr)



# FIGURE 2 -----------------------------------------------------------------

# Calculate PTR gap: Difference between change in apartment purchase and
#                    rental prices
# Calculate PTI gap: Difference between change in housing prices and income
# Make 2021 subset (end year of observation period)
# Relevel krs type for ascending order in figure
panel_krs_21 <- panel_krs %>%
  filter(year == 2021) %>%
  mutate(
    apRent_pti = apRent_chg08 - house_inc_chg08,
    apPurc_pti = apPurc_chg08 - house_inc_chg08,
    houPurc_pti = houPurc_chg08 - house_inc_chg08,
    ptr = apPurc_chg08 - apRent_chg08,
    krs_type = fct_relevel(krs_type, "0", "1", "2", "3", "4")
  )

# Subset Panel A
df_types <- panel_krs_21 %>%
  pivot_longer(., c(apRent_chg08, apPurc_chg08, houPurc_chg08),
    names_to = "outcome", values_to = "value"
  ) %>%
  mutate(
    outcome = fct_relevel(
      outcome, "apRent_chg08", "apPurc_chg08", "houPurc_chg08"
    ),
    outcome = fct_recode(outcome,
      "Apartment rents" = "apRent_chg08",
      "Apartment purchase prices" = "apPurc_chg08",
      "House purchase prices" = "houPurc_chg08"
    )
  )

# Subset Panel B
df_types2 <- panel_krs_21 %>%
  pivot_longer(., c(apRent_pti, apPurc_pti, houPurc_pti),
    names_to = "outcome", values_to = "value"
  ) %>%
  mutate(
    outcome = fct_relevel(
      outcome, "apRent_pti", "apPurc_pti", "houPurc_pti"
    ),
    outcome = fct_recode(outcome,
      "Apartment rents" = "apRent_pti",
      "Apartment purchase prices" = "apPurc_pti",
      "House purchase prices" = "houPurc_pti"
    )
  )

# Subset Panel C
df_types3 <- panel_krs_21 %>%
  pivot_longer(., c(ptr),
    names_to = "outcome", values_to = "value"
  )



# Plots -------------------------------------------------------------------

# Define comparison groups for significance tests
my_comparisons <- list(c("0", "1"), c("1", "2"), c("2", "3"), c("3", "4"))

# Define significance levels shown in plot
symnum.args <- list(
  cutpoints = c(0, 0.05, 1), symbols = c("*", "ns")
)

## Panel A. Price Growth
p1 <- df_types %>%
  ggplot(., aes(
    x = fct_rev(krs_type), y = value,
    fill = fct_rev(krs_type), colour = fct_rev(krs_type)
  )) +
  geom_hline(
    yintercept = 0, size = 0.3, colour = "grey30", linetype = 2
  ) +
  geom_jitter(
    pch = 21, color = "white", size = 1, alpha = 0.6,
    position = position_jitter(seed = 1)
  ) +
  stat_summary(
    fun = mean, fun.min = mean, fun.max = mean,
    geom = "crossbar", size = 0.3
  ) +
  stat_compare_means(
    label = "p.signif", comparisons = my_comparisons,
    ref.group = ".all.", size = 2, symnum.args = symnum.args,
    label.y = c(340, 355, 370, 385), tip.length = 0.01
  ) +
  facet_wrap(~outcome, scales = "free") +
  theme_pub() +
  scale_color_brewer(palette = "Set2") +
  scale_fill_brewer(palette = "Set2") +
  labs(
    x = NULL,
    y = "Change 2008-21 [%]",
    title = "Panel A. Price growth"
  ) +
  scale_x_discrete(
    labels = addline_format(c(
      "Spars. populated", "Rural", "Urban", "Large urban", "Top 7"
    ))
  ) +
  theme(
    legend.position = "none",
    panel.grid.major.y = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    strip.background = element_blank()
  )

## Panel B. PTI Gap
p2 <- df_types2 %>%
  ggplot(., aes(
    x = fct_rev(krs_type), y = value,
    fill = fct_rev(krs_type), colour = fct_rev(krs_type)
  )) +
  geom_hline(
    yintercept = 0, size = 0.3, colour = "grey30", linetype = 2
  ) +
  geom_jitter(
    pch = 21, color = "white", size = 1, alpha = 0.6,
    position = position_jitter(seed = 1)
  ) +
  stat_summary(
    fun = mean, fun.min = mean, fun.max = mean,
    geom = "crossbar", size = 0.3
  ) +
  stat_compare_means(
    label = "p.signif", comparisons = my_comparisons,
    ref.group = ".all.", size = 2, symnum.args = symnum.args,
    label.y = c(335, 350, 365, 380), tip.length = 0.01
  ) +
  facet_wrap(~outcome, scales = "free") +
  theme_pub() +
  scale_color_brewer(palette = "Set2") +
  scale_fill_brewer(palette = "Set2") +
  labs(
    x = NULL,
    y = "Gap 2008-21 [pp]",
    title = "Panel B. Price-to-income gap"
  ) +
  scale_y_continuous(
    labels = scales::number_format(accuracy = 1)
  ) +
  scale_x_discrete(
    labels = addline_format(c(
      "Spars. populated", "Rural", "Urban", "Large urban", "Top 7"
    ))
  ) +
  theme(
    legend.position = "none",
    panel.grid.major.y = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    strip.background = element_blank()
  )

## Panel C. PTR Gap
p3a <- df_types3 %>%
  ggplot(., aes(
    x = fct_rev(krs_type), y = value,
    fill = fct_rev(krs_type), colour = fct_rev(krs_type)
  )) +
  geom_hline(
    yintercept = 0, size = 0.3, colour = "grey30", linetype = 2
  ) +
  geom_jitter(
    pch = 21, color = "white", size = 1, alpha = 0.6,
    position = position_jitter(seed = 1)
  ) +
  stat_summary(
    fun = mean, fun.min = mean, fun.max = mean,
    geom = "crossbar", size = 0.3
  ) +
  stat_compare_means(
    label = "p.signif", comparisons = my_comparisons,
    ref.group = ".all.", size = 2, symnum.args = symnum.args,
    label.y = c(350, 365, 380, 395), tip.length = 0.01
  ) +
  theme_pub() +
  scale_color_brewer(palette = "Set2") +
  scale_fill_brewer(palette = "Set2") +
  labs(
    x = NULL,
    y = "Gap 2008-21 [pp]",
    title = "Panel C. Price-to-rent gap"
  ) +
  scale_y_continuous(
    labels = scales::number_format(accuracy = 1)
  ) +
  scale_x_discrete(
    labels = addline_format(c(
      "Spars. populated", "Rural", "Urban", "Large urban", "Top 7"
    ))
  ) +
  theme(
    legend.position = "none",
    panel.grid.major.y = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    strip.background = element_blank()
  )

# Fill up with blank panels
blank <- grid.rect(gp = gpar(col = "white"))
p3 <- ggarrange(p3a, blank, blank,
  nrow = 1, ncol = 3, widths = c(1.2, 1, 1)
)

# Put all plots together and export
p13 <- ggarrange(p1, p2, p3,
  nrow = 3, ncol = 1, heights = c(1, 1, 0.9)
)
ggsave("../figures/figure-2.png",
  width = 16, height = 16, unit = "cm", dpi = 300
)



### Fact stated on page 10: "The latter [Note: top7] have
# significantly higher price growth rates than all other
# districts, with approximately 36 (apartment rents), 121
# (apartment purchase prices) and 169 (house purchase prices)
# percentage points higher growth rates than the average."

# Calculate means per district type
types_21 <- panel_krs %>%
  group_by(year, krs_type) %>%
  summarise_at(vars(apRent_chg08, apPurc_chg08, houPurc_chg08),
    mean, na.rm = T
  ) %>%
  filter(year == 2021) %>%
  ungroup() %>%
  mutate(krs_type = as.character(krs_type))

av_21 <- panel_krs %>%
  group_by(year) %>%
  summarise_at(vars(apRent_chg08, apPurc_chg08, houPurc_chg08),
    mean, na.rm = T
  ) %>%
  filter(year == 2021) %>%
  mutate(krs_type = "mean")

types <- types_21 %>%
  bind_rows(av_21)

# Apartment rents
types$apRent_chg08[types$krs_type == "0"] -
  types$apRent_chg08[types$krs_type == "mean"]

# Apartment purchase prices
types$apPurc_chg08[types$krs_type == "0"] -
  types$apPurc_chg08[types$krs_type == "mean"]

# House purchase prices
types$houPurc_chg08[types$krs_type == "0"] -
  types$houPurc_chg08[types$krs_type == "mean"]


### Fact stated on page 10: "For instance, the seven out of
# the ten districts with the highest housing price growth
# are all located in the greater area of Munich but are grouped into
# two different district types."

sub <- panel_krs %>%
  left_join(., amr_key, by = "krs") %>%
  select(krs, year, houPurc_chg08, krs_type, amr) %>%
  filter(year == 2021) %>%
  arrange(-houPurc_chg08)
sub[1:10, ]



### Fact stated on page 10: "In most districts (54%), apartment rents
#   increased less than household income per capita, making
#   renting more affordable there."
pti <- panel_krs %>%
  mutate(
    apRent_pti = apRent_chg08 - house_inc_chg08,
    apPurc_pti = apPurc_chg08 - house_inc_chg08,
    houPurc_pti = houPurc_chg08 - house_inc_chg08
  ) %>%
  filter(year == 2021)

1 - sum(pti$apRent_pti < 0, na.rm = T) / sum(!is.na(pti$apRent_pti))


### Fact stated on page 10: "However, this does not apply for cities
#   with more than 100,000 inhabitants (“large urban”
#   and “Top7”), where rents rose by an average of 11 respectively
#   43 percentage points more than household income."

pti_krs_type <- pti %>%
  group_by(krs_type) %>%
  summarise_at(vars(apRent_pti, apPurc_pti, houPurc_pti),
    mean, na.rm = T
  )
pti_krs_type[pti_krs_type$krs_type == 1, 2]
pti_krs_type[pti_krs_type$krs_type == 0, 2]


### Fact stated on page 10: "By contrast, purchase prices increased
#   more than the average purchasing power of the population in around
#   83 to 88 percent of all districts, exacerbating the unaffordability of
#   homeownership across the board."

sum(pti$apPurc_pti > 0, na.rm = T) / sum(!is.na(pti$apPurc_pti))
sum(pti$houPurc_pti > 0, na.rm = T) / sum(!is.na(pti$houPurc_pti))


### Fact stated on page 14: "Purchases became particularly costly
#   in large urban districts (+63pp apartments; +111pp houses) and
#   in the Top7 (+175pp apartments; +244pp houses), but affordability
#   also declined in less densely populated rural areas. "

pti_krs_type[pti_krs_type$krs_type == 1, c(3, 4)]
pti_krs_type[pti_krs_type$krs_type == 0, c(3, 4)]
pti_krs_type[pti_krs_type$krs_type == 2, c(3, 4)]
pti_krs_type[pti_krs_type$krs_type == 3, c(3, 4)]
pti_krs_type[pti_krs_type$krs_type == 4, c(3, 4)]



### Fact stated on page 10f.: "In most districts (90%), apartment purchase
# prices rose more strongly than apartment rents."
ptr <- panel_krs %>%
  mutate(ptr = apPurc_chg08 - apRent_chg08) %>%
  filter(year == 2021)

sum(ptr$ptr > 0, na.rm = T) / sum(!is.na(ptr$ptr))


### And Fact stated on page 11: "The price-to-rent gap averaged 46 percentage points,
#   and was again particularly large in the seven largest cities (+132pp)."

mean(ptr$ptr, na.rm = T)

ptr_krs_type <- ptr %>%
  group_by(krs_type) %>%
  summarise_at(vars(ptr), mean, na.rm = T)
ptr_krs_type[ptr_krs_type$krs_type == 0, 2]
