## ---------------------------------------------
##
## Script name: figure-3.R
##
## Purpose of script: Generate Figure 3 and Results
##                    for Appendix Table B-2
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

library(openxlsx)
library(tidyverse)
library(stargazer)
library(ggpubr)
library(ggtext)

rm(list = ls()) # Clear environment

# Load customized plot theme
theme_pub <- function() {
  theme_bw() %+replace%
    theme(
      panel.grid.major.x = element_blank(),
      panel.grid.major.y = ggplot2::element_line(color = "gray95"),
      panel.grid.minor.y = element_blank(),
      panel.border = element_blank(),
      axis.line = element_line(colour = "grey30", size = 0.3),
      axis.text = element_text(size = 7),
      axis.title = element_text(size = 7),
      axis.ticks = element_line(colour = "grey30", size = 0.3),
      legend.text = element_text(size = 7),
      legend.background = element_rect(
        colour = "grey30",
        fill = "white",
        size = 0.2
      ),
      legend.key.height = unit(0.8, "line"),
      legend.key.width = unit(1, "line"),
      plot.title = element_text(
        size = 6,
        vjust = 2,
        hjust = 0,
        margin = margin(0.2, 0.2, 0.2, 0.2, "cm")
      )
    )
}



# Import ------------------------------------------------------------------

# Data
panel_krs <- readRDS("../data/panel_krs.RDS")



# Run bivariate correlations ----------------------------------------------

## Preparation

# Create subset for 2021 (end year of long difference)
panel_krs_21 <- panel_krs %>%
  filter(year == 2021)

# Define variables and labels
dep_vars <- c(
  "apRent_chg08", "apPurc_chg08", "houPurc_chg08"
)
vars <- c(
  "resbuild_pc_chg08", "lvng_area_pc_chg08", "smallapts_pc_chg08", 
  "houses_pc_chg08",
  "land_prc_chg08", "new_apts_pc_chg08", "developable_chg08",
  "permits_apts_pc_chg08", "new_hou_pc_chg08",
  "svb_hq_pt_chg08", "tight_chg08", "unemp_r_chg08", "vac_r_chg08", 
  "emp_wz_ind_pt_chg08", "hiring_r_chg08",
  "house_inc_chg08", "gdp_pc_chg08", "guest_nights_chg08",
  "age_chg08", "mig_chg08", "fem_pc_chg08", "students_pc_chg08", 
  "divorces_chg08", "hh_size_chg08",
  "pop_dens_chg08", "dom_mig_pc_chg08", "comm_net_chg08",
  "ext_mig_pc_chg08",
  "neg_credscore_chg08", "debtor_ratio_chg08", "hazard_rate_chg08", 
  "sb_lend_chg08"
)
y_names <- c(
  "apRent", "apPurc", "houPurc"
)
x_names <- c(
  "Residential buildings pc", "Living area pc", "Share of small apartments", 
  "Share of family houses",
  "Land prices", "Completed apartments pc", "Share of developable land", 
  "Building permits pc", "Completed houses pc",
  "Share of academics", "Labor market tightness", "Unemployment rate", 
  "Vacancy rate", "Emp. share in manufacturing", "Hiring rate",
  "Household income pc", "GDP pc", "Overnight stays",
  "Average population age", "Migrant share", "Female share", "Student ratio", 
  "Divorce rate", "Average household size",
  "Population density", "Domestic migration balance", "Commuter balance", 
  "External migration balance",
  "Share of subprime", "Private debtor rate", "Hazard rate", 
  "Mortgage lending"
)

# Standardize all variables to mean 0 and sd 1
panel_krs_21_sd <- panel_krs_21
panel_krs_21_sd[, c(dep_vars, vars)] <- scale(panel_krs_21_sd[, c(dep_vars, vars)])



### Run bivariate regressions by looping over all dep_vars and vars

## Extract and store coefficients
l_biv_coef <- list()
l_biv_coef <- lapply(dep_vars, function(y) {
  lapply(vars, function(x) {
    mod <- lm(get(y) ~ get(x), panel_krs_21_sd)
    l_biv_coef[[y]]$x <- mod$coefficients[2]
  })
})
names(l_biv_coef) <- y_names
l_biv_coef <- lapply(l_biv_coef, setNames, x_names)
biv_coef <- bind_rows(l_biv_coef, .id = "column_label")

biv_coef_long <- biv_coef %>%
  rename(y_var = column_label) %>%
  pivot_longer(!y_var, names_to = "x_var", values_to = "coef") %>%
  mutate(model = "bivariate")


## Extract and store SEs
l_biv_se <- list()
l_biv_se <- lapply(dep_vars, function(y) {
  lapply(vars, function(x) {
    mod <- summary(lm(get(y) ~ get(x), panel_krs_21_sd))
    l_biv_se[[y]]$x <- mod$coefficients[2, 2]
  })
})
names(l_biv_se) <- y_names
l_biv_se <- lapply(l_biv_se, setNames, x_names)
biv_se <- bind_rows(l_biv_se, .id = "column_label")

biv_se_long <- biv_se %>%
  rename(y_var = column_label) %>%
  pivot_longer(!y_var, names_to = "x_var", values_to = "se") %>%
  mutate(model = "bivariate")


# Merge Coefs and SEs
reg_biv <- merge(biv_coef_long, biv_se_long,
  by = c("y_var", "x_var", "model")
)

# Calculate 95% confidence bands
reg_biv$up <- reg_biv$coef + (reg_biv$se * 1.96)
reg_biv$down <- reg_biv$coef - (reg_biv$se * 1.96)



# Run multivariate blockwise correlations ---------------------------------

### Run regressions

## Define dependent variables
dep1 <- dep_vars[1]
dep2 <- dep_vars[2]
dep3 <- dep_vars[3]

## 1) Existing supply
hou <- c("lvng_area_pc_chg08 + smallapts_pc_chg08 + houses_pc_chg08")
lm_d1_hou <- lm(paste0(dep1, " ~", hou), panel_krs_21_sd)
lm_d2_hou <- lm(paste0(dep2, " ~", hou), panel_krs_21_sd)
lm_d3_hou <- lm(paste0(dep3, " ~", hou), panel_krs_21_sd)

## 2) New supply
build <- c("new_apts_pc_chg08 + land_prc_chg08 + new_hou_pc_chg08 + permits_apts_pc_chg08 + developable_chg08")
lm_d1_build <- lm(paste0(dep1, " ~", build), panel_krs_21_sd)
lm_d2_build <- lm(paste0(dep2, " ~", build), panel_krs_21_sd)
lm_d3_build <- lm(paste0(dep3, " ~", build), panel_krs_21_sd)

## 3) Labor market factors
lab <- c("svb_hq_pt_chg08 + tight_chg08 + emp_wz_ind_pt_chg08 + hiring_r_chg08 + vac_r_chg08")
lm_d1_lab <- lm(paste0(dep1, " ~", lab), panel_krs_21_sd)
lm_d2_lab <- lm(paste0(dep2, " ~", lab), panel_krs_21_sd)
lm_d3_lab <- lm(paste0(dep3, " ~", lab), panel_krs_21_sd)

## 4) Income & amenities
econ <- c("house_inc_chg08 + gdp_pc_chg08 + guest_nights_chg08")
lm_d1_econ <- lm(paste0(dep1, " ~", econ), panel_krs_21_sd)
lm_d2_econ <- lm(paste0(dep2, " ~", econ), panel_krs_21_sd)
lm_d3_econ <- lm(paste0(dep3, " ~", econ), panel_krs_21_sd)

## 5) Sociodemographics
soc <- c("age_chg08 + hh_size_chg08 + mig_chg08 +
          students_pc_chg08 + fem_pc_chg08 + divorces_chg08")
lm_d1_soc <- lm(paste0(dep1, " ~", soc), panel_krs_21_sd)
lm_d2_soc <- lm(paste0(dep2, " ~", soc), panel_krs_21_sd)
lm_d3_soc <- lm(paste0(dep3, " ~", soc), panel_krs_21_sd)

## 6) Population and mobility
mig <- c("pop_dens_chg08 + dom_mig_pc_chg08 + comm_net_chg08 + ext_mig_pc_chg08")
lm_d1_mig <- lm(paste0(dep1, " ~", mig), panel_krs_21_sd)
lm_d2_mig <- lm(paste0(dep2, " ~", mig), panel_krs_21_sd)
lm_d3_mig <- lm(paste0(dep3, " ~", mig), panel_krs_21_sd)

## 7) Financ. market
fin <- c("neg_credscore_chg08 + debtor_ratio_chg08 + hazard_rate_chg08 + sb_lend_chg08")
lm_d1_fin <- lm(paste0(dep1, " ~", fin), panel_krs_21_sd)
lm_d2_fin <- lm(paste0(dep2, " ~", fin), panel_krs_21_sd)
lm_d3_fin <- lm(paste0(dep3, " ~", fin), panel_krs_21_sd)

## Extract and store coefficients
lm_d1_hou_cof <- lm_d1_hou$coefficients[-1]
lm_d2_hou_cof <- lm_d2_hou$coefficients[-1]
lm_d3_hou_cof <- lm_d3_hou$coefficients[-1]

lm_d1_block <- c(
  lm_d1_hou_cof, lm_d1_build$coefficients[-1],
  lm_d1_lab$coefficients[-1], lm_d1_econ$coefficients[-1],
  lm_d1_soc$coefficients[-1], lm_d1_mig$coefficients[-1],
  lm_d1_fin$coefficients[-1]
)
lm_d2_block <- c(
  lm_d2_hou_cof, lm_d2_build$coefficients[-1],
  lm_d2_lab$coefficients[-1], lm_d2_econ$coefficients[-1],
  lm_d2_soc$coefficients[-1], lm_d2_mig$coefficients[-1],
  lm_d2_fin$coefficients[-1]
)
lm_d3_block <- c(
  lm_d3_hou_cof, lm_d3_build$coefficients[-1],
  lm_d3_lab$coefficients[-1], lm_d3_econ$coefficients[-1],
  lm_d3_soc$coefficients[-1], lm_d3_mig$coefficients[-1],
  lm_d3_fin$coefficients[-1]
)

l_lm_block <- list()
l_lm_block[["apRent"]] <- lm_d1_block
l_lm_block[["apPurc"]] <- lm_d2_block
l_lm_block[["houPurc"]] <- lm_d3_block

block_names <- c(
  "Living area pc", "Share of small apartments", "Share of family houses",
  "Completed apartments pc", "Land prices", "Completed houses pc", "Building permits pc",
  "Share of developable land",
  "Share of academics", "Labor market tightness", "Emp. share in manufacturing", 
  "Hiring rate", "Vacancy rate",
  "Household income pc", "GDP pc", "Overnight stays",
  "Average population age", "Average household size", "Migrant share",
  "Student ratio", "Female share", "Divorce rate",
  "Population density", "Domestic migration balance", "Commuter balance", 
  "External migration balance",
  "Share of subprime", "Private debtor rate", "Hazard rate", "Mortgage lending"
)

l_lm_block <- lapply(l_lm_block, setNames, block_names)
lm_block <- bind_rows(l_lm_block, .id = "column_label")

lm_block_long <- lm_block %>%
  rename(y_var = column_label) %>%
  pivot_longer(!y_var, names_to = "x_var", values_to = "coef") %>%
  mutate(model = "multivariate blockwise")


## Extract and store SEs
lm_d1_hou_se <- summary(lm_d1_hou)$coefficients[-1, 2]
lm_d2_hou_se <- summary(lm_d2_hou)$coefficients[-1, 2]
lm_d3_hou_se <- summary(lm_d3_hou)$coefficients[-1, 2]

lm_d1_block_se <- c(
  lm_d1_hou_se, summary(lm_d1_build)$coefficients[-1, 2],
  summary(lm_d1_lab)$coefficients[-1, 2],
  summary(lm_d1_econ)$coefficients[-1, 2],
  summary(lm_d1_soc)$coefficients[-1, 2],
  summary(lm_d1_mig)$coefficients[-1, 2],
  summary(lm_d1_fin)$coefficients[-1, 2]
)
lm_d2_block_se <- c(
  lm_d2_hou_se, summary(lm_d2_build)$coefficients[-1, 2],
  summary(lm_d2_lab)$coefficients[-1, 2],
  summary(lm_d2_econ)$coefficients[-1, 2],
  summary(lm_d2_soc)$coefficients[-1, 2],
  summary(lm_d2_mig)$coefficients[-1, 2],
  summary(lm_d2_fin)$coefficients[-1, 2]
)
lm_d3_block_se <- c(
  lm_d3_hou_se, summary(lm_d3_build)$coefficients[-1, 2],
  summary(lm_d3_lab)$coefficients[-1, 2],
  summary(lm_d3_econ)$coefficients[-1, 2],
  summary(lm_d3_soc)$coefficients[-1, 2],
  summary(lm_d3_mig)$coefficients[-1, 2],
  summary(lm_d3_fin)$coefficients[-1, 2]
)

l_lm_block_se <- list()
l_lm_block_se[["apRent"]] <- lm_d1_block_se
l_lm_block_se[["apPurc"]] <- lm_d2_block_se
l_lm_block_se[["houPurc"]] <- lm_d2_block_se

l_lm_block_se <- lapply(l_lm_block_se, setNames, block_names)
lm_block_se <- bind_rows(l_lm_block_se, .id = "column_label")

lm_block_se_long <- lm_block_se %>%
  rename(y_var = column_label) %>%
  pivot_longer(!y_var, names_to = "x_var", values_to = "se") %>%
  mutate(model = "multivariate blockwise")


## Merge Coefs and SEs
reg_block <- merge(lm_block_long, lm_block_se_long,
  by = c("y_var", "x_var", "model")
)


# Calculate 95% confidence bands
reg_block$up <- reg_block$coef + (reg_block$se * 1.96)
reg_block$down <- reg_block$coef - (reg_block$se * 1.96)


## Extract and store adj. R2
group_names <- c(
  "Income & amenities", "Labor market factors",
  "Sociodem. factors", "Population & mobility",
  "Existing supply", "New supply", "Financ. market"
)

lm_d1_econ_r2 <- summary(lm_d1_econ)$adj.r.squared
lm_d2_econ_r2 <- summary(lm_d2_econ)$adj.r.squared
lm_d3_econ_r2 <- summary(lm_d3_econ)$adj.r.squared

lm_d1_block_r2 <- c(
  lm_d1_econ_r2, summary(lm_d1_lab)$adj.r.squared,
  summary(lm_d1_soc)$adj.r.squared,
  summary(lm_d1_mig)$adj.r.squared,
  summary(lm_d1_hou)$adj.r.squared,
  summary(lm_d1_build)$adj.r.squared,
  summary(lm_d1_fin)$adj.r.squared
)
lm_d2_block_r2 <- c(
  lm_d2_econ_r2, summary(lm_d2_lab)$adj.r.squared,
  summary(lm_d2_soc)$adj.r.squared,
  summary(lm_d2_mig)$adj.r.squared,
  summary(lm_d2_hou)$adj.r.squared,
  summary(lm_d2_build)$adj.r.squared,
  summary(lm_d2_fin)$adj.r.squared
)
lm_d3_block_r2 <- c(
  lm_d3_econ_r2, summary(lm_d3_lab)$adj.r.squared,
  summary(lm_d3_soc)$adj.r.squared,
  summary(lm_d3_mig)$adj.r.squared,
  summary(lm_d3_hou)$adj.r.squared,
  summary(lm_d3_build)$adj.r.squared,
  summary(lm_d3_fin)$adj.r.squared
)

l_lm_block_r2 <- list()
l_lm_block_r2[["apRent"]] <- lm_d1_block_r2
l_lm_block_r2[["apPurc"]] <- lm_d2_block_r2
l_lm_block_r2[["houPurc"]] <- lm_d3_block_r2

l_lm_block_r2 <- lapply(l_lm_block_r2, setNames, group_names)
lm_block_r2 <- bind_rows(l_lm_block_r2, .id = "column_label")

lm_block_r2_long <- lm_block_r2 %>%
  rename(y_var = column_label) %>%
  pivot_longer(!y_var, names_to = "group", values_to = "adr2")


## Export block-wise regression results (Appendix Table A-4)
stargazer(lm_d1_hou, lm_d2_hou, lm_d3_hou,
  type = "html",
  dep.var.labels = c(
    "Apartment rents", "Apartment purchase prices", "House purchase prices"
  ),
  covariate.labels = c(
    "Living area pc", "Share of small apartments", "Share of family houses"
  ),
  omit = c("Constant"), omit.stat = c("ser", "f"),
  no.space = T,
  out = paste0("../tables/table-b2_a.html")
)

stargazer(lm_d1_build, lm_d2_build, lm_d3_build,
  type = "html",
  dep.var.labels = c(
    "Apartment rents", "Apartment purchase prices", "House purchase prices"
  ),
  covariate.labels = c(
    "Completed apartments pc", "Land prices", "Completed houses pc",
    "Building permits pc", "Share developable land"
  ),
  omit = c("Constant"), omit.stat = c("ser", "f"),
  no.space = T,
  out = paste0("../tables/table-b2_b.html")
)

stargazer(lm_d1_lab, lm_d2_lab, lm_d3_lab,
  type = "html",
  dep.var.labels = c(
    "Apartment rents", "Apartment purchase prices", "House purchase prices"
  ),
  covariate.labels = c(
    "Share of academics", "Labor market tightness",
    "Emp. share in manufacturing", "Hiring rate", "Vacancy rate"
  ),
  omit = c("Constant"), omit.stat = c("ser", "f"),
  no.space = T,
  out = paste0("../tables/table-b2_c.html")
)

stargazer(lm_d1_econ, lm_d2_econ, lm_d3_econ,
  type = "html",
  dep.var.labels = c(
    "Apartment rents", "Apartment purchase prices", "House purchase prices"
  ),
  covariate.labels = c("Household income pc", "GDP pc", "Overnight stays"),
  omit = c("Constant"), omit.stat = c("ser", "f"),
  no.space = T,
  out = paste0("../tables/table-b2_d.html")
)

stargazer(lm_d1_soc, lm_d2_soc, lm_d3_soc,
  type = "html",
  dep.var.labels = c(
    "Apartment rents", "Apartment purchase prices", "House purchase prices"
  ),
  covariate.labels = c(
    "Average population age", "Average household size", "Migrant share", 
    "Student ratio", "Female share", "Divorce rate"
  ),
  omit = c("Constant"), omit.stat = c("ser", "f"),
  no.space = T,
  out = paste0("../tables/table-b2_e.html")
)

stargazer(lm_d1_mig, lm_d2_mig, lm_d3_mig,
  type = "html",
  dep.var.labels = c(
    "Apartment rents", "Apartment purchase prices", "House purchase prices"
  ),
  covariate.labels = c(
    "Population density", "Dom. migration balance", "Commuter balance", 
    "Ext. migration balance"
  ),
  omit = c("Constant"), omit.stat = c("ser", "f"),
  no.space = T,
  out = paste0("../tables/table-b2_f.html")
)

stargazer(lm_d1_fin, lm_d2_fin, lm_d3_fin,
  type = "html",
  dep.var.labels = c(
    "Apartment rents", "Apartment purchase prices", "House purchase prices"
  ),
  covariate.labels = c(
    "Share of subprime", "Hazard rate", "Private debtor rate", 
    "Mortgage lending"
  ),
  omit = c("Constant"), omit.stat = c("ser", "f"),
  no.space = T,
  out = paste0("../tables/table-b2_g.html")
)



# Run multivariate correlations -------------------------------------------

### Run multivariate regressions with selected variables
var_mult <- c("lvng_area_pc_chg08 + smallapts_pc_chg08 + 
               new_apts_pc_chg08 + land_prc_chg08 +
               svb_hq_pt_chg08 + pop_dens_chg08 +
               house_inc_chg08 + age_chg08 +
               dom_mig_pc_chg08 + neg_credscore_chg08")

lm_d1_mult <- lm(paste0(dep1, " ~", var_mult), panel_krs_21_sd)
lm_d2_mult <- lm(paste0(dep2, " ~", var_mult), panel_krs_21_sd)
lm_d3_mult <- lm(paste0(dep3, " ~", var_mult), panel_krs_21_sd)


## Extract and store coefficients
lm_d1_mult_n <- lm_d1_mult
lm_d2_mult_n <- lm_d2_mult
lm_d3_mult_n <- lm_d3_mult

lm_d1_mult_n$coefficients <- lm_d1_mult$coefficients[-1]
lm_d2_mult_n$coefficients <- lm_d2_mult$coefficients[-1]
lm_d3_mult_n$coefficients <- lm_d3_mult$coefficients[-1]

l_multiv_coef <- list()
l_multiv_coef[["apRent"]] <- lm_d1_mult_n$coefficients
l_multiv_coef[["apPurc"]] <- lm_d2_mult_n$coefficients
l_multiv_coef[["houPurc"]] <- lm_d3_mult_n$coefficients

mult_names <- c(
  "Living area pc", "Share of small apartments",
  "Completed apartments pc", "Land prices",
  "Share of academics", "Population density",
  "Household income pc", "Average population age",
  "Domestic migration balance", "Share of subprime"
)

l_multiv_coef <- lapply(l_multiv_coef, setNames, mult_names)
multiv_coef <- bind_rows(l_multiv_coef, .id = "column_label")

multiv_coef_long <- multiv_coef %>%
  rename(y_var = column_label) %>%
  pivot_longer(!y_var, names_to = "x_var", values_to = "coef") %>%
  mutate(model = "multivariate selected")


## Extract and store SEs
l_multiv_se <- list()
l_multiv_se[["apRent"]] <- summary(lm_d1_mult)$coefficients[-1, 2]
l_multiv_se[["apPurc"]] <- summary(lm_d2_mult)$coefficients[-1, 2]
l_multiv_se[["houPurc"]] <- summary(lm_d3_mult)$coefficients[-1, 2]

l_multiv_se <- lapply(l_multiv_se, setNames, mult_names)
multiv_se <- bind_rows(l_multiv_se, .id = "column_label")

multiv_se_long <- multiv_se %>%
  rename(y_var = column_label) %>%
  pivot_longer(!y_var, names_to = "x_var", values_to = "se") %>%
  mutate(model = "multivariate selected")


## Merge Coefs and SEs
reg_multiv <- merge(multiv_coef_long, multiv_se_long,
  by = c("y_var", "x_var", "model")
)

## Calculate 95% confidence bands
reg_multiv$up <- reg_multiv$coef + (reg_multiv$se * 1.96)
reg_multiv$down <- reg_multiv$coef - (reg_multiv$se * 1.96)


## Extract and store adj. R2
group_names2 <- c("Combined factors")

lm_d1_mult_r2 <- summary(lm_d1_mult_n)$adj.r.squared
lm_d2_mult_r2 <- summary(lm_d2_mult_n)$adj.r.squared
lm_d3_mult_r2 <- summary(lm_d3_mult_n)$adj.r.squared

l_lm_mult_r2 <- list()
l_lm_mult_r2[["apRent"]] <- lm_d1_mult_r2
l_lm_mult_r2[["apPurc"]] <- lm_d2_mult_r2
l_lm_mult_r2[["houPurc"]] <- lm_d3_mult_r2

l_lm_mult_r2 <- lapply(l_lm_mult_r2, setNames, group_names2)
lm_mult_r2 <- bind_rows(l_lm_mult_r2, .id = "column_label")

lm_mult_r2_long <- lm_mult_r2 %>%
  rename(y_var = column_label) %>%
  pivot_longer(!y_var, names_to = "group", values_to = "adr2")


## Extract and Export Residuals
res_d1_mult <- as.data.frame(lm_d1_mult$residuals) %>%
  mutate(id = as.numeric(rownames(.)))

res_d2_mult <- as.data.frame(lm_d2_mult$residuals) %>%
  mutate(id = as.numeric(rownames(.)))

res_d3_mult <- as.data.frame(lm_d3_mult$residuals) %>%
  mutate(id = as.numeric(rownames(.)))

# Bind residuals by row number (id)
df_res_mult <- panel_krs_21 %>%
  ungroup() %>%
  select(krs) %>%
  mutate(id = (1:400)) %>%
  left_join(., res_d1_mult, by = "id") %>%
  left_join(., res_d2_mult, by = "id") %>%
  left_join(., res_d3_mult, by = "id") %>%
  dplyr::select(-id) %>%
  rename(
    "apRent_res" = "lm_d1_mult$residuals",
    "apPurc_res" = "lm_d2_mult$residuals",
    "houPurc_res" = "lm_d3_mult$residuals"
  ) %>%
  mutate(
    apRent_res_sd = as.numeric(scale(apRent_res)),
    apPurc_res_sd = as.numeric(scale(apPurc_res)),
    houPurc_res_sd = as.numeric(scale(houPurc_res))
  )

# Export
write.xlsx(df_res_mult, "../data/residuals.xlsx")



# Plot Correlations ----------------------------------------------------------------------

### Combine all coefficients
reg_coef <- reg_biv %>%
  bind_rows(., reg_block, reg_multiv) %>%
  group_by(y_var, model) %>%
  fill(x_var) %>%
  ungroup() %>%
  mutate(
    x_var = fct_rev(fct_relevel(x_var, c(
      "Living area pc", "Residential buildings pc",
      "Share of small apartments", "Share of family houses",
      "Land prices", "Completed apartments pc",
      "Share of developable land", "Building permits pc",
      "Completed houses pc",
      "Share of academics", "Labor market tightness",
      "Unemployment rate", "Vacancy rate",
      "Emp. share in manufacturing", "Hiring rate",
      "Household income pc", "GDP pc", "Overnight stays",
      "Average population age", "Migrant share", "Female share",
      "Student ratio", "Divorce rate", "Average household size",
      "Population density", "Domestic migration balance",
      "Commuter balance", "External migration balance",
      "Share of subprime", "Private debtor rate",
      "Hazard rate", "Mortgage lending"
    ))),
    model = fct_relevel(model, "bivariate", "multivariate blockwise", "multivariate selected"),
    y_var = fct_relevel(y_var, "apRent", "apPurc", "houPurc"),
    y_var = fct_recode(y_var,
      "Apartment rents" = "apRent",
      "Apartment purchase prices" = "apPurc",
      "House purchase prices" = "houPurc"
    )
  )

## Combine all R2s
reg_adj2 <- lm_block_r2_long %>%
  bind_rows(lm_mult_r2_long) %>%
  mutate(model = ifelse(group == "Combined factors", "multivariate selected", "multivariate blockwise"))


## Add category labels and relevel factors
reg_group <- reg_coef %>%
  mutate(group = case_when(
    x_var %in% c("Living area pc", "Residential buildings pc", 
                 "Share of small apartments", "Share of family houses") ~ "(1) Exist. supply",
    x_var %in% c("Land prices", "Completed apartments pc", 
                 "Share of developable land", "Building permits pc", 
                 "Completed houses pc") ~ "(2) New supply",
    x_var %in% c("Share of academics", "Labor market tightness", 
                 "Unemployment rate", "Vacancy rate", 
                 "Emp. share in manufacturing", "Hiring rate") ~ "(3) Labor market factors",
    x_var %in% c("Household income pc", "GDP pc", "Overnight stays") ~ "(4) Income & amenities",
    x_var %in% c("Average population age", "Migrant share", 
                 "Female share", "Student ratio", 
                 "Divorce rate", "Average household size") ~ "(5) Socio- demographics",
    x_var %in% c("Population density", "Domestic migration balance", 
                 "Commuter balance", "External migration balance") ~ "(6) Population & mobility",
    TRUE ~ "(7) Financial market"
  )) %>%
  mutate(group = fct_relevel(
    group, "(1) Exist. supply", "(2) New supply", "(3) Labor market factors", 
    "(4) Income & amenities", "(5) Socio- demographics", "(6) Population & mobility",
    "(7) Financial market"
  ))



## Plot regression coefficients
p1 <- reg_group %>%
  ggplot(
    .,
    aes(
      x = x_var, y = coef, ymax = up, ymin = down, 
      shape = model, colour = model
    )
  ) +
  geom_hline(aes(yintercept = 0),
    size = 0.4,
    colour = "grey30", linetype = "longdash"
  ) +
  geom_pointrange(
    position = position_dodge2(width = 0.7, reverse = T),
    fill = "white", size = 0.3
  ) +
  coord_flip() +
  labs(
    x = NULL,
    y = "Coefficient estimate",
    title = "Panel A. Correlation plot: \u0394<sup>08-21</sup> housing prices vs. \u0394<sup>08-21</sup> fundamentals"
  ) +
  facet_grid(group ~ y_var,
    scales = "free_y", space = "free",
    labeller = labeller(group = label_wrap_gen(width = 20))
  ) +
  scale_y_continuous(
    limits = c(-1.1, 1.1),
    breaks = c(-1, -0.5, 0, 0.5, 1)
  ) +
  scale_color_manual(values = c("#D55E00", "#0072B2", "#009e73")) +
  theme_pub() +
  theme(
    legend.position = "bottom",
    legend.title = element_blank(),
    strip.text.x = element_text(size = 7),
    strip.text.y = element_text(size = 6),
    axis.text = element_text(size = 7),
    plot.title = element_markdown(
      margin = margin(b = 10, l = -93),
      size = 9
    ),
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.border = element_rect(colour = "grey30", fill = NA)
  ) +
  guides(
    shape = guide_legend(override.aes = list(linetype = 0)),
    color = guide_legend(override.aes = list(linetype = 0))
  )


## Plot adjusted R2
p2 <- reg_adj2 %>%
  mutate(
    y_var = fct_relevel(y_var, "apRent", "apPurc", "houPurc"),
    y_var = fct_recode(y_var,
      "Apartment rents" = "apRent",
      "Apartment purchase prices" = "apPurc",
      "House purchase prices" = "houPurc"
    )
  ) %>%
  ggplot(., aes(x = fct_relevel(
    group, "Financ. market", "Sociodem. factors", "Income & amenities", 
    "New supply", "Existing supply", "Labor market factors",
    "Population & mobility", "Combined factors"
  ), y = adr2, fill = model)) +
  geom_col(alpha = 0.9) +
  scale_fill_manual(values = c("#0072B2", "#009e73")) +
  coord_flip(clip = "off") +
  facet_wrap(~y_var) +
  theme_pub() +
  labs(
    x = NULL,
    y = "Adj. R-squared",
    title = "Panel B. Explained variation in price change (\u0394<sup>08-21</sup>) by category"
  ) +
  scale_y_continuous(
    expand = c(0.01, 0),
    limits = c(0, 0.7)
  ) +
  scale_x_discrete(expand = c(0, 0.5)) +
  theme(
    legend.position = "none",
    legend.title = element_blank(),
    strip.text = element_text(size = 7),
    axis.text = element_text(size = 7),
    plot.title = element_markdown(
      margin = margin(b = 8, l = -70),
      size = 9
    ),
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.major.x = ggplot2::element_line(color = "gray95"),
    axis.line = element_blank(),
    axis.title = element_text(size = 7),
    axis.ticks = element_blank(),
    panel.spacing = unit(1, "lines")
  )


## Combine both plots and export
p_group_comb <- ggarrange(p1, p2,
  ncol = 1, nrow = 2, heights = c(3, 1), common.legend = F
)
ggsave("../figures/figure-3.png",
  width = 16, height = 22.5, units = "cm", dpi = 300
)



# Find order --------------------------------------------------------------

# Individual factors
reg_factors <- reg_group %>%
  filter(model == "bivariate") %>%
  group_by(x_var, group) %>%
  mutate(t = abs(coef) / se) %>%
  summarise_at(vars(t), mean, na.rm = T)

# Categories
reg_adj2_group <- reg_adj2 %>%
  group_by(group) %>%
  summarise_at(vars(adr2), mean, na.rm = T)

# Group factors
reg_factors2 <- reg_group %>%
  filter(model == "multivariate blockwise") %>%
  group_by(x_var, group) %>%
  mutate(t = abs(coef) / se) %>%
  summarise_at(vars(t), mean, na.rm = T)
