## ---------------------------------------------
##
## Script name: figure-4.R
##
## Purpose of script: Generate Figure 4and Results
##                    for Appendix Tables C-12 -
##                    C14 and C-16 - C18
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(tidyverse)
library(plm)
library(lmtest)

# Clear environment
rm(list = ls())

# Load customized plot theme
theme_pub <- function() {
  theme_bw() %+replace%
    theme(
      panel.grid.major.x = element_blank(),
      panel.grid.major.y = ggplot2::element_line(color = "gray95"),
      panel.grid.minor.y = element_blank(),
      panel.border = element_blank(),
      axis.line = element_line(colour = "grey40", size = 0.3),
      axis.text = element_text(size = 7),
      axis.title = element_text(size = 7),
      axis.ticks = element_line(colour = "grey40", size = 0.3),
      legend.text = element_text(size = 7),
      legend.background = element_rect(
        colour = "grey30",
        fill = "white",
        size = 0.2
      ),
      legend.key.height = unit(0.8, "line"),
      legend.key.width = unit(1, "line"),
      plot.title = element_text(
        size = 7,
        vjust = 2,
        hjust = 0,
        margin = margin(0.2, 0.2, 0.2, 0.2, "cm")
      )
    )
}



# Import ------------------------------------------------------------------

# Data
panel_krs <- readRDS("../data/panel_krs.RDS")



# Run 4-year correlations (Long differences) ------------------------------

## Calculate change compared to base year [= long difference for x vs. x[1]]
fd_r <- function(x) ((x / x[1] - 1) * 100) # Change in percent
fd_a <- function(x) (x - x[1]) # Change in absolute values

## Define variables
vars_fd_r <- c(
  "pop_dens", "age", "lvng_area_pc", "land_prc", "house_inc"
)
vars_fd_a <- c(
  "smallapts_pc", "new_apts_pc", "dom_mig_pc", "svb_hq_pt",
  "neg_credscore"
)

dep_vars <- c(
  "apRent_chg", "apPurc_chg", "houPurc_chg"
)
x_vars <- c(
  "lvng_area_pc_chg", "smallapts_pc_chg", "land_prc_chg", 
  "new_apts_pc_chg", "svb_hq_pt_chg", "house_inc_chg",
  "age_chg", "pop_dens_chg", "dom_mig_pc_chg", 
  "neg_credscore_chg"
)

# Define estimation model
dep1 <- dep_vars[1]
dep2 <- dep_vars[2]
dep3 <- dep_vars[3]

var_mult <- c("lvng_area_pc_chg + smallapts_pc_chg +
               land_prc_chg + new_apts_pc_chg +
               svb_hq_pt_chg + house_inc_chg +
               age_chg + pop_dens_chg +
               dom_mig_pc_chg + neg_credscore_chg")


## 2008-2011

# Subset
panel_krs_0811 <- panel_krs %>%
  filter(year %in% c(2008, 2011)) %>%
  arrange(krs, year) %>%
  group_by(krs) %>%
  mutate(
    across(all_of(vars_fd_r),
      .fns = fd_r,
      .names = "{col}_chg"
    ),
    across(all_of(vars_fd_a),
      .fns = fd_a,
      .names = "{col}_chg"
    ),
    apRent_chg_idx = apRent_chg_idx / apRent_chg_idx[1] * 100,
    apPurc_chg_idx = apPurc_chg_idx / apPurc_chg_idx[1] * 100,
    houPurc_chg_idx = houPurc_chg_idx / houPurc_chg_idx[1] * 100,
    apRent_chg = apRent_chg_idx - apRent_chg_idx[1],
    apPurc_chg = apPurc_chg_idx - apPurc_chg_idx[1],
    houPurc_chg = houPurc_chg_idx - houPurc_chg_idx[1]
  ) %>%
  filter(year == 2011)

# Standardize all variables to mean 0 and sd 1
panel_krs_0811_sd <- panel_krs_0811
panel_krs_0811_sd[, c(dep_vars, x_vars)] <-
  scale(panel_krs_0811_sd[, c(dep_vars, x_vars)])


# Run long difference models
lm_d1_mult_0811 <- lm(paste0(dep1, " ~", var_mult), panel_krs_0811_sd)
lm_d2_mult_0811 <- lm(paste0(dep2, " ~", var_mult), panel_krs_0811_sd)
lm_d3_mult_0811 <- lm(paste0(dep3, " ~", var_mult), panel_krs_0811_sd)

# Store results
results_0811 <- data.frame(
  period = "08-11",
  apRent = summary(lm_d1_mult_0811)$adj.r.squared,
  apPurc = summary(lm_d2_mult_0811)$adj.r.squared,
  houPurc = summary(lm_d3_mult_0811)$adj.r.squared
)

# Export --> Appendix Table C-12
stargazer(lm_d1_mult_0811, lm_d2_mult_0811, lm_d3_mult_0811,
  type = "html",
  dep.var.labels = c(
    "Apartment rents", "Apartment purchase prices",
    "House purchase prices"
  ),
  covariate.labels = c(
    "Living area pc", "Share of small apartments",
    "Building land prices", "Completed apartments pc",
    "Share of academics", "Household income pc",
    "Mean population age", "Population density",
    "Domestic migration balance",
    "Share of subprime credit scores"
  ),
  omit = c("Constant"), omit.stat = c("ser", "f"),
  no.space = T,
  out = paste0("../tables/table-c12.html")
)



## 2012-2016

# Subset
panel_krs_1216 <- panel_krs %>%
  filter(year %in% c(2012, 2016)) %>%
  arrange(krs, year) %>%
  group_by(krs) %>%
  mutate(
    across(all_of(vars_fd_r),
      .fns = fd_r,
      .names = "{col}_chg"
    ),
    across(all_of(vars_fd_a),
      .fns = fd_a,
      .names = "{col}_chg"
    ),
    apRent_chg_idx = apRent_chg_idx / apRent_chg_idx[1] * 100,
    apPurc_chg_idx = apPurc_chg_idx / apPurc_chg_idx[1] * 100,
    houPurc_chg_idx = houPurc_chg_idx / houPurc_chg_idx[1] * 100,
    apRent_chg = apRent_chg_idx - apRent_chg_idx[1],
    apPurc_chg = apPurc_chg_idx - apPurc_chg_idx[1],
    houPurc_chg = houPurc_chg_idx - houPurc_chg_idx[1]
  ) %>%
  filter(year == 2016)

# Standardize all variables to mean 0 and sd 1
panel_krs_1216_sd <- panel_krs_1216
panel_krs_1216_sd[, c(dep_vars, x_vars)] <-
  scale(panel_krs_1216_sd[, c(dep_vars, x_vars)])


# Run long difference models
lm_d1_mult_1216 <- lm(paste0(dep1, " ~", var_mult), panel_krs_1216_sd)
lm_d2_mult_1216 <- lm(paste0(dep2, " ~", var_mult), panel_krs_1216_sd)
lm_d3_mult_1216 <- lm(paste0(dep3, " ~", var_mult), panel_krs_1216_sd)

# Store results
results_1216 <- data.frame(
  period = "12-16",
  apRent = summary(lm_d1_mult_1216)$adj.r.squared,
  apPurc = summary(lm_d2_mult_1216)$adj.r.squared,
  houPurc = summary(lm_d3_mult_1216)$adj.r.squared
)

# Export --> Appendix Table C-13
stargazer(lm_d1_mult_1216, lm_d2_mult_1216, lm_d3_mult_1216,
  type = "html",
  dep.var.labels = c(
    "Apartment rents", "Apartment purchase prices",
    "House purchase prices"
  ),
  covariate.labels = c(
    "Living area pc", "Share of small apartments",
    "Building land prices", "Completed apartments pc",
    "Share of academics", "Household income pc",
    "Mean population age", "Population density",
    "Domestic migration balance",
    "Share of subprime credit scores"
  ),
  omit = c("Constant"), omit.stat = c("ser", "f"),
  no.space = T,
  out = paste0("../tables/table-c13.html")
)


## 2017-2021

# Subset
panel_krs_1721 <- panel_krs %>%
  filter(year %in% c(2017, 2021)) %>%
  arrange(krs, year) %>%
  group_by(krs) %>%
  mutate(
    across(all_of(vars_fd_r),
      .fns = fd_r,
      .names = "{col}_chg"
    ),
    across(all_of(vars_fd_a),
      .fns = fd_a,
      .names = "{col}_chg"
    ),
    apRent_chg_idx = apRent_chg_idx / apRent_chg_idx[1] * 100,
    apPurc_chg_idx = apPurc_chg_idx / apPurc_chg_idx[1] * 100,
    houPurc_chg_idx = houPurc_chg_idx / houPurc_chg_idx[1] * 100,
    apRent_chg = apRent_chg_idx - apRent_chg_idx[1],
    apPurc_chg = apPurc_chg_idx - apPurc_chg_idx[1],
    houPurc_chg = houPurc_chg_idx - houPurc_chg_idx[1]
  ) %>%
  filter(year == 2021)

# Standardize all variables to mean 0 and sd 1
panel_krs_1721_sd <- panel_krs_1721
panel_krs_1721_sd[, c(dep_vars, x_vars)] <-
  scale(panel_krs_1721_sd[, c(dep_vars, x_vars)])


# Run long difference models
lm_d1_mult_1721 <- lm(paste0(dep1, " ~", var_mult), panel_krs_1721_sd)
lm_d2_mult_1721 <- lm(paste0(dep2, " ~", var_mult), panel_krs_1721_sd)
lm_d3_mult_1721 <- lm(paste0(dep3, " ~", var_mult), panel_krs_1721_sd)

# Store results
results_1721 <- data.frame(
  period = "17-21",
  apRent = summary(lm_d1_mult_1721)$adj.r.squared,
  apPurc = summary(lm_d2_mult_1721)$adj.r.squared,
  houPurc = summary(lm_d3_mult_1721)$adj.r.squared
)


# Export --> Appendix Table C-14
stargazer(lm_d1_mult_1721, lm_d2_mult_1721, lm_d3_mult_1721,
  type = "html",
  dep.var.labels = c(
    "Apartment rents", "Apartment purchase prices",
    "House purchase prices"
  ),
  covariate.labels = c(
    "Living area pc", "Share of small apartments",
    "Building land prices", "Completed apartments pc",
    "Share of academics", "Household income pc",
    "Mean population age", "Population density",
    "Domestic migration balance",
    "Share of subprime credit scores"
  ),
  omit = c("Constant"), omit.stat = c("ser", "f"),
  no.space = T,
  out = paste0("../tables/table-c14.html")
)


## Put together in one DF
results_4y <- results_0811 %>%
  bind_rows(results_1216, results_1721) %>%
  mutate(model = "long")



# Fixed effects -----------------------------------------------------------

# Define variables
dep_vars <- c("apRent_chg_idx", "apPurc_chg_idx", "houPurc_chg_idx")
vars <- c(
  "lvng_area_pc", "smallapts_pc", "land_prc", "new_apts_pc",
  "svb_hq_pt", "house_inc", "age", "pop_dens", "dom_mig_pc",
  "neg_credscore"
)

## Define set of variables
dep1 <- "log(apRent_chg_idx)"
dep2 <- "log(apPurc_chg_idx)"
dep3 <- "log(houPurc_chg_idx)"

reg_vars <- c("lvng_area_pc + smallapts_pc +
              land_prc + new_apts_pc +
              svb_hq_pt + house_inc +
              age + pop_dens +
              dom_mig_pc + neg_credscore")


## 2008-2011

# Standardize independent variables to mean 0 and sd 1
panel_krs_0811_sd <- panel_krs %>%
  filter(year %in% c(2008:2011))
panel_krs_0811_sd[, c(vars)] <- scale(panel_krs_0811_sd[, c(vars)])
plm_krs_0811 <- pdata.frame(panel_krs_0811_sd, index = c("krs", "year"))


## Run fixed effects models and compute robust SEs, clustered at district level

# Apartment rents
fe_d1_0811 <- plm(paste0(dep1, " ~ ", reg_vars),
  plm_krs_0811,
  model = "within", effect = "individual"
)
fe_d1_0811_rse <- coeftest(fe_d1_0811,
  vcov = vcovHC(fe_d1_0811,
    type = "HC1",
    cluster = "group"
  )
)

# Apartment purchase prices
fe_d2_0811 <- plm(paste0(dep2, " ~ ", reg_vars),
  plm_krs_0811,
  model = "within", effect = "individual"
)
fe_d2_0811_rse <- coeftest(fe_d2_0811,
  vcov = vcovHC(fe_d2_0811,
    type = "HC1",
    cluster = "group"
  )
)

# House purchase prices
fe_d3_0811 <- plm(paste0(dep3, " ~ ", reg_vars),
  plm_krs_0811,
  model = "within", effect = "individual"
)
fe_d3_0811_rse <- coeftest(fe_d3_0811,
  vcov = vcovHC(fe_d3_0811,
    type = "HC1",
    cluster = "group"
  )
)

# Put together
results2_0811 <- data.frame(
  period = "08-11",
  apRent = summary(fe_d1_0811)$r.squared[2],
  apPurc = summary(fe_d2_0811)$r.squared[2],
  houPurc = summary(fe_d3_0811)$r.squared[2]
)

# Export --> Appendix Table C-16
stargazer(fe_d1_0811, fe_d2_0811, fe_d3_0811,
  type = "html",
  se = list(fe_d1_0811_rse[, 2], fe_d2_0811_rse[, 2], fe_d3_0811_rse[, 2]),
  dep.var.labels = c(
    "Apartment rents", "Apartment purchase prices",
    "House purchase prices"
  ),
  covariate.labels = c(
    "Living area pc", "Share of small apartments",
    "Building land prices", "Completed apartments pc",
    "Share of academics", "Household income pc",
    "Mean population age", "Population density",
    "Domestic migration balance",
    "Share of subprime credit scores"
  ),
  omit = c("year", "Constant"),
  omit.stat = c("f"), no.space = T,
  add.lines = list(
    c("Region FE", "Yes", "Yes", "Yes"),
    c("Year FE", "No", "No", "No")
  ),
  out = "../tables/table-c16.html"
)


## 2012-2016

# Standardize independent variables to mean 0 and sd 1
panel_krs_1216_sd <- panel_krs %>%
  filter(year %in% c(2012:2016))
panel_krs_1216_sd[, c(vars)] <- scale(panel_krs_1216_sd[, c(vars)])
plm_krs_1216 <- pdata.frame(panel_krs_1216_sd, index = c("krs", "year"))


## Run fixed effects models and compute robust SEs, clustered at district level

# Apartment rents
fe_d1_1216 <- plm(paste0(dep1, " ~ ", reg_vars),
  plm_krs_1216,
  model = "within", effect = "individual"
)
fe_d1_1216_rse <- coeftest(fe_d1_1216,
  vcov = vcovHC(fe_d1_1216,
    type = "HC1",
    cluster = "group"
  )
)

# Apartment purchase prices
fe_d2_1216 <- plm(paste0(dep2, " ~ ", reg_vars),
  plm_krs_1216,
  model = "within", effect = "individual"
)
fe_d2_1216_rse <- coeftest(fe_d2_1216,
  vcov = vcovHC(fe_d2_1216,
    type = "HC1",
    cluster = "group"
  )
)

# House purchase prices
fe_d3_1216 <- plm(paste0(dep3, " ~ ", reg_vars),
  plm_krs_1216,
  model = "within", effect = "individual"
)
fe_d3_1216_rse <- coeftest(fe_d3_1216,
  vcov = vcovHC(fe_d3_1216,
    type = "HC1",
    cluster = "group"
  )
)

# Put together
results2_1216 <- data.frame(
  period = "12-16",
  apRent = summary(fe_d1_1216)$r.squared[2],
  apPurc = summary(fe_d2_1216)$r.squared[2],
  houPurc = summary(fe_d3_1216)$r.squared[2]
)

# Export --> Appendix Table C-17
stargazer(fe_d1_1216, fe_d2_1216, fe_d3_1216,
  type = "html",
  se = list(fe_d1_1216_rse[, 2], fe_d2_1216_rse[, 2], fe_d3_1216_rse[, 2]),
  dep.var.labels = c(
    "Apartment rents", "Apartment purchase prices",
    "House purchase prices"
  ),
  covariate.labels = c(
    "Living area pc", "Share of small apartments",
    "Building land prices", "Completed apartments pc",
    "Share of academics", "Household income pc",
    "Mean population age", "Population density",
    "Domestic migration balance",
    "Share of subprime credit scores"
  ),
  omit = c("year", "Constant"),
  omit.stat = c("f"), no.space = T,
  add.lines = list(
    c("Region FE", "Yes", "Yes", "Yes"),
    c("Year FE", "No", "No", "No")
  ),
  out = "../tables/table-c17.html"
)


## 2017-2021

# Standardize independent variables to mean 0 and sd 1
panel_krs_1721_sd <- panel_krs %>%
  filter(year %in% c(2017:2021))
panel_krs_1721_sd[, c(vars)] <- scale(panel_krs_1721_sd[, c(vars)])
plm_krs_1721 <- pdata.frame(panel_krs_1721_sd, index = c("krs", "year"))


## Run fixed effects models and compute robust SEs, clustered at district level

# Apartment rents
fe_d1_1721 <- plm(paste0(dep1, " ~ ", reg_vars),
  plm_krs_1721,
  model = "within", effect = "individual"
)
fe_d1_1721_rse <- coeftest(fe_d1_1721,
  vcov = vcovHC(fe_d1_1721,
    type = "HC1",
    cluster = "group"
  )
)

# Apartment purchase prices
fe_d2_1721 <- plm(paste0(dep2, " ~ ", reg_vars),
  plm_krs_1721,
  model = "within", effect = "individual"
)
fe_d2_1721_rse <- coeftest(fe_d2_1721,
  vcov = vcovHC(fe_d2_1721,
    type = "HC1",
    cluster = "group"
  )
)

# House purchase prices
fe_d3_1721 <- plm(paste0(dep3, " ~ ", reg_vars),
  plm_krs_1721,
  model = "within", effect = "individual"
)
fe_d3_1721_rse <- coeftest(fe_d3_1721,
  vcov = vcovHC(fe_d3_1721,
    type = "HC1",
    cluster = "group"
  )
)

# Put together
results2_1721 <- data.frame(
  period = "17-21",
  apRent = summary(fe_d1_1721)$r.squared[2],
  apPurc = summary(fe_d2_1721)$r.squared[2],
  houPurc = summary(fe_d3_1721)$r.squared[2]
)

# Export --> Appendix Table C-18
stargazer(fe_d1_1721, fe_d2_1721, fe_d3_1721,
  type = "html",
  se = list(fe_d1_1721_rse[, 2], fe_d2_1721_rse[, 2], fe_d3_1721_rse[, 2]),
  dep.var.labels = c(
    "Apartment rents", "Apartment purchase prices",
    "House purchase prices"
  ),
  covariate.labels = c(
    "Living area pc", "Share of small apartments",
    "Building land prices", "Completed apartments pc",
    "Share of academics", "Household income pc",
    "Mean population age", "Population density",
    "Domestic migration balance",
    "Share of subprime credit scores"
  ),
  omit = c("year", "Constant"),
  omit.stat = c("f"), no.space = T,
  add.lines = list(
    c("Region FE", "Yes", "Yes", "Yes"),
    c("Year FE", "No", "No", "No")
  ),
  out = "../tables/table-c18.html"
)


## Put all single dfs for different periods together
results2_4y <- results2_0811 %>%
  bind_rows(results2_1216, results2_1721) %>%
  mutate(model = "fe")


### Combine long difference and fixed effects results
results <- results_4y %>%
  bind_rows(results2_4y) %>%
  pivot_longer(., "apRent":"houPurc",
    names_to = "outcome", values_to = "value"
  ) %>%
  mutate(outcome = as.factor(outcome)) %>%
  mutate(outcome = fct_recode(outcome,
    "Apartment rents" = "apRent",
    "Apartment purchase prices" = "apPurc",
    "House purchase prices" = "houPurc"
  ))

## Overall R2 (from Tables 1 and 2)
r2 <- data.frame(
  model = c("long", "long", "long", "fe", "fe", "fe"),
  outcome = c(
    "Apartment rents", "Apartment purchase prices",
    "House purchase prices",
    "Apartment rents", "Apartment purchase prices",
    "House purchase prices"
  ),
  total_r2 = c(0.620, 0.656, 0.607, 0.867, 0.763, 0.767)
)


## Merge
results <- results %>%
  left_join(r2, by = c("model", "outcome")) %>%
  mutate(outcome = fct_relevel(
    outcome, "Apartment rents", "Apartment purchase prices",
    "House purchase prices"
  ))



# Plot --------------------------------------------------------------------

# Long Difference
p1 <- results %>%
  filter(model == "long") %>%
  ggplot(., aes(x = factor(period), y = value)) +
  geom_hline(
    yintercept = 0, size = 0.3,
    colour = "grey30",
    linetype = 2
  ) +
  geom_hline(aes(yintercept = total_r2),
    size = 0.3,
    colour = "grey30"
  ) +
  geom_col(fill = "#0072B2D0", alpha = 0.7) +
  facet_wrap(~outcome, scales = "free") +
  theme_pub() +
  labs(
    x = NULL,
    y = "Share of explained variation",
    title = "Panel A. Between-region variation (overall)"
  ) +
  scale_y_continuous(
    limits = c(-0.25, 1),
    breaks = c(-0.2, 0, 0.2, 0.4, 0.6, 0.8, 1)
  ) +
  theme(
    legend.position = "none",
    panel.grid.major.y = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    strip.background = element_blank()
  )


# Fixed Effects
p2 <- results %>%
  filter(model == "fe") %>%
  ggplot(., aes(x = factor(period), y = value)) +
  geom_hline(
    yintercept = 0, size = 0.3,
    colour = "grey30",
    linetype = 2
  ) +
  geom_hline(aes(yintercept = total_r2),
    size = 0.3,
    colour = "grey30"
  ) +
  geom_col(fill = "#0072B2D0", alpha = 0.7) +
  facet_wrap(~outcome, scales = "free") +
  theme_pub() +
  labs(
    x = NULL,
    y = "Share of explained variation",
    title = "Panel B. Within-region variation (year-to-year)"
  ) +
  scale_y_continuous(
    limits = c(-0.25, 1),
    breaks = c(-0.2, 0, 0.2, 0.4, 0.6, 0.8, 1)
  ) +
  theme(
    legend.position = "none",
    panel.grid.major.y = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    strip.background = element_blank()
  )


# Export
p12 <- ggarrange(p1, p2, ncol = 1, nrow = 2)
ggsave(paste0("../figures/figure-4.png"),
  width = 16, height = 10, units = "cm", dpi = 400
)
