## ---------------------------------------------
##
## Script name: figure-5.R
##
## Purpose of script: Generate Figure 5
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(openxlsx)
library(tidyverse)
library(ggpubr)

# Clear environment
rm(list = ls())

# Load customized plot theme
theme_pub <- function() {
  theme_bw() %+replace%
    theme(
      panel.grid.major.x = element_blank(),
      panel.grid.major.y = ggplot2::element_line(color = "gray95"),
      panel.grid.minor.y = element_blank(),
      panel.border = element_blank(),
      axis.line = element_line(colour = "grey40", size = 0.3),
      axis.text = element_text(size = 7),
      axis.title = element_text(size = 7),
      axis.ticks = element_line(colour = "grey40", size = 0.3),
      legend.text = element_text(size = 7),
      legend.background = element_rect(
        colour = "grey30",
        fill = "white",
        size = 0.2
      ),
      legend.key.height = unit(0.8, "line"),
      legend.key.width = unit(1, "line"),
      plot.title = element_text(
        size = 7,
        vjust = 2,
        hjust = 0,
        margin = margin(0.2, 0.2, 0.2, 0.2, "cm")
      )
    )
}

# Function for additional lines for axis labels
addline_format <- function(x, ...) {
  gsub("\\s", "\n", x)
}



# Import ------------------------------------------------------------------

# Data
panel_krs <- readRDS("../data/panel_krs.RDS")

# Residuals (estimated in script "figure-3.R")
res <- read.xlsx("../data/residuals.xlsx")



# Preparation -------------------------------------------------------------

# Subset
panel_krs_21 <- panel_krs %>%
  filter(year == 2021) %>%
  left_join(res, by = "krs") %>%
  select(
    krs, krs_type, apRent_res_sd, apPurc_res_sd, houPurc_res_sd
  ) %>%
  mutate(krs_type = fct_relevel(krs_type, "0", "1", "2", "3", "4"))

# Reshape, relevel and recode for plotting
df_plot <- panel_krs_21 %>%
  pivot_longer(., "apRent_res_sd":"houPurc_res_sd",
    names_to = c("outcome", "variable", "sd"),
    names_sep = "_"
  ) %>%
  mutate(
    outcome = fct_relevel(
      outcome, "apRent", "apPurc", "houPurc"
    ),
    outcome = fct_recode(outcome,
      "Panel A. Apartment rents" = "apRent",
      "Panel B. Apartment purchase prices" = "apPurc",
      "Panel C. House purchase prices" = "houPurc"
    )
  )



# Plotting ----------------------------------------------------------------

# Define significance levels shown in plot
symnum.args <- list(
  cutpoints = c(0, 0.05, 1),
  symbols = c("*", "ns")
)

# Make Plot
p <- df_plot %>%
  ggplot(., aes(
    x = fct_rev(krs_type), y = value, fill = fct_rev(krs_type),
    colour = fct_rev(krs_type)
  )) +
  geom_hline(
    yintercept = 0, size = 0.2, colour = "grey30", linetype = 2
  ) +
  geom_hline(
    yintercept = -2, size = 0.2, colour = "grey50", linetype = 2
  ) +
  geom_hline(
    yintercept = 2, size = 0.2, colour = "grey50", linetype = 2
  ) +
  geom_jitter(
    pch = 21, color = "white", size = 1, alpha = 0.6,
    position = position_jitter(seed = 1)
  ) +
  stat_summary(
    fun = mean, fun.min = mean, fun.max = mean,
    geom = "crossbar", size = 0.3
  ) +
  stat_compare_means(
    label = "p.signif", ref.group = ".all.", size = 2.2,
    symnum.args = symnum.args, tip.length = 0.01
  ) +
  stat_compare_means(label.y = 45) +
  facet_wrap(~outcome, scales = "free") +
  theme_pub() +
  scale_color_brewer(palette = "Set2") +
  scale_fill_brewer(palette = "Set2") +
  labs(
    x = NULL,
    y = "Excessive price growth",
    title = NULL
  ) +
  scale_x_discrete(
    labels = addline_format(c(
      "Spars. populated", "Rural", "Urban", "Large urban", "Top 7"
    ))
  ) +
  scale_y_continuous(
    limits = c(-3, 8), breaks = c(-2, 0, 2, 4, 6, 8)
  ) +
  theme(
    legend.position = "none",
    panel.grid.major.y = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    strip.background = element_blank()
  )

# Export
ggsave(paste0("../figures/figure-5.png"),
  width = 16, height = 5, units = "cm", dpi = 400
)



### Fact stated on page 18: "Approximately 90 percent of
#   all residuals are within -1.5 and +1.5 standard deviations;
#   approximately 95 percent are within -2 to +2 standard deviations."

sd_range <- df_plot %>%
  mutate(
    res_sd_15 = ifelse(abs(value) > 1.5, 1, 0),
    res_sd_2 = ifelse(abs(value) > 2, 1, 0)
  )

apRent <- sd_range %>%
  filter(outcome == "Panel A. Apartment rents")

apPurc <- sd_range %>%
  filter(outcome == "Panel B. Apartment purchase prices")

houPurc <- sd_range %>%
  filter(outcome == "Panel C. House purchase prices")

# -1.5 to 1.5 SD
(length(apRent$res_sd_15) - sum(apRent$res_sd_15, na.rm = T)) / 
  length(apRent$res_sd_15)
(length(apPurc$res_sd_15) - sum(apPurc$res_sd_15, na.rm = T)) / 
  length(apPurc$res_sd_15)
(length(houPurc$res_sd_15) - sum(houPurc$res_sd_15, na.rm = T)) / 
  length(houPurc$res_sd_15)

# -2 to 2 SD
(length(apRent$res_sd_2) - sum(apRent$res_sd_2, na.rm = T)) / 
  length(apRent$res_sd_2)
(length(apPurc$res_sd_2) - sum(apPurc$res_sd_2, na.rm = T)) / 
  length(apPurc$res_sd_2)
(length(houPurc$res_sd_2) - sum(houPurc$res_sd_2, na.rm = T)) / 
  length(houPurc$res_sd_2)


### Fact stated on page 18: "This group includes some medium-sized cities in the east
#   (Potsdam, Leipzig, Chemnitz) and southwest (Darmstadt, Heidelberg)
#   that show above-average population growth and skill sorting but
#   experienced relative “low” apartment price growth."

sub_21 <- panel_krs %>%
  filter(year == 2021) %>%
  select(krs, pop_dens_chg08, svb_hq_pt_chg08) %>%
  left_join(res, by = "krs")

sub_21[sub_21$krs %in% c("12054", "14713", "14511", "06411", "08221"), ]
sub_21[sub_21$krs %in% c("12054", "14713", "14511", "06411", "08221"), c("pop_dens_chg08", "svb_hq_pt_chg08")]

panel_krs %>%
  ungroup() %>%
  filter(year == 2021) %>%
  summarise_at(vars(pop_dens_chg08, svb_hq_pt_chg08), mean, na.rm = T)


### Fact stated on page 18f.: "These indicate a clear and significant overvaluation
#   of housing prices, averaging approximately 1 to 1.5 standard deviations and
#   suggesting a large price premium for top cities not reflected in fundamentals."
df_plot %>%
  filter(krs_type == 0) %>%
  group_by(outcome) %>%
  summarise_at(vars(value), mean, na.rm = T)
