## ---------------------------------------------
##
## Script name: figure-6.R
##
## Purpose of script: Generate Figure 6
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(openxlsx)
library(tidyverse)
library(ggpubr)
library(binsreg)

# Clear environment
rm(list = ls())

# Load customized plot theme
theme_pub <- function() {
  theme_bw() %+replace%
    theme(
      panel.grid.major.x = element_blank(),
      panel.grid.major.y = ggplot2::element_line(color = "gray95"),
      panel.grid.minor.y = element_blank(),
      panel.border = element_blank(),
      axis.line = element_line(colour = "grey40", size = 0.3),
      axis.text = element_text(size = 7),
      axis.title = element_text(size = 7),
      axis.ticks = element_line(colour = "grey40", size = 0.3),
      legend.text = element_text(size = 7),
      legend.background = element_rect(
        colour = "grey30",
        fill = "white",
        size = 0.2
      ),
      legend.key.height = unit(0.8, "line"),
      legend.key.width = unit(1, "line"),
      plot.title = element_text(
        size = 7,
        vjust = 2,
        hjust = 0,
        margin = margin(0.2, 0.2, 0.2, 0.2, "cm")
      )
    )
}



# Import ------------------------------------------------------------------

# Data
panel_krs <- readRDS("../data/panel_krs.RDS")

# Residuals (estimated in script "figure-3.R")
res <- read.xlsx("../data/residuals.xlsx")



# Preparation -------------------------------------------------------------

# Subset
res_21 <- panel_krs %>%
  filter(year == 2021) %>%
  left_join(res, by = "krs") %>%
  select(
    krs, apRent_res_sd,
    apPurc_res_sd, houPurc_res_sd
  )

# Generate variables indicating initial level in 2008
panel_krs_sub <- panel_krs %>%
  mutate(guest_nights_pc = guest_nights / pop_total * 1000) %>%
  group_by(krs) %>%
  mutate(
    svb_hq_pt_08 = svb_hq_pt[year == 2008],
    house_inc_08 = house_inc[year == 2008],
    pop_total_08 = pop_total[year == 2008],
    guest_nights_pc_08 = guest_nights_pc[year == 2008]
  ) %>%
  ungroup() %>%
  filter(year == 2021) %>%
  select(
    krs, krs_type, house_inc_08, pop_total_08,
    svb_hq_pt_08, guest_nights_pc_08,
    apRent_chg08, apPurc_chg08, houPurc_chg08
  ) %>%
  left_join(., res_21, by = "krs")



# Plots -------------------------------------------------------------------

## Population

# Estimation Binscatter Least Squares Regression; number of bins = 10
# For each housing price indicator vs. log population
# Store results for plot

est1 <- binsreg(panel_krs_sub$apRent_res_sd, log(panel_krs_sub$pop_total_08), 
                nbins = 10, cb = T)$data.plot$`Group Full Sample`
est2 <- binsreg(panel_krs_sub$apPurc_res_sd, log(panel_krs_sub$pop_total_08),
                nbins = 10, cb = T)$data.plot$`Group Full Sample`
est3 <- binsreg(panel_krs_sub$houPurc_res_sd, log(panel_krs_sub$pop_total_08),
                nbins = 10, cb = T)$data.plot$`Group Full Sample`


# Create the figure to plot
fig1 <- ggplot() +
  geom_point(
    data = est1$data.dots, aes(x = x, y = fit),
    color = "#0072B2D0", size = 1.5
  ) +
  geom_ribbon(
    data = est1$data.cb, aes(x = x, ymin = cb.l, ymax = cb.r),
    fill = "#0072B2D0", alpha = 0.2
  ) +
  geom_hline(
    yintercept = 0, size = 0.3, colour = "grey30", linetype = 2
  ) +
  theme_pub() +
  labs(
    x = "Log population",
    y = "Excessive price growth",
    title = "Apartment rents"
  ) +
  scale_y_continuous(
    limits = c(-1.5, 3)
  ) +
  scale_x_continuous(
    limits = c(10.5, 14)
  ) +
  guides(
    fill = guide_legend(title = NULL),
    color = guide_legend(title = NULL)
  ) +
  theme(
    legend.position = "none",
    plot.title = element_text(size = 7),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.y = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    strip.background = element_blank(),
    plot.margin = unit(c(10, 5.5, 10, 5.5), "points")
  )


# Create the figure to plot 2
fig2 <- ggplot() +
  geom_point(
    data = est2$data.dots, aes(x = x, y = fit),
    color = "#0072B2D0", size = 1.5
  ) +
  geom_ribbon(
    data = est2$data.cb, aes(x = x, ymin = cb.l, ymax = cb.r),
    fill = "#0072B2D0", alpha = 0.2
  ) +
  geom_hline(
    yintercept = 0, size = 0.3, colour = "grey30", linetype = 2
  ) +
  theme_pub() +
  labs(
    x = "Log population",
    y = NULL,
    title = "Apartment purchase prices"
  ) +
  scale_y_continuous(
    limits = c(-1.5, 3)
  ) +
  scale_x_continuous(
    limits = c(10.5, 14)
  ) +
  theme(
    legend.position = "none",
    plot.title = element_text(size = 7),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.y = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    strip.background = element_blank(),
    plot.margin = unit(c(10, 5.5, 10, 5.5), "points")
  )


# Create the figure to plot 3
fig3 <- ggplot() +
  geom_point(
    data = est3$data.dots, aes(x = x, y = fit),
    color = "#0072B2D0", size = 1.5
  ) +
  geom_ribbon(
    data = est3$data.cb, aes(x = x, ymin = cb.l, ymax = cb.r),
    fill = "#0072B2D0", alpha = 0.2
  ) +
  geom_hline(
    yintercept = 0, size = 0.3, colour = "grey30", linetype = 2
  ) +
  theme_pub() +
  labs(
    x = "Log population",
    y = NULL,
    title = "House purchase prices"
  ) +
  scale_y_continuous(
    limits = c(-1.5, 3)
  ) +
  scale_x_continuous(
    limits = c(10.5, 14)
  ) +
  theme(
    legend.position = "none",
    plot.title = element_text(size = 7),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.y = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    strip.background = element_blank(),
    plot.margin = unit(c(10, 5.5, 10, 5.5), "points")
  )

# Combine
fig123 <- ggarrange(fig1, fig2, fig3,
  ncol = 3, nrow = 1,
  labels = c("Panel A. Population", NULL, NULL), vjust = 1, hjust = -0.1,
  font.label = list(size = 8, color = "black", face = "plain")
)


## Income

# Estimation Binscatter Least Squares Regression; number of bins = 10
# For each housing price indicator vs. household income
# Store results for plot

est4 <- binsreg(panel_krs_sub$apRent_res_sd, panel_krs_sub$house_inc_08,
                nbins = 10, cb = T)$data.plot$`Group Full Sample`
est5 <- binsreg(panel_krs_sub$apPurc_res_sd, panel_krs_sub$house_inc_08,
                nbins = 10, cb = T)$data.plot$`Group Full Sample`
est6 <- binsreg(panel_krs_sub$houPurc_res_sd, panel_krs_sub$house_inc_08,
                nbins = 10, cb = T)$data.plot$`Group Full Sample`


# Create the figure to plot 4
fig4 <- ggplot() +
  geom_point(
    data = est4$data.dots, aes(x = x, y = fit),
    color = "#0072B2D0", size = 1.5
  ) +
  geom_ribbon(
    data = est4$data.cb, aes(x = x, ymin = cb.l, ymax = cb.r),
    fill = "#0072B2D0", alpha = 0.2
  ) +
  geom_hline(
    yintercept = 0, size = 0.3, colour = "grey30", linetype = 2
  ) +
  theme_pub() +
  labs(
    x = "Household income pc [1,000]",
    y = "Excessive price growth",
    title = "Apartment rents"
  ) +
  scale_y_continuous(
    limits = c(-1.3, 3)
  ) +
  scale_x_continuous(
    limits = c(14, 26), breaks = c(15, 20, 25)
  ) +
  theme(
    legend.position = "none",
    plot.title = element_text(size = 7),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.y = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    strip.background = element_blank(),
    plot.margin = unit(c(5.5, 5.5, 10, 5.5), "points")
  )



# Create the figure to plot 5
fig5 <- ggplot() +
  geom_point(
    data = est5$data.dots, aes(x = x, y = fit),
    color = "#0072B2D0", size = 1.5
  ) +
  geom_ribbon(
    data = est5$data.cb, aes(x = x, ymin = cb.l, ymax = cb.r),
    fill = "#0072B2D0", alpha = 0.2
  ) +
  geom_hline(
    yintercept = 0, size = 0.3, colour = "grey30", linetype = 2
  ) +
  theme_pub() +
  labs(
    x = "Household income pc [1,000]",
    y = NULL,
    title = "Apartment purchase prices"
  ) +
  scale_y_continuous(
    limits = c(-1.3, 3)
  ) +
  scale_x_continuous(
    limits = c(14, 26), breaks = c(15, 20, 25)
  ) +
  theme(
    legend.position = "none",
    plot.title = element_text(size = 7),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.y = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    strip.background = element_blank(),
    plot.margin = unit(c(5.5, 5.5, 10, 5.5), "points")
  )


# Create the figure to plot 6
fig6 <- ggplot() +
  geom_point(
    data = est6$data.dots, aes(x = x, y = fit),
    color = "#0072B2D0", size = 1.5
  ) +
  geom_ribbon(
    data = est6$data.cb, aes(x = x, ymin = cb.l, ymax = cb.r),
    fill = "#0072B2D0", alpha = 0.2
  ) +
  geom_hline(
    yintercept = 0, size = 0.3, colour = "grey30", linetype = 2
  ) +
  theme_pub() +
  labs(
    x = "Household income pc [1,000]",
    y = NULL,
    title = "House purchase prices"
  ) +
  scale_y_continuous(
    limits = c(-1.3, 3)
  ) +
  scale_x_continuous(
    limits = c(14, 26), breaks = c(15, 20, 25)
  ) +
  theme(
    legend.position = "none",
    plot.title = element_text(size = 7),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.y = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    strip.background = element_blank(),
    plot.margin = unit(c(5.5, 5.5, 10, 5.5), "points")
  )

# Combine
fig456 <- ggarrange(fig4, fig5, fig6,
  ncol = 3, nrow = 1,
  labels = c("Panel B. Income", NULL, NULL), vjust = 0.5, hjust = -0.1,
  font.label = list(size = 8, color = "black", face = "plain")
)



## Skills

# Estimation Binscatter Least Squares Regression; number of bins = 10
# For each housing price indicator vs. academics share
# Store results for plot

est7 <- binsreg(panel_krs_sub$apRent_res_sd, panel_krs_sub$svb_hq_pt_08,
                nbins = 10, cb = T)$data.plot$`Group Full Sample`
est8 <- binsreg(panel_krs_sub$apPurc_res_sd, panel_krs_sub$svb_hq_pt_08,
                nbins = 10, cb = T)$data.plot$`Group Full Sample`
est9 <- binsreg(panel_krs_sub$houPurc_res_sd, panel_krs_sub$svb_hq_pt_08,
                nbins = 10, cb = T)$data.plot$`Group Full Sample`


# Create the figure to plot
fig7 <- ggplot() +
  geom_point(
    data = est7$data.dots, aes(x = x, y = fit),
    color = "#0072B2D0", size = 1.5
  ) +
  geom_ribbon(
    data = est7$data.cb, aes(x = x, ymin = cb.l, ymax = cb.r),
    fill = "#0072B2D0", alpha = 0.2
  ) +
  geom_hline(
    yintercept = 0, size = 0.3, colour = "grey30", linetype = 2
  ) +
  theme_pub() +
  labs(
    x = "Academics share [%]",
    y = "Excessive price growth",
    title = "Apartment rents"
  ) +
  scale_y_continuous(
    limits = c(-1.5, 3)
  ) +
  scale_x_continuous(
    limits = c(4, 25)
  ) +
  theme(
    legend.position = "none",
    plot.title = element_text(size = 7),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.y = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    strip.background = element_blank(),
    plot.margin = unit(c(5.5, 5.5, 10, 5.5), "points")
  )


# Create the figure to plot 2
fig8 <- ggplot() +
  geom_point(
    data = est8$data.dots, aes(x = x, y = fit),
    color = "#0072B2D0", size = 1.5
  ) +
  geom_ribbon(
    data = est8$data.cb, aes(x = x, ymin = cb.l, ymax = cb.r),
    fill = "#0072B2D0", alpha = 0.2
  ) +
  theme_pub() +
  geom_hline(
    yintercept = 0, size = 0.3, colour = "grey30", linetype = 2
  ) +
  labs(
    x = "Academics share [%]",
    y = NULL,
    title = "Apartment purchase prices"
  ) +
  scale_y_continuous(
    limits = c(-1.5, 3)
  ) +
  scale_x_continuous(
    limits = c(4, 25)
  ) +
  theme(
    legend.position = "none",
    plot.title = element_text(size = 7),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.y = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    strip.background = element_blank(),
    plot.margin = unit(c(5.5, 5.5, 10, 5.5), "points")
  )


# Create the figure to plot 3
fig9 <- ggplot() +
  geom_point(
    data = est9$data.dots, aes(x = x, y = fit),
    color = "#0072B2D0", size = 1.5
  ) +
  geom_ribbon(
    data = est9$data.cb, aes(x = x, ymin = cb.l, ymax = cb.r),
    fill = "#0072B2D0", alpha = 0.2
  ) +
  geom_hline(
    yintercept = 0, size = 0.3, colour = "grey30", linetype = 2
  ) +
  theme_pub() +
  labs(
    x = "Academics share [%]",
    y = NULL,
    title = "House purchase prices"
  ) +
  scale_y_continuous(
    limits = c(-1.5, 3)
  ) +
  scale_x_continuous(
    limits = c(4, 25)
  ) +
  theme(
    legend.position = "none",
    plot.title = element_text(size = 7),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.y = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    strip.background = element_blank(),
    plot.margin = unit(c(5.5, 5.5, 10, 5.5), "points")
  )

# Combine
fig789 <- ggarrange(fig7, fig8, fig9,
  ncol = 3, nrow = 1,
  labels = c("Panel C. Skills", NULL, NULL), vjust = 0.5, hjust = -0.1,
  font.label = list(size = 8, color = "black", face = "plain")
)


## Amenities

# Estimation Binscatter Least Squares Regression; number of bins = 10
# For each housing price indicator vs. log guest nights pc
# Store results for plot

est10 <- binsreg(panel_krs_sub$apRent_res_sd, log(panel_krs_sub$guest_nights_pc_08),
                 nbins = 10, cb = T)$data.plot$`Group Full Sample`
est11 <- binsreg(panel_krs_sub$apPurc_res_sd, log(panel_krs_sub$guest_nights_pc_08),
                 nbins = 10, cb = T)$data.plot$`Group Full Sample`
est12 <- binsreg(panel_krs_sub$houPurc_res_sd, log(panel_krs_sub$guest_nights_pc_08),
                 nbins = 10, cb = T)$data.plot$`Group Full Sample`


# Create the figure to plot
fig10 <- ggplot() +
  geom_point(
    data = est10$data.dots, aes(x = x, y = fit),
    color = "#0072B2D0", size = 1.5
  ) +
  geom_ribbon(
    data = est10$data.cb, aes(x = x, ymin = cb.l, ymax = cb.r),
    fill = "#0072B2D0", alpha = 0.2
  ) +
  geom_hline(
    yintercept = 0, size = 0.3, colour = "grey30", linetype = 2
  ) +
  theme_pub() +
  labs(
    x = "Log overnight stays pc [1,000]",
    y = "Excessive price growth",
    title = "Apartment rents"
  ) +
  scale_y_continuous(
    limits = c(-1.3, 3)
  ) +
  theme(
    legend.position = "none",
    plot.title = element_text(size = 7),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.y = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    strip.background = element_blank(),
    plot.margin = unit(c(5.5, 5.5, 10, 5.5), "points")
  )


# Create the figure to plot 2
fig11 <- ggplot() +
  geom_point(
    data = est11$data.dots, aes(x = x, y = fit),
    color = "#0072B2D0", size = 1.5
  ) +
  geom_ribbon(
    data = est11$data.cb, aes(x = x, ymin = cb.l, ymax = cb.r),
    fill = "#0072B2D0", alpha = 0.2
  ) +
  theme_pub() +
  geom_hline(
    yintercept = 0, size = 0.3, colour = "grey30", linetype = 2
  ) +
  labs(
    x = "Log overnight stays pc [1,000]",
    y = NULL,
    title = "Apartment purchase prices"
  ) +
  scale_y_continuous(
    limits = c(-1.3, 3)
  ) +
  theme(
    legend.position = "none",
    plot.title = element_text(size = 7),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.y = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    strip.background = element_blank(),
    plot.margin = unit(c(5.5, 5.5, 10, 5.5), "points")
  )


# Create the figure to plot 3
fig12 <- ggplot() +
  geom_point(
    data = est12$data.dots, aes(x = x, y = fit),
    color = "#0072B2D0", size = 1.5
  ) +
  geom_ribbon(
    data = est12$data.cb, aes(x = x, ymin = cb.l, ymax = cb.r),
    fill = "#0072B2D0", alpha = 0.2
  ) +
  theme_pub() +
  geom_hline(
    yintercept = 0, size = 0.3, colour = "grey30", linetype = 2
  ) +
  labs(
    x = "Log overnight stays pc [1,000]",
    y = NULL,
    title = "House purchase prices"
  ) +
  scale_y_continuous(
    limits = c(-1.3, 3)
  ) +
  theme(
    legend.position = "none",
    plot.title = element_text(size = 7),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.y = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    strip.background = element_blank(),
    plot.margin = unit(c(5.5, 5.5, 10, 5.5), "points")
  )

# Combine
fig1012 <- ggarrange(fig10, fig11, fig12,
  ncol = 3, nrow = 1,
  labels = c("Panel D. Amenities", NULL, NULL), vjust = 0.5, hjust = -0.1,
  font.label = list(size = 8, color = "black", face = "plain")
)


## Put all together and export

ggarrange(fig123, fig456, fig789, fig1012, ncol = 1, nrow = 4)

ggsave(paste0("../figures/figure-6.png"),
  width = 16, height = 16, units = "cm", dpi = 300
)



### Fact stated on page 12: "However, since high levels of income and
#   other demand factors are not exclusive to the Top7 cities,
#   this indicates that there must be another factor setting the Top7 apart,
#   such as the label of being a “global” or “superstar” city."

panel_krs_sub %>%
  select(krs, house_inc_08) %>%
  arrange(desc(house_inc_08))

panel_krs_sub %>%
  select(krs, svb_hq_pt_08) %>%
  arrange(desc(svb_hq_pt_08))

panel_krs_sub %>%
  select(krs, guest_nights_pc_08) %>%
  arrange(desc(guest_nights_pc_08))
