## ---------------------------------------------
##
## Script name: figure-7.R
##
## Purpose of script: Generate Figure 7
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(openxlsx)
library(tidyverse)
library(ggpubr)
library(ggtext)

# Clear environment
rm(list = ls())

# Load customized plot theme
theme_pub <- function() {
  theme_bw() %+replace%
    theme(
      panel.grid.major.x = element_blank(),
      panel.grid.major.y = ggplot2::element_line(color = "gray95"),
      panel.grid.minor.y = element_blank(),
      panel.border = element_blank(),
      axis.line = element_line(colour = "grey40", size = 0.3),
      axis.text = element_text(size = 7),
      axis.title = element_text(size = 7),
      axis.ticks = element_line(colour = "grey40", size = 0.3),
      legend.text = element_text(size = 7),
      legend.background = element_rect(
        colour = "grey30",
        fill = "white",
        size = 0.2
      ),
      legend.key.height = unit(0.8, "line"),
      legend.key.width = unit(1, "line"),
      plot.title = element_text(
        size = 7,
        vjust = 2,
        hjust = 0,
        margin = margin(0.2, 0.2, 0.2, 0.2, "cm")
      )
    )
}



# Import ------------------------------------------------------------------

# Data
panel_krs <- readRDS("../data/panel_krs.RDS")

# Residuals (estimated in script "figure-3.R")
res <- read.xlsx("../data/residuals.xlsx")



# Preparation -------------------------------------------------------------

# Subset 2021
panel_krs_21 <- panel_krs %>%
  filter(year == 2021) %>%
  left_join(res, by = "krs") %>%
  select(
    krs, 
    apRent_chg08, apPurc_chg08, houPurc_chg08, 
    apRent_res_sd, apPurc_res_sd, houPurc_res_sd,
    apRent_08, apPurc_08, houPurc_08
  )


## Reshape, relabel and add titles for plotting

# Price Changes relative to 2008
df <- panel_krs_21 %>%
  pivot_longer(., "apRent_res_sd":"houPurc_08",
    names_to = c("outcome", "variable", "sd"),
    names_sep = "_"
  ) %>%
  select(-sd) %>%
  pivot_wider(.,
    names_from = "variable",
    values_from = "value"
  ) %>%
  rename(level08 = "08") %>%
  mutate(
    outcome = fct_relevel(
      outcome, "apRent", "apPurc", "houPurc"
    ),
    outcome = fct_recode(outcome,
      "Panel A. Apartment rents" = "apRent",
      "Panel B. Apartment purchase prices" = "apPurc",
      "Panel C. House purchase prices" = "houPurc"
    )
  ) %>%
  rename(res_sd = res)


## Calculate slope and r-squared (adjusted) (depicted later in scatter plot)

# Generate squared initial price levels
panel_krs_21 <- panel_krs_21 %>%
  mutate(
    apRent_08_2 = apRent_08^2,
    apPurc_08_2 = apPurc_08^2,
    houPurc_08_2 = houPurc_08^2
  )

# Run linear model
m1 <- summary(lm(apRent_res_sd ~ apRent_08 + apRent_08_2, panel_krs_21))
m2 <- summary(lm(apPurc_res_sd ~ apPurc_08 + apPurc_08_2, panel_krs_21))
m3 <- summary(lm(houPurc_res_sd ~ houPurc_08 + houPurc_08_2, panel_krs_21))

# Extract and store coefficients, se, and r2 in data frame
df_m <- data.frame(
  outcome = c(
    "Panel A. Apartment rents", 
    "Panel B. Apartment purchase prices",
    "Panel C. House purchase prices"
  ),
  coef = c(
    round(m1$coefficients[2, 1], digits = 3),
    round(m2$coefficients[2, 1], digits = 3),
    round(m3$coefficients[2, 1], digits = 3)
  ),
  se = c(
    round(m1$coefficients[2, 2], digits = 3),
    round(m2$coefficients[2, 2], digits = 3),
    round(m3$coefficients[2, 2], digits = 3)
  ),
  R2 = c(
    round(m1$adj.r.squared, digits = 3),
    round(m2$adj.r.squared, digits = 3),
    round(m3$adj.r.squared, digits = 3)
  ),
  x1 = c(-50, -50, -30),
  x2 = c(50, 50, 65),
  y = c(7.5, 7.5, 7.5)
) %>%
  mutate(
    outcome = as.factor(outcome),
    outcome = fct_relevel(
      outcome, "Panel A. Apartment rents",
      "Panel B. Apartment purchase prices",
      "Panel C. House purchase prices"
    )
  )



# Plot --------------------------------------------------------------------

p <- df %>%
  ggplot(., aes(x = level08, y = res_sd)) +
  geom_hline(
    yintercept = 0, size = 0.3, colour = "grey30", linetype = 2
  ) +
  geom_vline(
    xintercept = 0, size = 0.3, colour = "grey30", linetype = 2
  ) +
  geom_point(
    pch = 21, fill = "#0072B2D0", color = "white", size = 1.1, alpha = 0.2
  ) +
  geom_smooth(
    method = "lm", size = 0.5, formula = "y ~ poly(x, 2)",
    colour = "#0072B2D0", se = F
  ) +
  geom_richtext(
    data = df_m, size = 2,
    mapping = aes(
      x = x1, y = y, label = paste0("*R*<sup>2</sup>=", R2)
    ),
    fill = NA, label.color = NA
  ) +
  facet_wrap(~outcome, scales = "free") +
  theme_pub() +
  labs(
    x = "Price level relative to the German mean 2008 [%]",
    y = "Excessive price growth",
    title = NULL
  ) +
  scale_y_continuous(
    limits = c(-3, 8), breaks = c(-2, 0, 2, 4, 6, 8)
  ) +
  theme(
    legend.position = "none",
    plot.title = element_text(size = 8),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.y = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    strip.background = element_blank()
  )

ggsave("../figures/figure-7.png",
  width = 16, height = 5, unit = "cm", dpi = 300
)



### Fact stated in footnote 21: "A regression of the total price change between
#   2008 and 2019 on the initial price level in 2008 yields an R-squared of 0.30
#   (apartment rents), 0.54 (apartment purchase prices) and 0.60
#   (house purchase prices), respectively."

# Run linear model
summary(lm(apRent_chg08 ~ apRent_08, panel_krs_21))
summary(lm(apPurc_chg08 ~ apPurc_08, panel_krs_21))
summary(lm(houPurc_chg08 ~ houPurc_08, panel_krs_21))
