## ---------------------------------------------
##
## Script name: figure-8.R
##
## Purpose of script: Generate Figure 8
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(openxlsx)
library(tidyverse)
library(rgdal)
library(spdep)
library(sf)
library(ggpubr)
library(ggtext)

# Clear environment
rm(list = ls())

# Load customized plot theme
theme_pub <- function() {
  theme_bw() %+replace%
    theme(
      panel.grid.major.x = element_blank(),
      panel.grid.major.y = ggplot2::element_line(color = "gray95"),
      panel.grid.minor.y = element_blank(),
      panel.border = element_blank(),
      axis.line = element_line(colour = "grey40", size = 0.3),
      axis.text = element_text(size = 7),
      axis.title = element_text(size = 7),
      axis.ticks = element_line(colour = "grey40", size = 0.3),
      legend.text = element_text(size = 7),
      legend.background = element_rect(
        colour = "grey30",
        fill = "white",
        size = 0.2
      ),
      legend.key.height = unit(0.8, "line"),
      legend.key.width = unit(1, "line"),
      plot.title = element_text(
        size = 7,
        vjust = 2,
        hjust = 0,
        margin = margin(0.2, 0.2, 0.2, 0.2, "cm")
      )
    )
}



# Import ------------------------------------------------------------------

# Data
panel_krs <- readRDS("../data/panel_krs.RDS")

# Residuals (estimated in script "figure-3.R")
res <- read.xlsx("../data/residuals.xlsx")

# Shapefile
shp <- st_read(dsn = "../data/geodata/vg250_ebenen", layer = "VG250_KRS")



# Preparation -------------------------------------------------------------

# Aggregate polygons to current district level (as of 2021)
# Join multiple polygons per district to unique polygons
shp <- shp %>%
  mutate(RS = ifelse(RS == "16056", "16063", RS)) %>% # joined in 2021
  group_by(RS) %>%
  summarise() %>%
  ungroup() %>%
  st_as_sf()

# Create 2021 subset
panel_krs_21 <- panel_krs %>%
  filter(year == 2021)

# Merge data
stopifnot(class(shp$RS) == class(panel_krs_21$krs))
stopifnot(length(unique(shp$RS)) == length(unique((panel_krs_21$krs))))
shp_21 <- merge(shp, panel_krs_21, by.x = "RS", by.y = "krs")



# Create spatial lag variable ---------------------------------------------

## Apartment rents

# Exclude NAs and save IDs
shp_y_apRent <- shp_21[!is.na(shp_21$apRent_chg08), ]
apRent_ids <- shp_y_apRent$RS

# Construct neighborhood list based on contiguous boundaries
nb_apRent <- poly2nb(shp_y_apRent, queen = TRUE)

# Construct spatial weight matrix: W == "row-standardized"
lw_apRent <- nb2listw(nb_apRent, style = "W", zero.policy = TRUE)

# Crate Spatial Lag
apRent_lag <- lag.listw(lw_apRent, shp_y_apRent$apRent_chg08)


## Apartment purchase prices

# Exclude NAs and save IDs
shp_y_apPurc <- shp_21[!is.na(shp_21$apPurc_chg08), ]
apPurc_ids <- shp_y_apPurc$RS

# Construct neighborhood list based on contiguous boundaries
nb_apPurc <- poly2nb(shp_y_apPurc, queen = TRUE)

# Construct spatial weight matrix: W == "row-standardized"
lw_apPurc <- nb2listw(nb_apPurc, style = "W", zero.policy = TRUE)

# Exclude all districts with no neighbors
self_neighbors <- which(sapply(nb_apPurc, function(x) {
  length(x) == 1 && x[1] == 0
}))
shp_y_apPurc <- shp_y_apPurc[-self_neighbors, ]
apPurc_ids <- shp_y_apPurc$RS
nb_apPurc <- poly2nb(shp_y_apPurc, queen = TRUE)
lw_apPurc <- nb2listw(nb_apPurc, style = "W", zero.policy = TRUE)

# Create Spatial Lag
apPurc_lag <- lag.listw(lw_apPurc, shp_y_apPurc$apPurc_chg08)


## House purchase prices

# Exclude NAs and save IDs
shp_y_houPurc <- shp_21[!is.na(shp_21$houPurc_chg08), ]
houPurc_ids <- shp_y_houPurc$RS

# Construct neighborhood list based on contiguous boundaries
nb_houPurc <- poly2nb(shp_y_houPurc, queen = TRUE)

# Construct spatial weight matrix: W == "row-standardized"
lw_houPurc <- nb2listw(nb_houPurc, style = "W", zero.policy = TRUE)

# Create Spatial Lag
houPurc_lag <- lag.listw(lw_houPurc, shp_y_houPurc$houPurc_chg08)


## Combine

apRent_lag <- as.data.frame(apRent_lag)
ap_Rent_mI <- apRent_lag %>%
  bind_cols(apRent_ids) %>%
  rename(krs = "...2")

apPurc_lag <- as.data.frame(apPurc_lag)
ap_Purc_mI <- apPurc_lag %>%
  bind_cols(apPurc_ids) %>%
  rename(krs = "...2")

houPurc_lag <- as.data.frame(houPurc_lag)
hou_Purc_mI <- houPurc_lag %>%
  bind_cols(houPurc_ids) %>%
  rename(krs = "...2")

mI <- ap_Rent_mI %>%
  full_join(ap_Purc_mI, by = "krs") %>%
  full_join(hou_Purc_mI, by = "krs")




# Preparation for Plotting ------------------------------------------------

# Subset
panel_krs_21 <- panel_krs %>%
  filter(year == 2021) %>%
  left_join(res, by = "krs") %>%
  select(
    krs, 
    apRent_chg08, apPurc_chg08, houPurc_chg08, 
    apRent_res_sd, apPurc_res_sd, houPurc_res_sd
  ) %>%
  left_join(mI, by = "krs")


# Price Changes relative to 2008
df <- panel_krs_21 %>%
  pivot_longer(., "apRent_res_sd":"houPurc_lag",
    names_to = c("outcome", "variable", "sd"),
    names_sep = "_"
  ) %>%
  select(-sd) %>%
  pivot_wider(.,
    names_from = "variable",
    values_from = "value"
  ) %>%
  mutate(
    outcome = fct_relevel(
      outcome, "apRent", "apPurc", "houPurc"
    ),
    outcome = fct_recode(outcome,
      "Panel A. Apartment rents" = "apRent",
      "Panel B. Apartment purchase prices" = "apPurc",
      "Panel C. House purchase prices" = "houPurc"
    )
  ) %>%
  rename(res_sd = res)


## Calculate slope and r-squared (adjusted) (depicted later in scatter plot)

# Run linear model
m1 <- summary(lm(apRent_res_sd ~ apRent_lag, panel_krs_21))
m2 <- summary(lm(apPurc_res_sd ~ apPurc_lag, panel_krs_21))
m3 <- summary(lm(houPurc_res_sd ~ houPurc_lag, panel_krs_21))

# Extract and store coefficients, se, and r2 in data frame
df_m <- data.frame(
  outcome = c(
    "Panel A. Apartment rents",
    "Panel B. Apartment purchase prices",
    "Panel C. House purchase prices"
  ),
  coef = c(
    round(m1$coefficients[2, 1], digits = 3),
    round(m2$coefficients[2, 1], digits = 3),
    round(m3$coefficients[2, 1], digits = 3)
  ),
  se = c(
    round(m1$coefficients[2, 2], digits = 3),
    round(m2$coefficients[2, 2], digits = 3),
    round(m3$coefficients[2, 2], digits = 3)
  ),
  R2 = c(
    round(m1$adj.r.squared, digits = 3),
    round(m2$adj.r.squared, digits = 3),
    round(m3$adj.r.squared, digits = 3)
  ),
  x1 = c(15, 40, 50),
  x2 = c(40, 150, 200),
  y = c(7.5, 7.5, 7.5)
) %>%
  mutate(
    outcome = as.factor(outcome),
    outcome = fct_relevel(
      outcome, "Panel A. Apartment rents",
      "Panel B. Apartment purchase prices",
      "Panel C. House purchase prices"
    )
  )



# Plotting ----------------------------------------------------------------

p <- df %>%
  ggplot(., aes(x = lag, y = res_sd)) +
  geom_hline(
    yintercept = 0, size = 0.3, colour = "grey30", linetype = 2
  ) +
  geom_vline(
    xintercept = 0, colour = "grey30", size = 0.3, linetype = 2
  ) +
  geom_point(
    pch = 21, fill = "#0072B2D0", color = "white", size = 1.1, alpha = 0.2
  ) +
  geom_smooth(
    method = "lm", size = 0.5, formula = "y ~ x",
    colour = "#0072B2D0", se = F
  ) +
  geom_richtext(
    data = df_m, size = 2,
    mapping = aes(
      x = x2, y = y,
      label = paste0(
        "slope=", coef,
        "(", se, ")"
      )
    ),
    fill = NA, label.color = NA
  ) +
  geom_richtext(
    data = df_m, size = 2,
    mapping = aes(
      x = x1, y = y, label = paste0("*R*<sup>2</sup>=", R2)
    ),
    fill = NA, label.color = NA
  ) +
  facet_wrap(~outcome, scales = "free") +
  theme_pub() +
  labs(
    x = "Spatial lag of price change 2008-21 [%]",
    y = "Excessive price growth",
    title = NULL
  ) +
  scale_y_continuous(
    limits = c(-3, 8), breaks = c(-2, 0, 2, 4, 6, 8)
  ) +
  theme(
    legend.position = "none",
    plot.title = element_text(size = 8),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.y = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    strip.background = element_blank()
  )

ggsave("../figures/figure-8.png",
  width = 16, height = 5, unit = "cm", dpi = 300
)



### Fact stated in footnote 21: "A regression of the total price change between 2008 and 2021
#   on a spatial lag variable representing the average of price growth of neighboring districts
#   yields an R-squared of 0.52 (apartment rents), 0.61 (apartment purchase prices),
#   and 0.65 (house purchase prices)."

# Run linear model
summary(lm(apRent_chg08 ~ apRent_lag, panel_krs_21))
summary(lm(apPurc_chg08 ~ apPurc_lag, panel_krs_21))
summary(lm(houPurc_chg08 ~ houPurc_lag, panel_krs_21))
