## ---------------------------------------------
##
## Script name: figure-9.R
##
## Purpose of script: Generate Figure 9
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(openxlsx)
library(tidyverse)
library(spdep)
library(sf)
library(ggpubr)
library(ggtext)

# Clear environment
rm(list = ls())

# Load customized plot theme
theme_pub <- function() {
  theme_bw() %+replace%
    theme(
      panel.grid.major.x = element_blank(),
      panel.grid.major.y = ggplot2::element_line(color = "gray95"),
      panel.grid.minor.y = element_blank(),
      panel.border = element_blank(),
      axis.line = element_line(colour = "grey40", size = 0.3),
      axis.text = element_text(size = 7),
      axis.title = element_text(size = 7),
      axis.ticks = element_line(colour = "grey40", size = 0.3),
      legend.text = element_text(size = 7),
      legend.background = element_rect(
        colour = "grey30",
        fill = "white",
        size = 0.2
      ),
      legend.key.height = unit(0.8, "line"),
      legend.key.width = unit(1, "line"),
      plot.title = element_text(
        size = 7,
        vjust = 2,
        hjust = 0,
        margin = margin(0.2, 0.2, 0.2, 0.2, "cm")
      )
    )
}



# Import ------------------------------------------------------------------

# Data
panel_krs <- readRDS("../data/panel_krs.RDS")

# Residuals (estimated in script "figure-3.R")
res <- read.xlsx("../data/residuals.xlsx")

# Shapefile
shp <- st_read(dsn = "../data/geodata/vg250_ebenen", layer = "VG250_KRS")

# Read in KRS-AMR Key
amr_key <- read.xlsx("../data/keys/krs_amr_rwi_key.xlsx")



# Preparation -------------------------------------------------------------

# Aggregate polygons to current district level (as of 2021)
# Join multiple polygons per district to unique polygons
shp <- shp %>%
  mutate(RS = ifelse(RS == "16056", "16063", RS)) %>% # joined in 2021
  group_by(RS) %>%
  summarise() %>%
  ungroup() %>%
  st_as_sf()

# Create 2021 subset
panel_krs_21 <- panel_krs %>%
  filter(year == 2021)

# Merge data
stopifnot(class(shp$RS) == class(panel_krs_21$krs))
stopifnot(length(unique(shp$RS)) == length(unique((panel_krs_21$krs))))
shp_21 <- merge(shp, panel_krs_21, by.x = "RS", by.y = "krs")



# Compute Distances  -------------------------------------------------------


## AMR (join "16056" and "16063", see above)
amr_key <- amr_key %>%
  select(krs, amr) %>%
  mutate(amr = ifelse(amr == "16056", "16063", amr))
 

## Compute distance matrix (based on centroids of districts)
centr <- shp_21 %>%
  st_centroid() %>%
  st_geometry() %>%
  st_coordinates()
dist <- as.matrix(dist(centr, method = "euclidean", diag = TRUE, upper = TRUE))
colnames(dist) <- shp_21$RS
row.names(dist) <- shp_21$RS
dist_df <- as.data.frame(dist)
dist_df$krs <- shp_21$RS
dist_df$krs_col <- shp_21$RS

dist_df <- dist_df %>%
  left_join(., amr_key, by = "krs")

dist_amr <- data.frame(dist_df$krs, NA)
colnames(dist_amr) <- c("krs", "dist_crd_amr")

for (i in 1:nrow(dist_df)) {
  x <- dist_df[i, "amr"]
  y <- dist_df[i, x]
  dist_amr[i, 2] <- y
}

dist_amr <- dist_amr %>%
  left_join(., amr_key, by = "krs")



# Preparation -------------------------------------------------------------

# Subset
panel_krs_21 <- panel_krs %>%
  filter(year == 2021) %>%
  left_join(res, by = "krs") %>%
  select(
    krs, 
    apRent_chg08, apPurc_chg08, houPurc_chg08, 
    apRent_res_sd, apPurc_res_sd, houPurc_res_sd
  ) %>%
  left_join(dist_amr, by = "krs")


# Price Changes relative to 2008
df <- panel_krs_21 %>%
  pivot_longer(., "apRent_res_sd":"houPurc_res_sd",
    names_to = c("outcome", "variable", "sd"),
    names_sep = "_"
  ) %>%
  select(-sd) %>%
  pivot_wider(.,
    names_from = "variable",
    values_from = "value"
  ) %>%
  mutate(
    outcome = fct_relevel(
      outcome, "apRent", "apPurc", "houPurc"
    ),
    outcome = fct_recode(outcome,
      "Panel A. Apartment rents" = "apRent",
      "Panel B. Apartment purchase prices" = "apPurc",
      "Panel C. House purchase prices" = "houPurc"
    )
  ) %>%
  rename(res_sd = res)


## Make subset of districts belonging to amr of top7 cities 
panel_top7_21 <- panel_krs_21 %>%
  filter(
    dist_crd_amr > 0,
    amr %in% c(
      "02000", "05111", "05315", "06412", "08111", "09162", "11000"
    ),
    krs != "09182"
  )


## Extract slope and r-squared (adjusted) (depicted later in scatter plot)

# Run linear model
m1 <- summary(lm(apRent_res_sd ~ log(dist_crd_amr), panel_top7_21))
m2 <- summary(lm(apPurc_res_sd ~ log(dist_crd_amr), panel_top7_21))
m3 <- summary(lm(houPurc_res_sd ~ log(dist_crd_amr), panel_top7_21))

# Extract and store in df
df_m <- data.frame(
  outcome = c(
    "Panel A. Apartment rents",
    "Panel B. Apartment purchase prices",
    "Panel C. House purchase prices"
  ),
  coef = c(
    round(m1$coefficients[2, 1], digits = 3),
    round(m2$coefficients[2, 1], digits = 3),
    round(m3$coefficients[2, 1], digits = 3)
  ),
  se = c(
    round(m1$coefficients[2, 2], digits = 3),
    round(m2$coefficients[2, 2], digits = 3),
    round(m3$coefficients[2, 2], digits = 3)
  ),
  R2 = c(
    round(m1$adj.r.squared, digits = 3),
    round(m2$adj.r.squared, digits = 3),
    round(m3$adj.r.squared, digits = 3)
  ),
  x1 = c(10.5, 10.5, 10.5),
  x2 = c(9.5, 9.5, 9.5),
  y = c(5.7, 5.7, 5.7)
) %>%
  mutate(
    outcome = as.factor(outcome),
    outcome = fct_relevel(
      outcome, "Panel A. Apartment rents",
      "Panel B. Apartment purchase prices",
      "Panel C. House purchase prices"
    )
  )



# Plotting ----------------------------------------------------------------

p <- df %>%
  filter(
    dist_crd_amr > 0,
    amr %in% c(
      "02000", "05111", "05315", "06412", "08111", "09162", "11000"
    ),
    krs != "09182"
  ) %>%
  ggplot(., aes(x = log(dist_crd_amr), y = res_sd)) +
  geom_hline(
    yintercept = 0, linewidth = 0.3, colour = "grey30", linetype = 2
  ) +
  geom_smooth(
    mapping = aes(
      x = log(dist_crd_amr), y = res_sd, color = amr
    ),
    method = "lm", linewidth = 0.5, formula = "y ~ x", se = F
  ) +
  geom_point(
    mapping = aes(
      x = log(dist_crd_amr), y = res_sd, fill = amr
    ), pch = 21, color = "grey40", size = 1.2
  ) +
  geom_richtext(
    data = df_m, size = 2,
    mapping = aes(
      x = x1, y = y,
      label = paste0(
        "slope=", coef,
        "(", se, ")"
      )
    ),
    fill = NA, label.color = NA
  ) +
  geom_richtext(
    data = df_m, size = 2,
    mapping = aes(
      x = x2, y = y, label = paste0("*R*<sup>2</sup>=", R2)
    ),
    fill = NA, label.color = NA
  ) +
  facet_wrap(~outcome, scales = "free") +
  theme_pub() +
  labs(
    x = "Log distance to center of labor market region",
    y = "Excessive price growth",
    title = NULL
  ) +
  scale_y_continuous(
    limits = c(-3, 6), breaks = c(-2, 0, 2, 4, 6)
  ) +
  scale_fill_brewer(
    palette = "Set2",
    labels = c(
      "Hamburg", "Düsseldorf", "Cologne", "Frankfurt", 
      "Stuttgart", "Munich", "Berlin"
    )
  ) +
  scale_color_brewer(
    palette = "Set2",
    labels = c(
      "Hamburg", "Düsseldorf", "Cologne", "Frankfurt", 
      "Stuttgart", "Munich", "Berlin"
    )
  ) +
  guides(
    fill = guide_legend(title = NULL),
    color = guide_legend(title = NULL)
  ) +
  theme(
    legend.position = "bottom",
    plot.title = element_text(size = 8),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.y = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    strip.background = element_blank()
  )

ggsave("../figures/figure-9.png",
  width = 16, height = 6.5, unit = "cm", dpi = 300
)
