## ---------------------------------------------
##
## Script name: table-2.R
##
## Purpose of script: Generate Results for
##                    Table 2
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(tidyverse)
library(stargazer)
library(plm)
library(lmtest)

# Clear environment
rm(list = ls())



# Import ------------------------------------------------------------------

# Data
panel_krs <- readRDS("../data/panel_krs.RDS")

# Define observation period
period <- c(2008:2021)



# Fixed effects -----------------------------------------------------------

# Define variables
dep_vars <- c("apRent_chg_idx", "apPurc_chg_idx", "houPurc_chg_idx")
vars <- c(
  "lvng_area_pc", "smallapts_pc", "land_prc", "new_apts_pc", "svb_hq_pt", 
  "house_inc", "age", "pop_dens", "dom_mig_pc", "neg_credscore"
)

# Select observation period
panel_krs_sd <- panel_krs %>%
  filter(year %in% period)

# Standardize independent variables to mean 0 and sd 1
# --> interpretation of a SD change in x on y in logpoints
panel_krs_sd[, c(vars)] <- scale(panel_krs_sd[, c(vars)])
plm_krs <- pdata.frame(panel_krs_sd, index = c("krs", "year"))


## Define parts of formulas for regressions

# Dependent variables: log price indices
dep1 <- "log(apRent_chg_idx)"
dep2 <- "log(apPurc_chg_idx)"
dep3 <- "log(houPurc_chg_idx)"

# Independent variables
reg_vars <- c("lvng_area_pc + smallapts_pc + land_prc + new_apts_pc +
              svb_hq_pt + house_inc + age + pop_dens + dom_mig_pc + 
              neg_credscore")


## Run fixed effects models and compute robust SEs, 
#  clustered at district level

# Apartment rents
fe_d1 <- plm(paste0(dep1, " ~ ", reg_vars),
  plm_krs,
  model = "within", effect = "individual"
)
fe_d1_rse <- coeftest(fe_d1,
  vcov = vcovHC(fe_d1,
    type = "HC1",
    cluster = "group"
  )
)


# Apartment purchase prices
fe_d2 <- plm(paste0(dep2, " ~ ", reg_vars),
  plm_krs,
  model = "within", effect = "individual"
)
fe_d2_rse <- coeftest(fe_d2,
  vcov = vcovHC(fe_d2,
    type = "HC1",
    cluster = "group"
  )
)


# House purchase prices
fe_d3 <- plm(paste0(dep3, " ~ ", reg_vars),
  plm_krs,
  model = "within", effect = "individual"
)
fe_d3_rse <- coeftest(fe_d3,
  vcov = vcovHC(fe_d3,
    type = "HC1",
    cluster = "group"
  )
)


# Export
stargazer(fe_d1, fe_d2, fe_d3,
  type = "html",
  se = list(fe_d1_rse[, 2], fe_d2_rse[, 2], fe_d3_rse[, 2]),
  dep.var.labels = c(
    "Apartment rents", "Apartment purchase prices",
    "House purchase prices"
  ),
  covariate.labels = c(
    "Living area pc", "Share of small apartments",
    "Building land prices", "Completed apartments pc",
    "Share of academics", "Household income pc",
    "Mean population age", "Population density",
    "Domestic migration balance",
    "Share of subprime credit scores"
  ),
  omit = c("Constant"),
  omit.stat = c("f"), no.space = T,
  add.lines = list(
    c("District FE", "Yes", "Yes", "Yes"),
    c("Time FE", "No", "No", "No")
  ),
  out = "../tables/table-2.html"
)



### Fact stated on page 15: "However, since an increase in living area
#   per capita by one standard deviation represents, in percentage terms,
#   almost the average percentage increase in living area per capita across
#   the entire observation period (+12%), ..."

((sd(panel_krs$lvng_area_pc) + mean(panel_krs$lvng_area_pc)) / 
    mean(panel_krs$lvng_area_pc) - 1) * 100

panel_krs_21 <- panel_krs %>%
  filter(year == 2021)
mean(panel_krs_21$lvng_area_pc_chg08)



### Fact stated on page 15: "A one standard deviation increase in population
#   density corresponds to an increase of 691 inhabitants per square kilometer,
#   which is more than double at the mean, but roughly equal to the absolute
#   population increase in Munich over our observation period."

sd(panel_krs$pop_dens)

((sd(panel_krs$pop_dens) + mean(panel_krs$pop_dens)) / 
    mean(panel_krs$pop_dens) - 1)

munich_pop21 <- panel_krs %>%
  ungroup() %>%
  filter(year == 2021, krs == "09162") %>%
  select(pop_dens)

munich_pop08 <- panel_krs %>%
  ungroup() %>%
  filter(year == 2008, krs == "09162") %>%
  select(pop_dens)

munich_pop21$pop_dens - munich_pop08$pop_dens


### Fact stated on page 16: "A one standard deviation increase
#   in the share of academics represents about the average skill
#   increase of large cities over our observation period."

sd(panel_krs$svb_hq_pt)

large_hq21 <- panel_krs %>%
  ungroup() %>%
  filter(year == 2021, krs_type == "0" | krs_type == "1") %>%
  select(svb_hq_pt_chg08)

mean(large_hq21$svb_hq_pt_chg08)


### Fact stated on page 17: "A one standard deviation increase 
#   in household income per capita (approximately 15 percent) increases 
#   housing prices by nine (apartment rents), 16 (apartment purchase 
#   prices), and 24 log points (house purchase prices)."

sd(panel_krs$house_inc) / mean(panel_krs$house_inc)
