## ---------------------------------------------
##
## Script name: table-3.R
##
## Purpose of script: Generate Results for
##                    Table 3
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(openxlsx)
library(tidyverse)

# Clear environment
rm(list = ls())



# Import ------------------------------------------------------------------

# Data
panel_krs <- readRDS("../data/panel_krs.RDS")

# Time on the market
tom <- read.xlsx("../data/regdata/TOM.xlsx")



# Market Liquidity --------------------------------------------------------

# Calculate ads per capita --> suffix: _n_pc
ads_pc_in <- panel_krs %>%
  select(
    krs, year, krs_type, pop_total,
    apRent_n, apPurc_n, houPurc_n
  ) %>%
  mutate(across(c(apRent_n, apPurc_n, houPurc_n),
    .fns = ~ . / pop_total * 100,
    .names = "{col}_pc"
  ))

# Merge ads per capita with TOM
liquid <- ads_pc_in %>%
  left_join(tom, by = "krs")

# Calculate means by district type
liquid_means <- liquid %>%
  group_by(krs_type) %>%
  summarise_at(vars(
    apRent_n_pc, apPurc_n_pc, houPurc_n_pc, 
    apRent_tom, apPurc_tom, houPurc_tom
  ), mean, na.rm = T) %>%
  mutate_at(vars(
    apRent_n_pc, apPurc_n_pc, houPurc_n_pc, 
    apRent_tom, apPurc_tom, houPurc_tom
  ), round, digits = 3) %>%
  mutate(krs_type = as.character(krs_type))

# Calculate overall mean
liquid_mean_total <- liquid %>%
  ungroup() %>%
  summarise_at(vars(
    apRent_n_pc, apPurc_n_pc, houPurc_n_pc, 
    apRent_tom, apPurc_tom, houPurc_tom
  ), mean, na.rm = T) %>%
  mutate_at(vars(
    apRent_n_pc, apPurc_n_pc, houPurc_n_pc, 
    apRent_tom, apPurc_tom, houPurc_tom
  ), round, digits = 3) %>%
  mutate(krs_type = "mean", .before = "apRent_n_pc")


# Bind together
liquid_means <- liquid_means %>%
  bind_rows(., liquid_mean_total) %>%
  slice(5, 2, 4, 3, 1, 6)

# Export the computed means for inclusion in Table 3
write.xlsx(liquid_means, "../tables/table-3.xlsx")



## Wilcoxon Rank Sum Tests (as indicated in in Table 3)

# Top7 vs. rest
liquid_top7 <- liquid %>%
  mutate(krs_type = ifelse(krs_type == 0, 1, 0))

pairwise.wilcox.test(liquid_top7$apRent_n_pc, liquid_top7$krs_type)
pairwise.wilcox.test(liquid_top7$apPurc_n_pc, liquid_top7$krs_type)
pairwise.wilcox.test(liquid_top7$houPurc_n_pc, liquid_top7$krs_type)
pairwise.wilcox.test(liquid_top7$apRent_tom, liquid_top7$krs_type)
pairwise.wilcox.test(liquid_top7$apPurc_tom, liquid_top7$krs_type)
pairwise.wilcox.test(liquid_top7$houPurc_tom, liquid_top7$krs_type)

# Large urban vs. rest
liquid_1 <- liquid %>%
  mutate(krs_type = ifelse(krs_type == 1, 1, 0))

pairwise.wilcox.test(liquid_1$apRent_n_pc, liquid_1$krs_type)
pairwise.wilcox.test(liquid_1$apPurc_n_pc, liquid_1$krs_type)
pairwise.wilcox.test(liquid_1$houPurc_n_pc, liquid_1$krs_type)
pairwise.wilcox.test(liquid_1$apRent_tom, liquid_1$krs_type)
pairwise.wilcox.test(liquid_1$apPurc_tom, liquid_1$krs_type)
pairwise.wilcox.test(liquid_1$houPurc_tom, liquid_1$krs_type)

# Urban vs. rest
liquid_2 <- liquid %>%
  mutate(krs_type = ifelse(krs_type == 2, 1, 0))

pairwise.wilcox.test(liquid_2$apRent_n_pc, liquid_2$krs_type)
pairwise.wilcox.test(liquid_2$apPurc_n_pc, liquid_2$krs_type)
pairwise.wilcox.test(liquid_2$houPurc_n_pc, liquid_2$krs_type)
pairwise.wilcox.test(liquid_2$apRent_tom, liquid_2$krs_type)
pairwise.wilcox.test(liquid_2$apPurc_tom, liquid_2$krs_type)
pairwise.wilcox.test(liquid_2$houPurc_tom, liquid_2$krs_type)

# Rural vs. rest
liquid_3 <- liquid %>%
  mutate(krs_type = ifelse(krs_type == 3, 1, 0))

pairwise.wilcox.test(liquid_3$apRent_n_pc, liquid_3$krs_type)
pairwise.wilcox.test(liquid_3$apPurc_n_pc, liquid_3$krs_type)
pairwise.wilcox.test(liquid_3$houPurc_n_pc, liquid_3$krs_type)
pairwise.wilcox.test(liquid_3$apRent_tom, liquid_3$krs_type)
pairwise.wilcox.test(liquid_3$apPurc_tom, liquid_3$krs_type)
pairwise.wilcox.test(liquid_3$houPurc_tom, liquid_3$krs_type)

# Sparsely populated vs. rest
liquid_4 <- liquid %>%
  mutate(krs_type = ifelse(krs_type == 4, 1, 0))

pairwise.wilcox.test(liquid_4$apRent_n_pc, liquid_4$krs_type)
pairwise.wilcox.test(liquid_4$apPurc_n_pc, liquid_4$krs_type)
pairwise.wilcox.test(liquid_4$houPurc_n_pc, liquid_4$krs_type)
pairwise.wilcox.test(liquid_4$apRent_tom, liquid_4$krs_type)
pairwise.wilcox.test(liquid_4$apPurc_tom, liquid_4$krs_type)
pairwise.wilcox.test(liquid_4$houPurc_tom, liquid_4$krs_type)
