## ---------------------------------------------
##
## Script name: figure-b1.R
##
## Purpose of script: Generate Appendix Figure B-1
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(tidyverse)
library(sf)
library(tmap)

# Clear environment
rm(list = ls())



# Import ------------------------------------------------------------------

# Data
data <- readRDS("../data/panel_krs.RDS")

# Shapefile
shp <- read_sf("../data/geodata/vg250_ebenen/VG250_KRS.shp")



# Preparation -------------------------------------------------------------

# Aggregate polygons to current district level (as of 2021)
# Join multiple polygons per district to unique polygons
shp <- shp %>%
  mutate(RS = ifelse(RS == "16056", "16063", RS)) %>% # joined in 2021
  group_by(RS) %>%
  summarise() %>%
  ungroup() %>%
  st_as_sf()

# 2021 subset
data_21 <- data %>%
  filter(year == 2021) %>%
  select(krs, year, apRent_chg08, apPurc_chg08, houPurc_chg08)

# Merge data to shp file
stopifnot(class(shp$RS) == class(data_21$krs))
stopifnot(length(unique(shp$RS)) == length(unique((data_21$krs))))
shp_data <- merge(shp, data_21, by.x = "RS", by.y = "krs")



# Mapping -----------------------------------------------------------------

# Apartment rents
m1 <- tm_shape(shp_data) +
  tm_fill("apRent_chg08",
    palette = "-RdYlGn",
    style = "pretty",
    title = "Change 08-21 [%]",
    midpoint = 0
  ) +
  tm_borders(alpha = .4) +
  tm_layout(
    main.title = "Panel A. Apartment rents",
    attr.outside = T,
    legend.text.size = 1,
    legend.title.size = 1.4
  )

# Apartment purchase prices
m2 <- tm_shape(shp_data) +
  tm_fill("apPurc_chg08",
    palette = "-RdYlGn",
    title = "Change 08-21 [%]",
    midpoint = 0,
    breaks = c(-50, 0, 100, 200, 300, 400, 500)
  ) +
  tm_borders(alpha = .4) +
  tm_layout(
    main.title = "Panel B. Apartment purchase prices",
    attr.outside = T,
    legend.text.size = 1,
    legend.title.size = 1.4
  )

# House purchase prices
m3 <- tm_shape(shp_data) +
  tm_fill("houPurc_chg08",
    palette = "-RdYlGn",
    title = "Change 08-21 [%]",
    midpoint = 0,
    breaks = c(-50, 0, 100, 200, 300, 400, 500)
  ) +
  tm_borders(alpha = .4) +
  tm_layout(
    main.title = "Panel C. House purchase prices",
    attr.outside = T,
    legend.text.size = 1,
    legend.title.size = 1.4
  )

# Combine and export
m13 <- tmap_arrange(m1, m2, m3, nrow = 1, ncol = 3)
tmap_save(m13, "../figures/figure-b1.png",
  dpi = 300,
  width = 16, height = 7.5
)
