## ---------------------------------------------
##
## Script name: figure-b2.R
##
## Purpose of script: Make Appendix Figure B-2
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(tidyverse)
library(sf)
library(tmap)

# Clear environment
rm(list = ls())



# Import ------------------------------------------------------------------

# Data
data <- readRDS("../data/panel_krs.RDS")

# Shapefile
shp <- read_sf("../data/geodata/vg250_ebenen/VG250_KRS.shp")



# Preparation -------------------------------------------------------------

# Aggregate polygons to current district level (as of 2021)
# Join multiple polygons per district to unique polygons
shp <- shp %>%
  mutate(RS = ifelse(RS == "16056", "16063", RS)) %>% # joined in 2021
  group_by(RS) %>%
  summarise() %>%
  ungroup() %>%
  st_as_sf()

# 2021 subset
data_21 <- data %>%
  filter(year == 2021) %>%
  select(krs, year, krs_type) %>%
  mutate(
    krs_type = recode(krs_type,
      "0" = "Top 7", "1" = "Large urban",
      "2" = "Urban", "3" = "Rural", "4" = "Spars. pop."
    ),
    krs_type = fct_relevel(
      krs_type, "Spars. pop.", "Rural", "Urban", "Large urban", "Top 7"
    )
  )

# Merge to shp file
stopifnot(class(shp$RS) == class(data_21$krs))
stopifnot(length(unique(shp$RS)) == length(unique((data_21$krs))))
shp_data <- merge(shp, data_21, by.x = "RS", by.y = "krs")



# Mapping -----------------------------------------------------------------

m1 <- tm_shape(shp_data) +
  tm_polygons("krs_type",
    title = "",
    alpha = 0.8,
    palette = c(
      "#8DD3C7", "#FFFFB3", "#BEBADA", "#FDB462", "#FB8072"
    )
  ) +
  tm_borders(alpha = .4) +
  tm_layout(
    main.title = "",
    attr.outside = T,
    legend.text.size = 1,
    legend.title.size = 1.4
  )

tmap_save(m1, "../figures/figure-b2.png",
  dpi = 300,
  width = 8, height = 7.5
)
