## ---------------------------------------------
##
## Script name: figure-b3.R
##
## Purpose of script: Generate Appendix Figure B-3
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(tidyverse)
library(rgdal)
library(spdep)
library(tmap)
library(sf)

# Clear environment
rm(list = ls())



# Import ------------------------------------------------------------------

# Data
panel_krs <- readRDS("../data/panel_krs.RDS")

# Shapefile
shp <- read_sf("../data/geodata/vg250_ebenen/VG250_KRS.shp")



# GI Statistic ---------------------------------------------------------------

# Aggregate polygons to current district level (as of 2021)
# Join multiple polygons per district to unique polygons
shp <- shp %>%
  mutate(RS = ifelse(RS == "16056", "16063", RS)) %>% # joined in 2021
  group_by(RS) %>%
  summarise() %>%
  ungroup() %>%
  st_as_sf()

# Create 2021 subset
panel_krs_21 <- panel_krs %>%
  filter(year == 2021)

# Merge shapefile with data
stopifnot(class(shp$RS) == class(panel_krs_21$krs))
stopifnot(length(unique(shp$RS)) == length(unique((panel_krs_21$krs))))
shp_21 <- merge(shp, panel_krs_21, by.x = "RS", by.y = "krs")


### Compute GI Statistic

## Apartment rents

# Exclude NAs
shp_21_apRent <- shp_21[!is.na(shp_21$apRent_chg08), ]

# Construct neighborhood list based on contiguous boundaries
nb_apRent <- poly2nb(shp_21_apRent, queen = TRUE)

# Construct spatial weight matrix: W == "row-standardized"
lw_apRent <- nb2listw(nb_apRent, style = "W", zero.policy = TRUE)

# Exclude districts with no neighbors (due to exclusion of missings above)
self_apRent <- which(sapply(nb_apRent, function(x) {
  length(x) == 1 && x[1] == 0
}))
if (length(self_apRent > 0)) {
  shp_21_apRent <- shp_21_apRent[-self_apRent, ]
}
apRent_ids <- shp_21_apRent$RS
nb_apRent <- poly2nb(shp_21_apRent, queen = TRUE)
lw_apRent <- nb2listw(nb_apRent, style = "W", zero.policy = TRUE)

# Compute Local GI Statistic
apRent_local_g <- localG(shp_21_apRent$apRent_chg08,
  lw_apRent,
  zero.policy = T
)
apRent_local_g <- cbind(shp_21_apRent, as.matrix(apRent_local_g))
names(apRent_local_g)[names(apRent_local_g) == "as.matrix.apRent_local_g."] <- "Gi statistic"


## Apartment purchase prices

# Exclude NAs
shp_21_apPurc <- shp_21[!is.na(shp_21$apPurc_chg08), ]

# Construct neighborhood list based on contiguous boundaries
nb_apPurc <- poly2nb(shp_21_apPurc, queen = TRUE)

# Construct spatial weight matrix: W == "row-standardized"
lw_apPurc <- nb2listw(nb_apPurc, style = "W", zero.policy = TRUE)

# Exclude districts with no neighbors (due to exclusion of missings above)
self_apPurc <- which(sapply(nb_apPurc, function(x) {
  length(x) == 1 && x[1] == 0
}))
if (length(self_apPurc > 0)) {
  shp_21_apPurc <- shp_21_apPurc[-self_apPurc, ]
}
apPurc_ids <- shp_21_apPurc$RS
nb_apPurc <- poly2nb(shp_21_apPurc, queen = TRUE)
lw_apPurc <- nb2listw(nb_apPurc, style = "W", zero.policy = TRUE)

# Compute Local GI Statistic
apPurc_local_g <- localG(shp_21_apPurc$apPurc_chg08,
  lw_apPurc,
  zero.policy = T
)
apPurc_local_g <- cbind(shp_21_apPurc, as.matrix(apPurc_local_g))
names(apPurc_local_g)[names(apPurc_local_g) == "as.matrix.apPurc_local_g."] <- "Gi statistic"


## House purchase prices

# Exclude NAs
shp_21_houPurc <- shp_21[!is.na(shp_21$houPurc_chg08), ]

# Construct neighborhood list based on contiguous boundaries
nb_houPurc <- poly2nb(shp_21_houPurc, queen = TRUE)

# Construct spatial weight matrix: W == "row-standardized"
lw_houPurc <- nb2listw(nb_houPurc, style = "W", zero.policy = TRUE)

# Exclude districts with no neighbors (due to exclusion of missings above)
self_houPurc <- which(sapply(nb_houPurc, function(x) {
  length(x) == 1 && x[1] == 0
}))
if (length(self_houPurc > 0)) {
  shp_21_houPurc <- shp_21_houPurc[-self_houPurc, ]
}
houPurc_ids <- shp_21_houPurc$RS
nb_houPurc <- poly2nb(shp_21_houPurc, queen = TRUE)
lw_houPurc <- nb2listw(nb_houPurc, style = "W", zero.policy = TRUE)

# Compute Local GI Statistic
houPurc_local_g <- localG(shp_21_houPurc$houPurc_chg08,
  lw_houPurc,
  zero.policy = T
)
houPurc_local_g <- cbind(shp_21_houPurc, as.matrix(houPurc_local_g))
names(houPurc_local_g)[names(houPurc_local_g) == "as.matrix.houPurc_local_g."] <- "Gi statistic"



# Plot --------------------------------------------------------------------

# Apartment rents
m1 <- tm_shape(apRent_local_g) +
  tm_fill("Gi statistic",
    palette = "RdBu",
    breaks = c(-6, -4, -2, 0, 2, 4, 6, 8, 10, 12),
    midpoint = 0
  ) +
  tm_borders(alpha = .4) +
  tm_layout(
    main.title = "Panel A. Apartment rents",
    legend.text.size = 1,
    legend.title.size = 1.4
  ) +
  tm_borders(col = "black", alpha = 1)


# Apartment purchase prices
m2 <- tm_shape(apPurc_local_g) +
  tm_fill("Gi statistic",
    palette = "RdBu",
    breaks = c(-6, -4, -2, 0, 2, 4, 6, 8, 10, 12),
    midpoint = 0
  ) +
  tm_borders(alpha = .4) +
  tm_layout(
    main.title = "Panel B. Apartment purchase prices",
    legend.text.size = 1,
    legend.title.size = 1.4
  ) +
  tm_borders(col = "black", alpha = 1)


# House purchase prices
m3 <- tm_shape(houPurc_local_g) +
  tm_fill("Gi statistic",
    palette = "RdBu",
    breaks = c(-6, -4, -2, 0, 2, 4, 6, 8, 10, 12),
    midpoint = 0
  ) +
  tm_borders(alpha = .4) +
  tm_layout(
    main.title = "Panel C. House purchase prices",
    legend.text.size = 1,
    legend.title.size = 1.4
  ) +
  tm_borders(col = "black", alpha = 1)


## Combine plots and export
m13 <- tmap_arrange(m1, m2, m3, nrow = 1, ncol = 3)
tmap_save(m13, "../figures/figure-b3.png",
  dpi = 300,
  width = 16, height = 7.5
)
