## ---------------------------------------------
##
## Script name: figure-b4.R
##
## Purpose of script: Generate Appendix Figure B-4
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(tidyverse)
library(glmnet)
library(plotmo)

# Clear environment
rm(list = ls())

# Set seed
set.seed(1010)



# Import ------------------------------------------------------------------

# Data
panel_krs <- readRDS("../data/panel_krs.RDS")



# LASSO estimator -----------------------------------------------------------

# 2021 subset
panel_krs_21 <- panel_krs %>%
  filter(year == 2021)

# Delete NAs
panel_krs_21_na1 <- panel_krs_21[!is.na(panel_krs_21$apRent_chg08), ]
panel_krs_21_na2 <- panel_krs_21[!is.na(panel_krs_21$apPurc_chg08), ]
panel_krs_21_na3 <- panel_krs_21[!is.na(panel_krs_21$houPurc_chg08), ]


### Create subsets for lasso estimation and standardize variables

# List of variables
vars <- c(
  "lvng_area_pc_chg08", "smallapts_pc_chg08", "houses_pc_chg08",
  "land_prc_chg08", "new_apts_pc_chg08", "developable_chg08",
  "permits_apts_pc_chg08", "new_hou_pc_chg08",
  "svb_hq_pt_chg08", "tight_chg08", "vac_r_chg08", "emp_wz_ind_pt_chg08", 
  "hiring_r_chg08",
  "house_inc_chg08", "gdp_pc_chg08", "guest_nights_chg08",
  "age_chg08", "mig_chg08", "fem_pc_chg08", "students_pc_chg08", 
  "divorces_chg08", "hh_size_chg08",
  "pop_dens_chg08", "dom_mig_pc_chg08", "comm_net_chg08",
  "ext_mig_pc_chg08",
  "neg_credscore_chg08", "debtor_ratio_chg08", "hazard_rate_chg08", 
  "sb_lend_chg08"
)

names <- c(
  "lvng_area_pc", "smallapts_pc", "houses_pc", 
  "land_prc", "new_apts_pc", "developable", "permits_apts_pc", 
  "new_hou_pc",
  "svb_hq_pt", "tight", "vac_r", "emp_wz_ind_pt", "hiring_r",
  "house_inc", "gdp_pc", "guest_nights",
  "age", "mig", "fem_pc", "students_pc", "divorces", "hh_size",
  "pop_dens", "dom_mig_pc", "comm_net", "ext_mig_pc",
  "neg_credscore", "debtor_ratio", "hazard_rate", "sb_lend"
)

### Apartment Rents

# Bring all variables in matrix form
x1 <- as.matrix(panel_krs_21_na1[, c("apRent_chg08", vars)])
x1 <- apply(x1, 2, scale)
x1 <- x1[complete.cases(x1), ]
y1 <- x1[, 1]
x1 <- x1[, -1]
colnames(x1) <- names

## Choose penalty level by 10-fold cross-validation (100 iterations),
## see Cooper et al. (2020) in JPE
l1 <- NULL
for (i in 1:100)
{
  fit <- cv.glmnet(x1, y1)
  sdlamb <- data.frame(fit$lambda.1se)
  l1 <- rbind(l1, sdlamb)
}

lm1 <- as.matrix(l1)
lav1 <- mean(lm1)

# Calculate LASSO
m1 <- glmnet(x1, y1, lambda = lav1)
coef(m1)


### Apartment Purchase prices

# Bring all variables in matrix form
x2 <- as.matrix(panel_krs_21_na2[, c("apPurc_chg08", vars)])
x2 <- apply(x2, 2, scale)
x2 <- x2[complete.cases(x2), ]
y2 <- x2[, 1]
x2 <- x2[, -1]
colnames(x2) <- names

## Choose penalty level by 10-fold cross-validation (100 iterations),
## see Cooper et al. (2020) in JPE
l2 <- NULL
for (i in 1:100)
{
  fit <- cv.glmnet(x2, y2)
  sdlamb <- data.frame(fit$lambda.1se)
  l2 <- rbind(l2, sdlamb)
}

lm2 <- as.matrix(l2)
lav2 <- mean(lm2)

# Calculate LASSO
m2 <- glmnet(x2, y2, lambda = lav2)
coef(m2)


### House Purchase prices

# Bring all variables in matrix form
x3 <- as.matrix(panel_krs_21_na3[, c("houPurc_chg08", vars)])
x3 <- apply(x3, 2, scale)
x3 <- x3[complete.cases(x3), ]
y3 <- x3[, 1]
x3 <- x3[, -1]
colnames(x3) <- names

## Choose penalty level by 10-fold cross-validation (100 iterations),
## see Cooper et al. (2020) in JPE
l3 <- NULL
for (i in 1:100)
{
  fit <- cv.glmnet(x3, y3)
  sdlamb <- data.frame(fit$lambda.1se)
  l3 <- rbind(l3, sdlamb)
}

lm3 <- as.matrix(l3)
lav3 <- mean(lm3)

# Calculate LASSO
m3 <- glmnet(x3, y3, lambda = lav3)
coef(m3)


## LASSO PLOTS

# Apartment rents
m1_full <- glmnet(x1, y1)
png(
  file = "../figures/figure-b4_a.png",
  width = 8, height = 11, units = "cm", res = 300, pointsize = 10
)
plot_glmnet(m1_full, label = T, xvar = "norm")
title("a) Apartment rents",
  adj = 0, line = 3.3,
  cex.main = 1
)
dev.off()

# Apartment Purchase prices
m2_full <- glmnet(x2, y2)
png(
  file = "../figures/figure-b4_b.png",
  width = 8, height = 11, units = "cm", res = 300, pointsize = 10
)
plot_glmnet(m2_full, label = T, xvar = "norm")
title("b) Apartment purchase prices",
  adj = 0, line = 3.3,
  cex.main = 1
)
dev.off()

# House Purchase prices
m3_full <- glmnet(x3, y3)
png(
  file = "../figures/figure-b4_c.png",
  width = 8, height = 11, units = "cm", res = 300, pointsize = 10
)
plot_glmnet(m3_full, label = T, xvar = "norm")
title("c) House purchase prices",
  adj = 0, line = 3.3,
  cex.main = 1
)
dev.off()
