## ---------------------------------------------
##
## Script name: figure-b5.R
##
## Purpose of script: Generate Appendix Figure B-5
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(tidyverse)

# Clear environment
rm(list = ls())

# Load customized plot theme
theme_pub <- function() {
  theme_bw() %+replace%
    theme(
      panel.grid.major.x = element_blank(),
      panel.grid.major.y = ggplot2::element_line(color = "gray95"),
      panel.grid.minor.y = element_blank(),
      panel.border = element_blank(),
      axis.line = element_line(colour = "grey30", size = 0.3),
      axis.text = element_text(size = 7),
      axis.title = element_text(size = 7),
      axis.ticks = element_line(colour = "grey30", size = 0.3),
      legend.text = element_text(size = 7),
      legend.background = element_rect(
        colour = "grey30",
        fill = "white",
        size = 0.2
      ),
      legend.key.height = unit(0.8, "line"),
      legend.key.width = unit(1, "line"),
      plot.title = element_text(
        size = 6,
        vjust = 2,
        hjust = 0,
        margin = margin(0.2, 0.2, 0.2, 0.2, "cm")
      )
    )
}



# Import ------------------------------------------------------------------

# Data
panel_krs <- readRDS("../data/panel_krs.RDS")



# Run bivariate correlations ----------------------------------------------

## Preparation

# 2021 subset
panel_krs_21 <- panel_krs %>%
  filter(year == 2021)

# Define variables and labels
dep_vars <- c(
  "apRent_chg08", "apPurc_chg08", "houPurc_chg08"
)
vars <- c(
  "resbuild_pc_chg08", "lvng_area_pc_chg08", "smallapts_pc_chg08", 
  "houses_pc_chg08",
  "land_prc_chg08", "new_apts_pc_chg08", "developable_chg08",
  "permits_apts_pc_chg08", "new_hou_pc_chg08",
  "svb_hq_pt_chg08", "tight_chg08", "unemp_r_chg08", "vac_r_chg08", 
  "emp_wz_ind_pt_chg08", "hiring_r_chg08",
  "house_inc_chg08", "gdp_pc_chg08", "guest_nights_chg08",
  "age_chg08", "mig_chg08", "fem_pc_chg08", "students_pc_chg08", 
  "divorces_chg08", "hh_size_chg08",
  "pop_dens_chg08", "dom_mig_pc_chg08", "comm_net_chg08",
  "ext_mig_pc_chg08",
  "neg_credscore_chg08", "debtor_ratio_chg08", "hazard_rate_chg08", 
  "sb_lend_chg08"
)
y_names <- c(
  "apRent", "apPurc", "houPurc"
)
x_names <- c(
  "Residential buildings pc", "Living area pc",
  "Share of small apartments", "Share of family houses",
  "Land prices", "Completed apartments pc",
  "Share of developable land", "Building permits pc",
  "Completed houses pc",
  "Share of academics", "Labor market tightness",
  "Unemployment rate", "Vacancy rate",
  "Emp. share in manufacturing", "Hiring rate",
  "Household income pc", "GDP pc", "Overnight stays",
  "Average population age", "Migrant share", "Female share",
  "Student ratio", "Divorce rate", "Average household size",
  "Population density", "Domestic migration balance",
  "Commuter balance", "External migration balance",
  "Share of subprime", "Private debtor rate",
  "Hazard rate", "Mortgage lending"
)

# Standardize all variables to mean 0 and sd 1
panel_krs_21_sd <- panel_krs_21
panel_krs_21_sd[, c(dep_vars, vars)] <- scale(panel_krs_21_sd[, c(dep_vars, vars)])



### Run univariate regressions by looping over all dep_vars and vars

## Extract and store coefficients
l_biv_coef <- list()
l_biv_coef <- lapply(dep_vars, function(y) {
  lapply(vars, function(x) {
    mod <- lm(get(y) ~ get(x), panel_krs_21_sd)
    l_biv_coef[[y]]$x <- mod$coefficients[2]
  })
})
names(l_biv_coef) <- y_names
l_biv_coef <- lapply(l_biv_coef, setNames, x_names)
univ_coef <- bind_rows(l_biv_coef, .id = "column_label")

univ_coef_long <- univ_coef %>%
  rename(y_var = column_label) %>%
  pivot_longer(!y_var, names_to = "x_var", values_to = "coef") %>%
  mutate(model = "bivariate")


## Extract and store SEs
l_biv_se <- list()
l_biv_se <- lapply(dep_vars, function(y) {
  lapply(vars, function(x) {
    mod <- summary(lm(get(y) ~ get(x), panel_krs_21_sd))
    l_biv_se[[y]]$x <- mod$coefficients[2, 2]
  })
})
names(l_biv_se) <- y_names
l_biv_se <- lapply(l_biv_se, setNames, x_names)
univ_se <- bind_rows(l_biv_se, .id = "column_label")

univ_se_long <- univ_se %>%
  rename(y_var = column_label) %>%
  pivot_longer(!y_var, names_to = "x_var", values_to = "se") %>%
  mutate(model = "bivariate")


# Merge Coefs and SEs
reg_biv <- merge(univ_coef_long, univ_se_long,
  by = c("y_var", "x_var", "model")
)

# Calculate 95% confidence bands
reg_biv$up <- reg_biv$coef + (reg_biv$se * 1.96)
reg_biv$down <- reg_biv$coef - (reg_biv$se * 1.96)



# Run multivariate correlations -------------------------------------------

### Run multivariate regressions with selected variables

## Define dependent variables
dep1 <- dep_vars[1]
dep2 <- dep_vars[2]
dep3 <- dep_vars[3]

# Define covariates
var_mult <- c("lvng_area_pc_chg08 + smallapts_pc_chg08 +
               new_apts_pc_chg08 + land_prc_chg08 +
               svb_hq_pt_chg08 + pop_dens_chg08 +
               house_inc_chg08 + age_chg08 +
               dom_mig_pc_chg08 + neg_credscore_chg08")

lm_d1_mult <- lm(paste0(dep1, " ~", var_mult), panel_krs_21_sd)
lm_d2_mult <- lm(paste0(dep2, " ~", var_mult), panel_krs_21_sd)
lm_d3_mult <- lm(paste0(dep3, " ~", var_mult), panel_krs_21_sd)


## Extract and store coefficients
lm_d1_mult_n <- lm_d1_mult
lm_d2_mult_n <- lm_d2_mult
lm_d3_mult_n <- lm_d3_mult

lm_d1_mult_n$coefficients <- lm_d1_mult$coefficients[-1]
lm_d2_mult_n$coefficients <- lm_d2_mult$coefficients[-1]
lm_d3_mult_n$coefficients <- lm_d3_mult$coefficients[-1]

l_multiv_coef <- list()
l_multiv_coef[["apRent"]] <- lm_d1_mult_n$coefficients
l_multiv_coef[["apPurc"]] <- lm_d2_mult_n$coefficients
l_multiv_coef[["houPurc"]] <- lm_d3_mult_n$coefficients

mult_names <- c(
  "Living area pc", "Share of small apartments",
  "Completed apartments pc", "Land prices",
  "Share of academics", "Population density",
  "Household income pc", "Average population age",
  "Domestic migration balance", "Share of subprime"
)

l_multiv_coef <- lapply(l_multiv_coef, setNames, mult_names)
multiv_coef <- bind_rows(l_multiv_coef, .id = "column_label")

multiv_coef_long <- multiv_coef %>%
  rename(y_var = column_label) %>%
  pivot_longer(!y_var, names_to = "x_var", values_to = "coef") %>%
  mutate(model = "multivariate selected")


## Extract and store SEs
l_multiv_se <- list()
l_multiv_se[["apRent"]] <- summary(lm_d1_mult)$coefficients[-1, 2]
l_multiv_se[["apPurc"]] <- summary(lm_d2_mult)$coefficients[-1, 2]
l_multiv_se[["houPurc"]] <- summary(lm_d3_mult)$coefficients[-1, 2]

l_multiv_se <- lapply(l_multiv_se, setNames, mult_names)
multiv_se <- bind_rows(l_multiv_se, .id = "column_label")

multiv_se_long <- multiv_se %>%
  rename(y_var = column_label) %>%
  pivot_longer(!y_var, names_to = "x_var", values_to = "se") %>%
  mutate(model = "multivariate selected")


## Merge Coefs and SEs
reg_multiv <- merge(multiv_coef_long, multiv_se_long,
  by = c("y_var", "x_var", "model")
)


# Calculate 95% confidence bands
reg_multiv$up <- reg_multiv$coef + (reg_multiv$se * 1.96)
reg_multiv$down <- reg_multiv$coef - (reg_multiv$se * 1.96)



# Run multivariate correlations - post-LASSO ------------------------------

### Run multivariate regressions with LASSO selected variables (see figure-b4.R)
var_lasso1 <- c("houses_pc_chg08 + svb_hq_pt_chg08 +
                pop_dens_chg08 + dom_mig_pc_chg08 +
                neg_credscore_chg08")
var_lasso2 <- c("land_prc_chg08 + svb_hq_pt_chg08 +
                vac_r_chg08 + pop_dens_chg08 +
                dom_mig_pc_chg08 + neg_credscore_chg08")
var_lasso3 <- c("smallapts_pc_chg08 + land_prc_chg08 +
                svb_hq_pt_chg08 + vac_r_chg08 +
                house_inc_chg08 + pop_dens_chg08 +
                dom_mig_pc_chg08 + neg_credscore_chg08")

lm_d1_lasso <- lm(paste0(dep1, " ~", var_lasso1), panel_krs_21_sd)
lm_d2_lasso <- lm(paste0(dep2, " ~", var_lasso2), panel_krs_21_sd)
lm_d3_lasso <- lm(paste0(dep3, " ~", var_lasso3), panel_krs_21_sd)


## Extract and store coefficients
lm_d1_lasso_n <- lm_d1_lasso
lm_d2_lasso_n <- lm_d2_lasso
lm_d3_lasso_n <- lm_d3_lasso

lm_d1_lasso_n$coefficients <- lm_d1_lasso$coefficients[-1]
lm_d2_lasso_n$coefficients <- lm_d2_lasso$coefficients[-1]
lm_d3_lasso_n$coefficients <- lm_d3_lasso$coefficients[-1]

l_lasso_coef <- list()
l_lasso_coef[["apRent"]] <- lm_d1_lasso_n$coefficients
l_lasso_coef[["apPurc"]] <- lm_d2_lasso_n$coefficients
l_lasso_coef[["houPurc"]] <- lm_d3_lasso_n$coefficients

lasso_names1 <- c(
  "Share of family houses", "Share of academics",
  "Population density", "Domestic migration balance",
  "Share of subprime"
)
lasso_names2 <- c(
  "Land prices", "Share of academics", "Vacancy rate",
  "Population density", "Domestic migration balance",
  "Share of subprime"
)
lasso_names3 <- c(
  "Share of small apartments", "Land prices",
  "Share of academics", "Vacancy rate",
  "Household income pc", "Population density",
  "Domestic migration balance",
  "Share of subprime"
)

l_lasso_coef[1] <- lapply(l_lasso_coef[1], setNames, lasso_names1)
l_lasso_coef[2] <- lapply(l_lasso_coef[2], setNames, lasso_names2)
l_lasso_coef[3] <- lapply(l_lasso_coef[3], setNames, lasso_names3)
lasso_coef <- bind_rows(l_lasso_coef, .id = "column_label")

lasso_coef_long <- lasso_coef %>%
  rename(y_var = column_label) %>%
  pivot_longer(!y_var, names_to = "x_var", values_to = "coef") %>%
  mutate(model = "post-Lasso")


## Extract and store SEs
l_lasso_se <- list()
l_lasso_se[["apRent"]] <- summary(lm_d1_lasso)$coefficients[-1, 2]
l_lasso_se[["apPurc"]] <- summary(lm_d2_lasso)$coefficients[-1, 2]
l_lasso_se[["houPurc"]] <- summary(lm_d3_lasso)$coefficients[-1, 2]

l_lasso_se[1] <- lapply(l_lasso_se[1], setNames, lasso_names1)
l_lasso_se[2] <- lapply(l_lasso_se[2], setNames, lasso_names2)
l_lasso_se[3] <- lapply(l_lasso_se[3], setNames, lasso_names3)
lasso_se <- bind_rows(l_lasso_se, .id = "column_label")

lasso_se_long <- lasso_se %>%
  rename(y_var = column_label) %>%
  pivot_longer(!y_var, names_to = "x_var", values_to = "se") %>%
  mutate(model = "post-Lasso")


# Merge Coefs and SEs
reg_lasso <- merge(lasso_coef_long, lasso_se_long,
  by = c("y_var", "x_var", "model")
)


# Calculate 95% confidence bands
reg_lasso$up <- reg_lasso$coef + (reg_lasso$se * 1.96)
reg_lasso$down <- reg_lasso$coef - (reg_lasso$se * 1.96)



# Plot Appendix Figure A-5 ------------------------------------------------

## Combine all coefficients
reg_coef <- reg_biv %>%
  bind_rows(., reg_multiv, reg_lasso) %>%
  group_by(y_var, model) %>%
  fill(x_var) %>%
  ungroup() %>%
  mutate(
    x_var = fct_rev(fct_relevel(x_var, c(
      "Living area pc", "Residential buildings pc",
      "Share of small apartments", "Share of family houses",
      "Land prices", "Completed apartments pc",
      "Share of developable land", "Building permits pc",
      "Completed houses pc",
      "Share of academics", "Labor market tightness",
      "Unemployment rate", "Vacancy rate",
      "Emp. share in manufacturing", "Hiring rate",
      "Household income pc", "Share of subprime",
      "Overnight stays", "Private debtor rate", "GDP pc",
      "Average population age", "Migrant share", "Female share",
      "Student ratio", "Divorce rate", "Average household size",
      "Population density", "Domestic migration balance",
      "Commuter balance",
      "External migration balance"
    ))),
    model = fct_relevel(model, "bivariate", "multivariate selected", "post-LASSO"),
    y_var = fct_relevel(y_var, "apRent", "apPurc", "houPurc"),
    y_var = fct_recode(y_var,
      "Apartment rents" = "apRent",
      "Apartment purchase prices" = "apPurc",
      "House purchase prices" = "houPurc"
    )
  )


## Add category labels and relevel factors
reg_group <- reg_coef %>%
  mutate(group = case_when(
    x_var %in% c("Living area pc", "Residential buildings pc", 
                 "Share of small apartments", "Share of family houses") ~ "(1) Exist. supply",
    x_var %in% c("Land prices", "Completed apartments pc", 
                 "Share of developable land", "Building permits pc", 
                 "Completed houses pc") ~ "(2) New supply",
    x_var %in% c("Share of academics", "Labor market tightness", 
                 "Unemployment rate", "Vacancy rate", 
                 "Emp. share in manufacturing", "Hiring rate") ~ "(3) Labor market factors",
    x_var %in% c("Household income pc", "GDP pc", "Overnight stays") ~ "(4) Income & amenities",
    x_var %in% c("Average population age", "Migrant share", 
                 "Female share", "Student ratio", 
                 "Divorce rate", "Average household size") ~ "(5) Socio- demographics",
    x_var %in% c("Population density", "Domestic migration balance", 
                 "Commuter balance", "External migration balance") ~ "(6) Population & mobility",
    TRUE ~ "(7) Financial market"
  )) %>%
  mutate(group = fct_relevel(
    group, "(1) Exist. supply", "(2) New supply", "(3) Labor market factors", 
    "(4) Income & amenities", "(5) Socio- demographics", "(6) Population & mobility",
    "(7) Financial market"
  ))


## Plot regression coefficients
p <- reg_group %>%
  ggplot(
    .,
    aes(
      x = x_var, y = coef, ymax = up, ymin = down, 
      shape = model, colour = model
    )
  ) +
  geom_hline(aes(yintercept = 0),
    size = 0.4, colour = "grey30", linetype = "longdash"
  ) +
  geom_pointrange(
    position = position_dodge2(width = 0.7, reverse = T),
    fill = "white", size = 0.3
  ) +
  coord_flip() +
  labs(
    x = NULL,
    y = "Coefficient estimate"
  ) +
  facet_grid(group ~ y_var,
    scales = "free_y", space = "free",
    labeller = labeller(group = label_wrap_gen(width = 20))
  ) +
  scale_y_continuous(
    limits = c(-1.1, 1.1), breaks = c(-1, -0.5, 0, 0.5, 1)
  ) +
  scale_color_manual(values = c("#D55E00", "#0072B2", "#009e73")) +
  theme_pub() +
  theme(
    legend.position = "bottom",
    legend.title = element_blank(),
    strip.text.x = element_text(size = 7),
    strip.text.y = element_text(size = 6),
    axis.text = element_text(size = 7),
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.border = element_rect(colour = "grey30", fill = NA)
  ) +
  guides(
    shape = guide_legend(override.aes = list(linetype = 0)),
    color = guide_legend(override.aes = list(linetype = 0))
  )

# Export
ggsave("../figures/figure-b5.png",
  width = 16, height = 18, units = "cm", dpi = 300
)
