## ---------------------------------------------
##
## Script name: figure-b6.R
##
## Purpose of script: Generate Appendix Figure B-6
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(tidyverse)
library(ggpubr)

# Clear environment
rm(list = ls())

# Load customized plot theme
theme_pub <- function() {
  theme_bw() %+replace%
    theme(
      panel.grid.major.x = element_blank(),
      panel.grid.major.y = ggplot2::element_line(color = "gray95"),
      panel.grid.minor.y = element_blank(),
      panel.border = element_blank(),
      axis.line = element_line(colour = "grey40", size = 0.3),
      axis.text = element_text(size = 7),
      axis.title = element_text(size = 7),
      axis.ticks = element_line(colour = "grey40", size = 0.3),
      legend.text = element_text(size = 7),
      legend.background = element_rect(
        colour = "grey30",
        fill = "white",
        size = 0.2
      ),
      legend.key.height = unit(0.8, "line"),
      legend.key.width = unit(1, "line"),
      plot.title = element_text(
        size = 7,
        vjust = 2,
        hjust = 0,
        margin = margin(0.2, 0.2, 0.2, 0.2, "cm")
      )
    )
}



# Import ------------------------------------------------------------------

# Data
panel_krs <- readRDS("../data/panel_krs.RDS")



# Preparation -------------------------------------------------------------

# Initial levels of population density and academic share
panel_krs <- panel_krs %>%
  group_by(krs) %>%
  mutate(
    pop_dens_08 = pop_dens[year == 2008],
    svb_hq_pt_08 = svb_hq_pt[year == 2008]
  )

# Subset 2021
panel_krs_21 <- panel_krs %>%
  filter(year == 2021)



# Plotting ----------------------------------------------------------------

# Change in skill level vs. initial log population density

p1 <- panel_krs_21 %>%
  ggplot(., aes(x = log(pop_dens_08), y = svb_hq_pt_chg08)) +
  geom_hline(
    data = panel_krs_21,
    aes(yintercept = mean(svb_hq_pt_chg08, na.rm = T)),
    size = 0.3, colour = "grey30", linetype = 2
  ) +
  geom_vline(
    data = panel_krs_21,
    aes(xintercept = mean(log(pop_dens_08), na.rm = T)),
    size = 0.3, colour = "grey30", linetype = 2
  ) +
  geom_point(
    pch = 21, fill = "#0072B2D0", color = "white", size = 1.1,
    alpha = 0.2
  ) +
  geom_smooth(
    method = "lm", size = 0.5, colour = "#0072B2D0", 
    formula = "y ~ x", se = F
  ) +
  stat_regline_equation(
    aes(label = paste(after_stat(adj.rr.label))),
    formula = y ~ x, size = 2
  ) +
  theme_pub() +
  labs(
    x = "Log population density 2008",
    y = "\u0394 share of academics 2008-21 [pp]",
    title = "Panel A. Initial population"
  ) +
  scale_y_continuous(
    labels = scales::number_format(accuracy = 1)
  ) +
  theme(
    legend.position = "none",
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.y = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    strip.background = element_blank()
  )


# Change in skill level vs. initial skill level

p2 <- panel_krs_21 %>%
  ggplot(., aes(x = svb_hq_pt_08, y = svb_hq_pt_chg08)) +
  geom_hline(
    data = panel_krs_21,
    aes(yintercept = mean(svb_hq_pt_chg08, na.rm = T)),
    size = 0.3, colour = "grey30", linetype = 2
  ) +
  geom_vline(
    data = panel_krs_21,
    aes(xintercept = mean(svb_hq_pt_08, na.rm = T)),
    size = 0.3, colour = "grey30", linetype = 2
  ) +
  geom_point(
    pch = 21, fill = "#0072B2D0", color = "white", size = 1.1,
    alpha = 0.2
  ) +
  geom_smooth(
    method = "lm", size = 0.5, colour = "#0072B2D0", 
    formula = "y ~ x", se = F
  ) +
  stat_regline_equation(
    aes(label = paste(after_stat(adj.rr.label))),
    formula = y ~ x, size = 2
  ) +
  theme_pub() +
  labs(
    x = "Share of academics 2008 [%]",
    y = "\u0394 share of academics 2008-21 [pp]",
    title = "Panel B. Initial skill supply"
  ) +
  scale_y_continuous(
    labels = scales::number_format(accuracy = 1)
  ) +
  scale_x_continuous(
    limits = c(3, 30)
  ) +
  theme(
    legend.position = "none",
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.y = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    strip.background = element_blank()
  )


# Change in skill level vs. initial housing price level

p3 <- panel_krs_21 %>%
  ggplot(., aes(x = houPurc_08, y = svb_hq_pt_chg08)) +
  geom_hline(
    data = panel_krs_21,
    aes(yintercept = mean(svb_hq_pt_chg08, na.rm = T)),
    size = 0.3, colour = "grey30", linetype = 2
  ) +
  geom_vline(
    data = panel_krs_21,
    aes(xintercept = mean(houPurc_08, na.rm = T)),
    size = 0.3, colour = "grey30", linetype = 2
  ) +
  geom_point(
    pch = 21, fill = "#0072B2D0", color = "white", size = 1.1,
    alpha = 0.2
  ) +
  geom_smooth(
    method = "lm", size = 0.5, colour = "#0072B2D0",
    formula = "y ~ x", se = F
  ) +
  stat_regline_equation(
    aes(label = paste(after_stat(adj.rr.label))),
    formula = y ~ x, size = 2
  ) +
  theme_pub() +
  labs(
    x = "House purchase prices 2008",
    y = "\u0394 share of academics 2008-21 [pp]",
    title = "Panel C. Initial house prices"
  ) +
  scale_y_continuous(
    labels = scales::number_format(accuracy = 1)
  ) +
  theme(
    legend.position = "none",
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.y = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    strip.background = element_blank()
  )

# Combine and export
p13 <- ggarrange(p1, p2, p3, ncol = 3, nrow = 1)
ggsave("../figures/figure-b6.png",
  width = 16, height = 5, unit = "cm", dpi = 300
)
