## ---------------------------------------------
##
## Script name: figure-b7.R
##
## Purpose of script: Generate Appendix Figure B-7
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(openxlsx)
library(tidyverse)
library(sf)
library(tmap)

# Clear environment
rm(list = ls())



# Import ------------------------------------------------------------------

# Data
panel_krs <- readRDS("../data/panel_krs.RDS")

# Shapefile
shp <- read_sf("../data/geodata/vg250_ebenen/VG250_KRS.shp")

# Residuals (estimated in script "figure-3.R")
res <- read.xlsx("../data/residuals.xlsx")



# Preparation -------------------------------------------------------

# Aggregate polygons to current district level (as of 2021)
# Join multiple polygons per district to unique polygons
shp <- shp %>%
  mutate(RS = ifelse(RS == "16056", "16063", RS)) %>% # joined in 2021
  group_by(RS) %>%
  summarise() %>%
  ungroup() %>%
  st_as_sf()

# Subset 2021 and merge residuals
panel_krs_21 <- panel_krs %>%
  filter(year == 2021) %>%
  left_join(res, by = "krs") %>%
  select(
    krs, apRent_res_sd,
    apPurc_res_sd, houPurc_res_sd
  )

# Merge to shp file
stopifnot(class(shp$RS) == class(panel_krs_21$krs))
stopifnot(length(unique(shp$RS)) == length(unique((panel_krs_21$krs))))
shp_res <- merge(shp, panel_krs_21, by.x = "RS", by.y = "krs")



# Mapping -----------------------------------------------------------------

# Apartment rents
m1 <- tm_shape(shp_res) +
  tm_fill("apRent_res_sd",
    palette = "-RdYlGn",
    title = "", midpoint = 0,
    breaks = c(-4, -2, -1.5, 0, 1.5, 2, 4, 8)
  ) +
  tm_borders(alpha = .4) +
  tm_layout(
    main.title = "Panel A. Valuation gap: apartment rents [sd]",
    attr.outside = T,
    legend.text.size = 1
  )

# Apartment purchase prices
m2 <- tm_shape(shp_res) +
  tm_fill("apPurc_res_sd",
    palette = "-RdYlGn",
    title = "", midpoint = 0,
    breaks = c(-4, -2, -1.5, 0, 1.5, 2, 4, 8)
  ) +
  tm_borders(alpha = .4) +
  tm_layout(
    main.title = "Panel B. Valuation gap: ap. pur. prices [sd]",
    attr.outside = T,
    legend.text.size = 1
  )

# House purchase prices
m3 <- tm_shape(shp_res) +
  tm_fill("houPurc_res_sd",
    palette = "-RdYlGn",
    title = "", midpoint = 0,
    breaks = c(-4, -2, -1.5, 0, 1.5, 2, 4, 8)
  ) +
  tm_borders(alpha = .4) +
  tm_layout(
    main.title = "Panel C. Valuation gap: hou. pur. prices [sd]",
    attr.outside = T,
    legend.text.size = 1
  )

# Combine and export
m13 <- tmap_arrange(m1, m2, m3, nrow = 1, ncol = 3)
tmap_save(m13, "../figures/figure-b7.png",
  dpi = 300,
  width = 16, height = 7.5
)
