## ---------------------------------------------
##
## Script name: figure-b8.R
##
## Purpose of script: Generate Appendix Figure B-8
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(openxlsx)
library(tidyverse)
library(ggpubr)
library(ggtext)

# Clear environment
rm(list = ls())

# Load customized plot theme
theme_pub <- function() {
  theme_bw() %+replace%
    theme(
      panel.grid.major.x = element_blank(),
      panel.grid.major.y = ggplot2::element_line(color = "gray95"),
      panel.grid.minor.y = element_blank(),
      panel.border = element_blank(),
      axis.line = element_line(colour = "grey40", size = 0.3),
      axis.text = element_text(size = 7),
      axis.title = element_text(size = 7),
      axis.ticks = element_line(colour = "grey40", size = 0.3),
      legend.text = element_text(size = 7),
      legend.background = element_rect(
        colour = "grey30",
        fill = "white",
        size = 0.2
      ),
      legend.key.height = unit(0.8, "line"),
      legend.key.width = unit(1, "line"),
      plot.title = element_text(
        size = 7,
        vjust = 2,
        hjust = 0,
        margin = margin(0.2, 0.2, 0.2, 0.2, "cm")
      )
    )
}



# Import ------------------------------------------------------------------

# Data
panel_krs <- readRDS("../data/panel_krs.RDS")

# Time on the market
tom <- read.xlsx("../data/regdata/TOM.xlsx")

# Residuals (estimated in script "figure-3.R")
res <- read.xlsx("../data/residuals.xlsx")



# Market Liquidity --------------------------------------------------------

# Generate variables: ads per capita --> suffix: _n_pc
ads_pc_in <- panel_krs %>%
  select(krs, year, apRent_n, apPurc_n, houPurc_n, pop_total) %>%
  mutate(across(c(apRent_n, apPurc_n, houPurc_n),
    .fns = ~ . / pop_total * 100,
    .names = "{col}_pc"
  )) %>%
  filter(year == 2021) %>%
  left_join(res, by = "krs") %>%
  select(
    krs,
    apRent_n_pc, apPurc_n_pc, houPurc_n_pc,
    apRent_res_sd, apPurc_res_sd, houPurc_res_sd
  )


# Merge with main dataset
liquid <- ads_pc_in %>%
  left_join(tom, by = "krs")


## Subset for plots

# Ads per capita
liquid_long1 <- liquid %>%
  select(
    krs, apRent_res_sd:houPurc_res_sd,
    apRent_n_pc:houPurc_n_pc
  ) %>%
  rename(
    apRent_ads = apRent_n_pc,
    apPurc_ads = apPurc_n_pc,
    houPurc_ads = houPurc_n_pc
  ) %>%
  pivot_longer(., apRent_res_sd:houPurc_ads,
    names_to = c("var", "type"), names_sep = "_",
    values_to = "value"
  ) %>%
  pivot_wider(.,
    names_from = "type",
    values_from = "value"
  ) %>%
  mutate(
    var = fct_relevel(var, "apRent", "apPurc", "houPurc"),
    var = fct_recode(var,
      "Apartments for rent" = "apRent",
      "Apartments for sale" = "apPurc",
      "Houses for sale" = "houPurc"
    )
  )

# TOM
liquid_long2 <- liquid %>%
  select(
    krs, apRent_res_sd:houPurc_res_sd,
    apRent_tom:houPurc_tom
  ) %>%
  pivot_longer(., apRent_res_sd:houPurc_tom,
    names_to = c("var", "type"), names_sep = "_",
    values_to = "value"
  ) %>%
  pivot_wider(.,
    names_from = "type",
    values_from = "value"
  ) %>%
  mutate(
    var = fct_relevel(var, "apRent", "apPurc", "houPurc"),
    var = fct_recode(var,
      "Apartments for rent" = "apRent",
      "Apartments for sale" = "apPurc",
      "Houses for sale" = "houPurc"
    )
  )


## Calculate slope and r-squared (adjusted) (depicted in plot)

# Run linear model
m1 <- summary(lm(apRent_res_sd ~ apRent_n_pc, liquid))
m2 <- summary(lm(apPurc_res_sd ~ apPurc_n_pc, liquid))
m3 <- summary(lm(houPurc_res_sd ~ houPurc_n_pc, liquid))

# Extract and store in df
df_m1 <- data.frame(
  var = c(
    "Apartments for rent",
    "Apartments for sale",
    "Houses for sale"
  ),
  coef = c(
    round(m1$coefficients[2, 1], digits = 3),
    round(m2$coefficients[2, 1], digits = 3),
    round(m3$coefficients[2, 1], digits = 3)
  ),
  se = c(
    round(m1$coefficients[2, 2], digits = 3),
    round(m2$coefficients[2, 2], digits = 3),
    round(m3$coefficients[2, 2], digits = 3)
  ),
  R2 = c(
    round(m1$adj.r.squared, digits = 3),
    round(m2$adj.r.squared, digits = 3),
    round(m3$adj.r.squared, digits = 3)
  ),
  x1 = c(0.8, 0.2, 0.5),
  x2 = c(4, 0.6, 1.4),
  y = c(7.5, 7.5, 7.5)
) %>%
  mutate(
    var = as.factor(var),
    var = fct_relevel(
      var, "Apartments for rent",
      "Apartments for sale",
      "Houses for sale"
    )
  )


## Calculate slope and r-squared (adjusted) (depicted in plot)

# Run linear model
m4 <- summary(lm(apRent_res_sd ~ apRent_tom, liquid))
m5 <- summary(lm(apPurc_res_sd ~ apPurc_tom, liquid))
m6 <- summary(lm(houPurc_res_sd ~ houPurc_tom, liquid))

# Extract and store in df
df_m2 <- data.frame(
  var = c(
    "Apartments for rent",
    "Apartments for sale",
    "Houses for sale"
  ),
  coef = c(
    round(m4$coefficients[2, 1], digits = 3),
    round(m5$coefficients[2, 1], digits = 3),
    round(m6$coefficients[2, 1], digits = 3)
  ),
  se = c(
    round(m4$coefficients[2, 2], digits = 3),
    round(m5$coefficients[2, 2], digits = 3),
    round(m6$coefficients[2, 2], digits = 3)
  ),
  R2 = c(
    round(m4$adj.r.squared, digits = 3),
    round(m5$adj.r.squared, digits = 3),
    round(m6$adj.r.squared, digits = 3)
  ),
  x1 = c(10, 55, 50),
  x2 = c(22, 150, 100),
  y = c(7.5, 7.5, 7.5)
) %>%
  mutate(
    var = as.factor(var),
    var = fct_relevel(
      var, "Apartments for rent",
      "Apartments for sale",
      "Houses for sale"
    )
  )



# Plotting ----------------------------------------------------------------

# Panel A. Ads per capita
p1 <- liquid_long1 %>%
  ggplot(., aes(x = ads, y = res)) +
  geom_hline(
    yintercept = 0, size = 0.3,
    colour = "grey30",
    linetype = 2
  ) +
  geom_point(
    pch = 21, fill = "#0072B2D0",
    color = "white", size = 1.1,
    alpha = 0.2
  ) +
  geom_smooth(
    method = "lm", size = 0.5,
    formula = "y ~ x",
    colour = "#0072B2D0", se = F
  ) +
  geom_richtext(
    data = df_m1, size = 2,
    mapping = aes(
      x = x2, y = y,
      label = paste0(
        "slope=", coef,
        "(", se, ")"
      )
    ),
    fill = NA, label.color = NA
  ) +
  geom_richtext(
    data = df_m1, size = 2,
    mapping = aes(
      x = x1, y = y,
      label = paste0("*R*<sup>2</sup>=", R2)
    ),
    fill = NA, label.color = NA
  ) +
  facet_wrap(~var, scales = "free") +
  theme_pub() +
  labs(
    x = "Ads per capita [per 100]",
    y = "Excessive price growth",
    title = "Panel A. Advertisements per capita"
  ) +
  scale_y_continuous(
    limits = c(-3, 8),
    breaks = c(-2, 0, 2, 4, 6, 8)
  ) +
  theme(
    legend.position = "none",
    plot.title = element_text(size = 8),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.y = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    strip.background = element_blank()
  )

# Panel B. TOM
p2 <- liquid_long2 %>%
  ggplot(., aes(x = tom, y = res)) +
  geom_hline(
    yintercept = 0, size = 0.3,
    colour = "grey30",
    linetype = 2
  ) +
  geom_point(
    pch = 21, fill = "#0072B2D0",
    color = "white", size = 1.1,
    alpha = 0.2
  ) +
  geom_smooth(
    method = "lm", size = 0.5,
    formula = "y ~ x",
    colour = "#0072B2D0", se = F
  ) +
  geom_richtext(
    data = df_m2, size = 2,
    mapping = aes(
      x = x2, y = y,
      label = paste0(
        "slope=", coef,
        "(", se, ")"
      )
    ),
    fill = NA, label.color = NA
  ) +
  geom_richtext(
    data = df_m2, size = 2,
    mapping = aes(
      x = x1, y = y,
      label = paste0("*R*<sup>2</sup>=", R2)
    ),
    fill = NA, label.color = NA
  ) +
  facet_wrap(~var, scales = "free") +
  theme_pub() +
  labs(
    x = "Time on the market [days]",
    y = "Excessive price growth",
    title = "Panel B. Time on the market"
  ) +
  scale_y_continuous(
    limits = c(-3, 8),
    breaks = c(-2, 0, 2, 4, 6, 8)
  ) +
  theme(
    legend.position = "none",
    plot.title = element_text(size = 8),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.y = element_blank(),
    strip.text.x = element_text(size = 7, hjust = 0),
    strip.background = element_blank()
  )

p12 <- ggarrange(p1, p2, nrow = 2, ncol = 1)

ggsave("../figures/figure-b8.png",
  width = 16, height = 10, unit = "cm", dpi = 300
)
