## ---------------------------------------------
##
## Script name: figure-c1.R
##
## Purpose of script: Generate Appendix Figure C-1
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(tidyverse)
library(stargazer)
library(plm)
library(lmtest)
library(ggh4x)

# Clear environment
rm(list = ls())

# Load customized plot theme
theme_pub <- function() {
  theme_bw() %+replace%
    theme(
      panel.grid.major.x = element_blank(),
      panel.grid.major.y = ggplot2::element_line(color = "gray95"),
      panel.grid.minor.y = element_blank(),
      panel.border = element_blank(),
      axis.line = element_line(colour = "grey30", size = 0.3),
      axis.text = element_text(size = 7),
      axis.title = element_text(size = 7),
      axis.ticks = element_line(colour = "grey30", size = 0.3),
      legend.text = element_text(size = 7),
      legend.background = element_rect(
        colour = "grey30",
        fill = "white",
        size = 0.2
      ),
      legend.key.height = unit(0.8, "line"),
      legend.key.width = unit(1, "line"),
      plot.title = element_text(
        size = 6,
        vjust = 2,
        hjust = 0,
        margin = margin(0.2, 0.2, 0.2, 0.2, "cm")
      )
    )
}



# Import ------------------------------------------------------------------

# Data
panel_krs <- readRDS("../data/panel_krs.RDS")



# Full sample -------------------------------------------------------------

# Define variables
dep_vars <- c("apRent_chg_idx", "apPurc_chg_idx", "houPurc_chg_idx")
vars <- c(
  "lvng_area_pc", "smallapts_pc", "land_prc", "new_apts_pc", "svb_hq_pt", 
  "house_inc", "neg_credscore", "age", "pop_dens", "dom_mig_pc"
)

# Standardize independent variables to mean 0 and sd 1
panel_krs_sd <- panel_krs
panel_krs_sd[, c(vars)] <- scale(panel_krs_sd[, c(vars)])
plm_krs <- pdata.frame(panel_krs_sd, index = c("krs", "year"))


## Define set of variables

# Dependent: log price indices
dep1 <- "log(apRent_chg_idx)"
dep2 <- "log(apPurc_chg_idx)"
dep3 <- "log(houPurc_chg_idx)"

# Independent
reg_vars <- c("lvng_area_pc + smallapts_pc + land_prc + new_apts_pc +
              svb_hq_pt + house_inc + age + pop_dens + dom_mig_pc + 
              neg_credscore")


## Run fixed effects model and compute robust SEs, 
#  clustered at district level

# Apartment rents
fe_d1 <- plm(paste0(dep1, " ~", reg_vars),
  plm_krs,
  na.rm = TRUE, model = "within",
  effect = "individual"
)
fe_d1_rse <- coeftest(fe_d1,
  vcov = vcovHC(fe_d1,
    type = "HC1",
    cluster = "group"
  )
)


# Apartment purchase prices
fe_d2 <- plm(paste0(dep2, " ~", reg_vars),
  plm_krs,
  na.rm = TRUE, model = "within",
  effect = "individual"
)
fe_d2_rse <- coeftest(fe_d2,
  vcov = vcovHC(fe_d2,
    type = "HC1",
    cluster = "group"
  )
)


# House purchase prices
fe_d3 <- plm(paste0(dep3, " ~", reg_vars),
  plm_krs,
  na.rm = TRUE, model = "within",
  effect = "individual"
)
fe_d3_rse <- coeftest(fe_d3,
  vcov = vcovHC(fe_d3,
    type = "HC1",
    cluster = "group"
  )
)


## Extract and store coefficients
lm_d1_mult_n <- fe_d1
lm_d2_mult_n <- fe_d2
lm_d3_mult_n <- fe_d3

l_multiv_coef <- list()
l_multiv_coef[["apRent"]] <- lm_d1_mult_n$coefficients
l_multiv_coef[["apPurc"]] <- lm_d2_mult_n$coefficients
l_multiv_coef[["houPurc"]] <- lm_d3_mult_n$coefficients

mult_names <- c(
  "Living area pc", "Share of small apartments",
  "Building land prices", "Completed apartments pc",
  "Share of academics", "Household income pc",
  "Mean population age", "Population density",
  "Domestic migration balance",
  "Share of subprime credit scores"
)

l_multiv_coef <- lapply(l_multiv_coef, setNames, mult_names)
multiv_coef <- bind_rows(l_multiv_coef, .id = "column_label")

multiv_coef_long <- multiv_coef %>%
  rename(y_var = column_label) %>%
  pivot_longer(!y_var, names_to = "x_var", values_to = "coef") %>%
  mutate(model = "Full sample")


## Extract and store SEs
l_multiv_se <- list()
l_multiv_se[["apRent"]] <- summary(fe_d1)$coefficients[, 2]
l_multiv_se[["apPurc"]] <- summary(fe_d2)$coefficients[, 2]
l_multiv_se[["houPurc"]] <- summary(fe_d3)$coefficients[, 2]

l_multiv_se <- lapply(l_multiv_se, setNames, mult_names)
multiv_se <- bind_rows(l_multiv_se, .id = "column_label")

multiv_se_long <- multiv_se %>%
  rename(y_var = column_label) %>%
  pivot_longer(!y_var, names_to = "x_var", values_to = "se") %>%
  mutate(model = "Full sample")

## Merge Coefs and SEs
reg_multiv_full <- merge(multiv_coef_long, multiv_se_long,
  by = c("y_var", "x_var", "model")
)



# District types ---------------------------------------------------

### Loop through values of krs_type (=district type)

types <- c("1", "2", "3", "4")
names <- c(
  "Spars. populated", "Rural", "Urban", "Large urban"
)

reg_multiv <- list()

reg_multiv <- lapply(types, function(i) {
  
  # Select subset
  panel_krs_sub <- panel_krs_sd %>%
    filter(krs_type == i)

  # Create panel data frame
  plm_krs <- pdata.frame(panel_krs_sub, index = c("krs", "year"))


  ## Run fixed effects model and compute robust SEs, clustered at district level

  # Apartment rents
  fe_d1 <- plm(paste0(dep1, " ~", reg_vars),
    plm_krs,
    na.rm = TRUE, model = "within",
    effect = "individual"
  )
  fe_d1_rse <- coeftest(fe_d1,
    vcov = vcovHC(fe_d1,
      type = "HC1",
      cluster = "group"
    )
  )
  
  # Apartment purchase prices
  fe_d2 <- plm(paste0(dep2, " ~", reg_vars),
    plm_krs,
    na.rm = TRUE, model = "within",
    effect = "individual"
  )
  fe_d2_rse <- coeftest(fe_d2,
    vcov = vcovHC(fe_d2,
      type = "HC1",
      cluster = "group"
    )
  )

  # House purchase prices
  fe_d3 <- plm(paste0(dep3, " ~", reg_vars),
    plm_krs,
    na.rm = TRUE, model = "within",
    effect = "individual"
  )
  fe_d3_rse <- coeftest(fe_d3,
    vcov = vcovHC(fe_d3,
      type = "HC1",
      cluster = "group"
    )
  )


  ## Extract and store coefficients
  lm_d1_mult_n <- fe_d1
  lm_d2_mult_n <- fe_d2
  lm_d3_mult_n <- fe_d3

  l_multiv_coef <- list()
  l_multiv_coef[["apRent"]] <- lm_d1_mult_n$coefficients
  l_multiv_coef[["apPurc"]] <- lm_d2_mult_n$coefficients
  l_multiv_coef[["houPurc"]] <- lm_d3_mult_n$coefficients

  l_multiv_coef_2 <- lapply(l_multiv_coef, setNames, mult_names)
  multiv_coef_2 <- bind_rows(l_multiv_coef_2, .id = "column_label")

  multiv_coef_long_2 <- multiv_coef_2 %>%
    rename(y_var = column_label) %>%
    pivot_longer(!y_var, names_to = "x_var", values_to = "coef") %>%
    mutate(model = names[as.numeric(i)])


  ## Extract and store SEs
  l_multiv_se <- list()
  l_multiv_se[["apRent"]] <- summary(fe_d1)$coefficients[, 2]
  l_multiv_se[["apPurc"]] <- summary(fe_d2)$coefficients[, 2]
  l_multiv_se[["houPurc"]] <- summary(fe_d3)$coefficients[, 2]

  l_multiv_se_2 <- lapply(l_multiv_se, setNames, mult_names)
  multiv_se_2 <- bind_rows(l_multiv_se_2, .id = "column_label")

  multiv_se_long_2 <- multiv_se_2 %>%
    rename(y_var = column_label) %>%
    pivot_longer(!y_var, names_to = "x_var", values_to = "se") %>%
    mutate(model = names[as.numeric(i)])

  ## Merge Coefs and SEs
  reg_multiv[[i]] <- merge(multiv_coef_long_2, multiv_se_long_2,
    by = c("y_var", "x_var", "model")
  )
})

reg_multiv_types <- bind_rows(reg_multiv)



# Excl. top 7 ---------------------------------------------------

# Excl. top 7
panel_krs_sub <- panel_krs_sd %>%
  filter(!(krs %in% c(
    "11000", "02000", "09162", "05315", "06412", "08111", "05111"
  )))

plm_krs <- pdata.frame(panel_krs_sub, index = c("krs", "year"))


## Run fixed effects model and compute robust SEs, 
#  clustered at district level

# Apartment rents
fe_d1 <- plm(paste0(dep1, " ~", reg_vars),
  plm_krs,
  na.rm = TRUE, model = "within",
  effect = "individual"
)
fe_d1_rse <- coeftest(fe_d1,
  vcov = vcovHC(fe_d1,
    type = "HC1",
    cluster = "group"
  )
)


# Apartment purchase prices
fe_d2 <- plm(paste0(dep2, " ~", reg_vars),
  plm_krs,
  na.rm = TRUE, model = "within",
  effect = "individual"
)
fe_d2_rse <- coeftest(fe_d2,
  vcov = vcovHC(fe_d2,
    type = "HC1",
    cluster = "group"
  )
)


# House purchase prices
fe_d3 <- plm(paste0(dep3, " ~", reg_vars),
  plm_krs,
  na.rm = TRUE, model = "within",
  effect = "individual"
)
fe_d3_rse <- coeftest(fe_d3,
  vcov = vcovHC(fe_d3,
    type = "HC1",
    cluster = "group"
  )
)


## Extract and store coefficients
lm_d1_mult_n <- fe_d1
lm_d2_mult_n <- fe_d2
lm_d3_mult_n <- fe_d3

l_multiv_coef <- list()
l_multiv_coef[["apRent"]] <- lm_d1_mult_n$coefficients
l_multiv_coef[["apPurc"]] <- lm_d2_mult_n$coefficients
l_multiv_coef[["houPurc"]] <- lm_d3_mult_n$coefficients

l_multiv_coef_top7 <- lapply(l_multiv_coef, setNames, mult_names)
multiv_coef_top7 <- bind_rows(l_multiv_coef_top7, .id = "column_label")

multiv_coef_long_top7 <- multiv_coef_top7 %>%
  rename(y_var = column_label) %>%
  pivot_longer(!y_var, names_to = "x_var", values_to = "coef") %>%
  mutate(model = "Excl. top 7")


## Extract and store SEs
l_multiv_se <- list()
l_multiv_se[["apRent"]] <- summary(fe_d1)$coefficients[, 2]
l_multiv_se[["apPurc"]] <- summary(fe_d2)$coefficients[, 2]
l_multiv_se[["houPurc"]] <- summary(fe_d3)$coefficients[, 2]

l_multiv_se_top7 <- lapply(l_multiv_se, setNames, mult_names)
multiv_se_top7 <- bind_rows(l_multiv_se_top7, .id = "column_label")

multiv_se_long_top7 <- multiv_se_top7 %>%
  rename(y_var = column_label) %>%
  pivot_longer(!y_var, names_to = "x_var", values_to = "se") %>%
  mutate(model = "Excl. top 7")

## Merge Coefs and SEs
reg_multiv_top7 <- merge(multiv_coef_long_top7, multiv_se_long_top7,
  by = c("y_var", "x_var", "model")
)



# Combine all -------------------------------------------------------------

# Combine
reg_all <- reg_multiv_full %>%
  bind_rows(reg_multiv_types, reg_multiv_top7) %>%
  mutate(group = ifelse(x_var == "Population density", 1, 0)) %>%
  mutate(
    y_var = fct_relevel(y_var, "apRent", "apPurc", "houPurc"),
    y_var = fct_recode(y_var,
      "Apartment rents" = "apRent",
      "Apartment purchase prices" = "apPurc",
      "House purchase prices" = "houPurc"
    ),
    model = fct_relevel(
      model, "Full sample", "Excl. top 7",
      "Spars. populated", "Rural", "Urban", "Large urban"
    )
  ) %>%
  mutate(x_var = fct_relevel(
    x_var, "Share of subprime credit scores",
    "Domestic migration balance", "Population density",
    "Mean population age", "Household income pc",
    "Share of academics", "Completed apartments pc",
    "Building land prices", "Share of small apartments",
    "Living area pc"
  ))


## Calculate 95% confidence bands
reg_all$up <- reg_all$coef + (reg_all$se * 1.96)
reg_all$down <- reg_all$coef - (reg_all$se * 1.96)



# Plotting ----------------------------------------------------------------

## Plot regression coefficients
p1 <- reg_all %>%
  ggplot(
    .,
    aes(
      x = x_var, y = coef, ymax = up, ymin = down, 
      shape = model, colour = model
    )
  ) +
  geom_hline(aes(yintercept = 0),
    size = 0.4, colour = "grey30", linetype = "longdash"
  ) +
  geom_pointrange(
    position = position_dodge2(width = 0.7, reverse = T),
    fill = "white", size = 0.3
  ) +
  coord_flip() +
  labs(
    x = NULL,
    y = "Coefficient estimate"
  ) +
  facet_grid2(vars(group), vars(y_var),
    scales = "free", independent = "x", space = "free"
  ) +
  scale_y_continuous() +
  theme_pub() +
  theme(
    legend.position = "bottom",
    legend.title = element_blank(),
    strip.text.x = element_text(size = 7),
    strip.text.y = element_blank(),
    axis.text = element_text(size = 7),
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.border = element_rect(colour = "grey30", fill = NA)
  ) +
  guides(
    shape = guide_legend(override.aes = list(linetype = 0)),
    color = guide_legend(override.aes = list(linetype = 0))
  )

ggsave("../figures/figure-c1.png",
  width = 16, height = 18, units = "cm", dpi = 300
)
