## ---------------------------------------------
##
## Script name: table-b4.R
##
## Purpose of script: Generate Results for
##                    Appendix Table B-4
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(tidyverse)
library(stargazer)

# Clear environment
rm(list = ls())



# Import ------------------------------------------------------------------

# Data
panel_krs <- readRDS("../data/panel_krs.RDS")



# Preparation -------------------------------------------------------------

# 2021 subset
panel_krs_21 <- panel_krs %>%
  filter(year == 2021) %>%
  ungroup()



# Appendix Table B-4 ------------------------------------------------------

## Individual models

# Pop Density ~ Births
lm_1 <- lm(pop_dens_chg08 ~ births_pc_chg08, panel_krs_21)

# Pop Density ~ Deaths
lm_2 <- lm(pop_dens_chg08 ~ deaths_pc_chg08, panel_krs_21)

# Pop Density ~ Ext Mig
lm_3 <- lm(pop_dens_chg08 ~ ext_mig_balance_sum08, panel_krs_21)

# Pop Density ~ Dom Mig
lm_4 <- lm(pop_dens_chg08 ~ dom_mig_balance_sum08, panel_krs_21)

# Pop Density ~ Births + Deaths + Ext Mig + Dom Mig
lm_5 <- lm(pop_dens_chg08 ~ births_pc_chg08 + deaths_pc_chg08 +
  dom_mig_balance_sum08 + ext_mig_balance_sum08, panel_krs_21)

## Export
stargazer(lm_1, lm_2, lm_3, lm_4, lm_5,
  type = "html",
  dep.var.labels = c("Population density"),
  covariate.labels = c(
    "Birth rate", "Death rate", "Domestic migration balance",
    "External migration balance"
  ),
  omit = c("Constant"), omit.stat = c("ser", "f"),
  no.space = T,
  out = paste0("../tables/table-b4.html")
)
