## ---------------------------------------------
##
## Script name: table-c1.R
##
## Purpose of script: Generate Results for
##                    Appendix Table C-1
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(tidyverse)
library(stargazer)
library(plm)
library(lmtest)

# Clear environment
rm(list = ls())



# Import ------------------------------------------------------------------

# Data
panel_krs <- readRDS("../data/panel_krs.RDS")



# First Difference --------------------------------------------------------

# Define variables
vars <- c(
  "lvng_area_pc", "smallapts_pc", "land_prc", "new_apts_pc",
  "svb_hq_pt", "house_inc", "age", "pop_dens", "dom_mig_pc",
  "neg_credscore"
)

# Standardize variables to mean 0 and sd 1
panel_krs_sd <- panel_krs
panel_krs_sd[, c(vars)] <- scale(panel_krs_sd[, c(vars)])
plm_krs <- pdata.frame(panel_krs_sd, index = c("krs", "year"))


## Define parts of formulas for regressions

# Dependent variables: log price indices
dep1 <- "log(apRent_chg_idx)"
dep2 <- "log(apPurc_chg_idx)"
dep3 <- "log(houPurc_chg_idx)"

# Independent variables:
# Specify -1 to do not include year trend
reg_vars <- c("lvng_area_pc + smallapts_pc +  land_prc + new_apts_pc +
              svb_hq_pt + house_inc + age + pop_dens + dom_mig_pc +
              neg_credscore - 1")


## Run first difference model and compute robust SEs, clustered at district level

# Apartment rents
fd_d1 <- plm(paste0(dep1, " ~", reg_vars),
  plm_krs,
  model = "fd"
)
fd_d1_rse <- coeftest(fd_d1,
  vcov = vcovHC(fd_d1,
    type = "HC1",
    cluster = "group"
  )
)

# Apartment purchase prices
fd_d2 <- plm(paste0(dep2, " ~", reg_vars),
  plm_krs,
  model = "fd"
)
fd_d2_rse <- coeftest(fd_d2,
  vcov = vcovHC(fd_d2,
    type = "HC1",
    cluster = "group"
  )
)

# House purchase prices
fd_d3 <- plm(paste0(dep3, " ~", reg_vars),
  plm_krs,
  model = "fd"
)
fd_d3_rse <- coeftest(fd_d3,
  vcov = vcovHC(fd_d3,
    type = "HC1",
    cluster = "group"
  )
)

# Export
stargazer(fd_d1, fd_d2, fd_d3,
  type = "html",
  se = list(fd_d1_rse[, 2], fd_d2_rse[, 2], fd_d3_rse[, 2]),
  dep.var.labels = c(
    "Apartment rents", "Apartment purchase prices",
    "House purchase prices"
  ),
  covariate.labels = c(
    "Living area pc", "Share of small apartments",
    "Building land prices", "Completed apartments pc",
    "Share of academics", "Household income pc",
    "Mean population age", "Population density",
    "Domestic migration balance",
    "Share of subprime credit scores"
  ),
  omit.stat = c("f"), no.space = T,
  add.lines = list(c("Constant", "No", "No", "No")),
  out = "../tables/table-c1.html"
)
