## ---------------------------------------------
##
## Script name: table-c11.R
##
## Purpose of script: Generate Results for
##                    Appendix Table C-11
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(openxlsx)
library(tidyverse)
library(stargazer)
library(plm)
library(lmtest)

# Clear environment
rm(list = ls())



# Import ------------------------------------------------------------------

# Data
panel_krs <- readRDS("../data/panel_krs.RDS")

# GREIX
greix <- read.xlsx("../data/GREIX/GREIX.xlsx")

# Define period
period <- c(2008:2021)

# Sample (GREIX Cities)
cities <- c(
  "11000", "05314", "14511", "05315", "05913", "14612",
  "05111", "05112", "06412", "02000", "01003", "05515",
  "09162", "12054", "08111", "06414"
)



# Fixed effects -----------------------------------------------------------

# Define variables
dep_vars <- c("GREIX_apts_idx", "GREIX_mfh_idx", "GREIX_efh_idx")
vars <- c(
  "lvng_area_pc", "smallapts_pc", "land_prc", "new_apts_pc",
  "svb_hq_pt", "house_inc", "age", "pop_dens", "dom_mig_pc",
  "neg_credscore"
)

# Extract observation period and cities in GREIX
panel_krs_sd <- panel_krs %>%
  mutate(year = as.numeric(year)) %>%
  filter(
    year %in% period,
    krs %in% cities
  ) %>%
  left_join(greix, by = c("krs", "year"))

# Standardize all variables to mean 0 and sd 1
panel_krs_sd[, c(vars)] <- scale(panel_krs_sd[, c(vars)])
plm_krs <- pdata.frame(panel_krs_sd, index = c("krs", "year"))


## Define parts of formulas for regressions

# Dependent variables: log price indices
dep1 <- "log(GREIX_apts_idx)"
dep2 <- "log(GREIX_mfh_idx)"
dep3 <- "log(GREIX_efh_idx)"

# Independent variables
reg_vars <- c("lvng_area_pc + smallapts_pc + land_prc + new_apts_pc +
              svb_hq_pt + house_inc + age + pop_dens + dom_mig_pc + 
              neg_credscore")


## Run fixed effects models and compute robust SEs, clustered at district level

# Apartment rents
fe_d1 <- plm(paste0(dep1, " ~ ", reg_vars),
  plm_krs,
  model = "within", effect = "individual"
)
fe_d1_rse <- coeftest(fe_d1,
  vcov = vcovHC(fe_d1,
    type = "HC1",
    cluster = "group"
  )
)
summary(fe_d1)
fe_d1_rse


# Apartment purchase prices
fe_d2 <- plm(paste0(dep2, " ~ ", reg_vars),
  plm_krs,
  model = "within", effect = "individual"
)
fe_d2_rse <- coeftest(fe_d2,
  vcov = vcovHC(fe_d2,
    type = "HC1",
    cluster = "group"
  )
)
summary(fe_d2)
fe_d2_rse


# House purchase prices
fe_d3 <- plm(paste0(dep3, " ~ ", reg_vars),
  plm_krs,
  model = "within", effect = "individual"
)
fe_d3_rse <- coeftest(fe_d3,
  vcov = vcovHC(fe_d3,
    type = "HC1",
    cluster = "group"
  )
)
summary(fe_d3)
fe_d3_rse


# Export
stargazer(fe_d1, fe_d2, fe_d3,
  type = "html",
  se = list(fe_d1_rse[, 2], fe_d2_rse[, 2], fe_d3_rse[, 2]),
  dep.var.labels = c(
    "Apartment prices", "Single-fam. house prices",
    "Multi-fam. house prices"
  ),
  covariate.labels = c(
    "Living area pc", "Share of small apartments",
    "Building land prices", "Completed apartments pc",
    "Share of academics", "Household income pc",
    "Mean population age", "Population density",
    "Domestic migration balance",
    "Share of subprime credit scores"
  ),
  omit = c("Constant"),
  omit.stat = c("f"), no.space = T,
  add.lines = list(
    c("District FE", "Yes", "Yes", "Yes"),
    c("Time FE", "No", "No", "No")
  ),
  out = "../tables/table-c11.html"
)
