## ---------------------------------------------
##
## Script name: table-c2.R
##
## Purpose of script: Generate Results for
##                    Appendix Table C-2
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(tidyverse)
library(stargazer)
library(plm)
library(lmtest)

# Clear environment
rm(list = ls())



# Import ------------------------------------------------------------------

# Data
panel_krs <- readRDS("../data/panel_krs.RDS")



# Rob Check: Fixed effects in logs ----------------------------------------

# Rescale dom mig balance to be interpreted as a share of 100 inhabitants
panel_krs <- panel_krs %>%
  mutate(dom_mig_pc = dom_mig_pc / 10)

# Create panel data frame
plm_krs <- pdata.frame(panel_krs, index = c("krs", "year"))


# Define variables
dep_vars <- c("apRent_chg_idx", "apPurc_chg_idx", "houPurc_chg_idx")
vars <- c(
  "lvng_area_pc", "smallapts_pc", "land_prc", "new_apts_pc",
  "svb_hq_pt", "house_inc", "age", "pop_dens", "dom_mig_pc",
  "neg_credscore"
)


## Define parts of formulas for regressions

# Dependent variables: log price indices
dep1 <- "log(apRent_chg_idx)"
dep2 <- "log(apPurc_chg_idx)"
dep3 <- "log(houPurc_chg_idx)"

# Independent variables: absolute vars in logs
reg_vars <- c("log(lvng_area_pc) +  smallapts_pc + log(land_prc) +
  new_apts_pc + svb_hq_pt + log(house_inc) + log(age) +
  log(pop_dens) + dom_mig_pc + neg_credscore")


## Run fixed effects models and compute robust SEs, clustered at district level

# Apartment rents
fe_d1 <- plm(paste0(dep1, " ~", reg_vars),
  plm_krs,
  model = "within", effect = "individual"
)
fe_d1_rse <- coeftest(fe_d1,
  vcov = vcovHC(fe_d1,
    type = "HC1",
    cluster = "group"
  )
)

# Apartment purchase prices
fe_d2 <- plm(paste0(dep2, " ~", reg_vars),
  plm_krs,
  model = "within", effect = "individual"
)
fe_d2_rse <- coeftest(fe_d2,
  vcov = vcovHC(fe_d2,
    type = "HC1",
    cluster = "group"
  )
)

# House purchase prices
fe_d3 <- plm(paste0(dep3, " ~", reg_vars),
  plm_krs,
  model = "within", effect = "individual"
)
fe_d3_rse <- coeftest(fe_d3,
  vcov = vcovHC(fe_d3,
    type = "HC1",
    cluster = "group"
  )
)

# Export
stargazer(fe_d1, fe_d2, fe_d3,
  type = "html",
  se = list(fe_d1_rse[, 2], fe_d2_rse[, 2], fe_d3_rse[, 2]),
  dep.var.labels = c(
    "Apartment rents", "Apartment purchase prices",
    "House purchase prices"
  ),
  covariate.labels = c(
    "Log living area pc", "Share of small apartments",
    "Log land prices", "Completed apartments pc",
    "Share of academics", "Log household income pc",
    "Log mean population age", "Log population density",
    "Domestic migration balance",
    "Share of subprime credit scores"
  ),
  omit = c("year", "Constant"),
  omit.stat = c("f"), no.space = T,
  add.lines = list(
    c("District FE", "Yes", "Yes", "Yes"),
    c("Time FE", "No", "No", "No")
  ),
  out = "../tables/table-c2.html"
)
