## ---------------------------------------------
##
## Script name: table-c4.R
##
## Purpose of script: Generate Results for
##                    Appendix Table C-4
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(tidyverse)
library(stargazer)
library(plm)
library(lmtest)

# Clear environment
rm(list = ls())



# Import ------------------------------------------------------------------

# Data
panel_krs <- readRDS("../data/panel_krs.RDS")

# Shapefile
shp_input <- st_read(
  dsn = "../data/geodata/vg250_ebenen",
  layer = "VG250_KRS"
)


# Aggregate polygons to current district level (as of 2021)
# Join multiple polygons per district to unique polygons
shp_input <- shp_input %>%
  mutate(RS = ifelse(RS == "16056", "16063", RS)) %>% # joined in 2021
  group_by(RS) %>%
  summarise() %>%
  ungroup() %>%
  st_as_sf()



# Create Spatial Lag for every year ---------------------------------------

l_lag <- list()
years <- c(2008:2021)

l_lag <- lapply(years, function(i) {
  
  print(i)
  
  # Create subset
  panel_krs_sub <- panel_krs %>%
    filter(year == i) %>%
    select(
      krs, year, 
      apRent_chg08, apPurc_chg08, houPurc_chg08
    )

  # Merge shapefile with data
  stopifnot(class(shp_input$RS) == class(panel_krs_sub$krs))
  stopifnot(length(unique(shp_input$RS)) == length(unique((panel_krs_sub$krs))))
  shp <- merge(shp_input, panel_krs_sub, by.x = "RS", by.y = "krs")


  ## Apartment rents

  # Exclude NAs
  shp_sub <- shp
  shp_sub[shp_sub$RS == "09363", ] <- NA
  shp_y_apRent <- shp_sub[!is.na(shp_sub$apRent_chg08), ]
  apRent_ids <- shp_y_apRent$RS

  # Construct neighborhood list based on contiguous boundaries
  nb_apRent <- poly2nb(shp_y_apRent, queen = TRUE)

  # Construct spatial weight matrix: W == "row-standardized"
  lw_apRent <- nb2listw(nb_apRent, style = "W", zero.policy = TRUE)

  # Compute Local Moran
  ap_Rent_I <- localmoran(
    shp_y_apRent$apRent_chg08,
    lw_apRent
  )
  apRent_lag <- lag.listw(lw_apRent, shp_y_apRent$apRent_chg08)


  ## Apartment purchase prices

  # Exclude NAs and regions with all neighbors NA
  # These are manually passed below

  range_y <- c(2017:2018)
  range_y2 <- c(2015)
  range_y3 <- c(2016, 2017)
  range_y4 <- c(2020)
  range_y5 <- c(2021)
  shp_sub2 <- shp
  shp_sub2[shp_sub2$RS == "16055" & shp_sub2$year %in% range_y, ] <- NA
  shp_sub2[shp_sub2$RS %in% c("09362", "09363", "12052") &
    shp_sub2$year %in% range_y2, ] <- NA
  shp_sub2[shp_sub2$RS %in% c("09362", "09363") &
    shp_sub2$year %in% range_y3, ] <- NA
  shp_sub2[shp_sub2$RS %in% c("09263", "09361", "09363", "09662", "12052", "16053", "16055") &
    shp_sub2$year %in% range_y4, ] <- NA
  shp_sub2[shp_sub2$RS %in% c("09263", "09361", "16053", "16055") &
    shp_sub2$year %in% range_y5, ] <- NA
  shp_y_apPurc <- shp_sub2[!is.na(shp_sub2$apPurc_chg08), ]
  apPurc_ids <- shp_y_apPurc$RS

  # Construct neighborhood list based on contiguous boundaries
  nb_apPurc <- poly2nb(shp_y_apPurc, queen = TRUE)

  # Construct spatial weight matrix: W == "row-standardized"
  lw_apPurc <- nb2listw(nb_apPurc, style = "W", zero.policy = TRUE)

  # Compute Local Moran
  ap_Purc_I <- localmoran(
    shp_y_apPurc$apPurc_chg08,
    lw_apPurc
  )
  apPurc_lag <- lag.listw(lw_apPurc, shp_y_apPurc$apPurc_chg08)


  ## House purchase prices

  # Exclude NAs
  shp_y_houPurc <- shp[!is.na(shp$houPurc_chg08), ]
  houPurc_ids <- shp_y_houPurc$RS

  # Construct neighborhood list based on contiguous boundaries
  nb_houPurc <- poly2nb(shp_y_houPurc, queen = TRUE)

  # Construct spatial weight matrix: W == "row-standardized"
  lw_houPurc <- nb2listw(nb_houPurc, style = "W", zero.policy = TRUE)

  # Compute Local Moran
  hou_Purc_I <- localmoran(
    shp_y_houPurc$houPurc_chg08,
    lw_houPurc
  )
  houPurc_lag <- lag.listw(lw_houPurc, shp_y_houPurc$houPurc_chg08)


  ## Combine

  apRent_lag <- as.data.frame(apRent_lag)
  ap_Rent_mI <- apRent_lag %>%
    bind_cols(apRent_ids) %>%
    rename(krs = "...2")

  apPurc_lag <- as.data.frame(apPurc_lag)
  ap_Purc_mI <- apPurc_lag %>%
    bind_cols(apPurc_ids) %>%
    rename(krs = "...2")

  houPurc_lag <- as.data.frame(houPurc_lag)
  hou_Purc_mI <- houPurc_lag %>%
    bind_cols(houPurc_ids) %>%
    rename(krs = "...2")

  mI <- ap_Rent_mI %>%
    full_join(ap_Purc_mI, by = "krs") %>%
    full_join(hou_Purc_mI, by = "krs")

  l_lag[[i]] <- mI
})

# Reduce list of data frames to data frame

names(l_lag) <- years

df_lag <- l_lag %>%
  bind_rows(.id = "year")


## Merge to panel data
panel_krs <- merge(panel_krs, df_lag, by = c("krs", "year"))



# Fixed effects -----------------------------------------------------------

# Define variables
vars <- c(
  "lvng_area_pc", "smallapts_pc", "land_prc", "new_apts_pc",
  "svb_hq_pt", "house_inc", "age", "pop_dens", "dom_mig_pc",
  "neg_credscore", "apRent_lag", "apPurc_lag", "houPurc_lag"
)

# Standardize variables to mean 0 and sd 1
panel_krs_sd <- panel_krs
panel_krs_sd[, c(vars)] <- scale(panel_krs_sd[, c(vars)])
plm_krs <- pdata.frame(panel_krs_sd, index = c("krs", "year"))


## Define parts of formulas for regressions

# Dependent variables: log price indices
dep1 <- "log(apRent_chg_idx)"
dep2 <- "log(apPurc_chg_idx)"
dep3 <- "log(houPurc_chg_idx)"

# Independent variables
reg_vars <- c("lvng_area_pc + smallapts_pc + land_prc + new_apts_pc +
              svb_hq_pt + house_inc + age + pop_dens + dom_mig_pc + 
              neg_credscore")


## Run fixed effects models and compute robust SEs, clustered at district level

# Apartment rents
fe_d1 <- plm(paste0(dep1, " ~ ", reg_vars, " + apRent_lag"),
  plm_krs,
  na.rm = T,
  model = "within", effect = "individual"
)
fe_d1_rse <- coeftest(fe_d1,
  vcov = vcovHC(fe_d1,
    type = "HC1",
    cluster = "group"
  )
)

# Apartment purchase prices
fe_d2 <- plm(paste0(dep2, " ~ ", reg_vars, " + apPurc_lag"),
  plm_krs,
  na.rm = T,
  model = "within", effect = "individual"
)
fe_d2_rse <- coeftest(fe_d2,
  vcov = vcovHC(fe_d2,
    type = "HC1",
    cluster = "group"
  )
)

# House purchase prices
fe_d3 <- plm(paste0(dep3, " ~ ", reg_vars, " + houPurc_lag"),
  plm_krs,
  na.rm = T,
  model = "within", effect = "individual"
)
fe_d3_rse <- coeftest(fe_d3,
  vcov = vcovHC(fe_d3,
    type = "HC1",
    cluster = "group"
  )
)

# Export
stargazer(fe_d1, fe_d2, fe_d3,
  type = "html",
  se = list(fe_d1_rse[, 2], fe_d2_rse[, 2], fe_d3_rse[, 2]),
  dep.var.labels = c(
    "Apartment rents", "Apartment purchase prices",
    "House purchase prices"
  ),
  covariate.labels = c(
    "Living area pc", "Share of small apartments",
    "Building land prices", "Completed apartments pc",
    "Share of academics", "Household income pc",
    "Mean population age", "Population density",
    "Domestic migration balance",
    "Share of subprime credit scores",
    "Spatial lag apartment rents",
    "Spatial lag apartment purchase prices",
    "Spatial lag house purchase prices"
  ),
  omit = c("year", "Constant"),
  omit.stat = c("f"), no.space = T,
  add.lines = list(
    c("District FE", "Yes", "Yes", "Yes"),
    c("Time FE", "No", "No", "No")
  ),
  out = "../tables/table-c4.html"
)
