## ---------------------------------------------
##
## Script name: table-c7.R
##
## Purpose of script: Generate Results for
##                    Appendix Table C-7
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(tidyverse)
library(stargazer)

# Clear environment
rm(list = ls())



# Import ------------------------------------------------------------------

# Data
panel_krs <- readRDS("../data/panel_krs.RDS")



# Preparation -------------------------------------------------------------

## Calculate change in new residential areas (2009 to 2021 due to data
#  availability)
panel_krs_21 <- panel_krs %>%
  group_by(krs) %>%
  mutate(
    new_res_area_chg09 =
      (new_res_area / new_res_area[year == 2009] - 1) * 100
  ) %>%
  filter(year == 2021)


# Define variables and labels
dep_vars <- c("apRent_chg08", "apPurc_chg08", "houPurc_chg08")
x_vars <- c(
  "lvng_area_pc_chg08", "smallapts_pc_chg08",
  "land_prc_chg08", "new_apts_pc_chg08",
  "svb_hq_pt_chg08", "house_inc_chg08",
  "neg_credscore_chg08", "age_chg08",
  "pop_dens_chg08", "dom_mig_pc_chg08",
  "new_res_area_chg09"
)

# Standardize all variables to mean 0 and sd 1
panel_ni_21_sd <- panel_krs_21
panel_ni_21_sd[, c(dep_vars, x_vars)] <-
  scale(panel_ni_21_sd[, c(dep_vars, x_vars)])



# Run multivariate correlations -----------------------------------------

## Define dependent variables
dep1 <- dep_vars[1]
dep2 <- dep_vars[2]
dep3 <- dep_vars[3]

# Define independent variables
var_mult <- c("lvng_area_pc_chg08 + smallapts_pc_chg08 +
              land_prc_chg08 + new_apts_pc_chg08 +
              svb_hq_pt_chg08 + house_inc_chg08 +
              age_chg08 + pop_dens_chg08 +
              dom_mig_pc_chg08 + neg_credscore_chg08 +
              new_res_area_chg09")


## Run linear models
lm_d1_mult <- lm(paste0(dep1, " ~", var_mult), panel_ni_21_sd)
lm_d2_mult <- lm(paste0(dep2, " ~", var_mult), panel_ni_21_sd)
lm_d3_mult <- lm(paste0(dep3, " ~", var_mult), panel_ni_21_sd)


## Export
stargazer(lm_d1_mult, lm_d2_mult, lm_d3_mult,
  type = "html",
  dep.var.labels = c(
    "Apartment rents", "Apartment purchase prices",
    "House purchase prices"
  ),
  covariate.labels = c(
    "Living area pc", "Share of small apartments",
    "Building land prices", "Completed apartments pc",
    "Share of academics", "Household income pc",
    "Mean population age", "Population density",
    "Domestic migration balance",
    "Share of subprime credit scores",
    "Newly designated residential zones"
  ),
  omit = c("Constant"), omit.stat = c("ser", "f"),
  no.space = T,
  out = paste0("../tables/table-c7.html")
)
